@@ -67,6 +67,9 @@
                     "[file %s, line %d]: " fmt, \
                     __FILE__, __LINE__, ##__VA_ARGS__)
 
+#define LOG_ALERT(fmt, ...) \
+    slapi_log_error(SLAPI_LOG_ALERT, log_func, fmt, ##__VA_ARGS__)
+
 #define LOG_PWDPOLICY(fmt, ...) \
     slapi_log_error(SLAPI_LOG_PWDPOLICY, log_func, fmt, ##__VA_ARGS__)
 
