@@ -41,6 +41,7 @@
 #define _GNU_SOURCE 1 /* for asprintf() */
 #endif
 
+#include <stdbool.h>
 #include <errno.h>
 #include <stdio.h>
 #include <sys/param.h>
@@ -49,6 +50,14 @@
 #include "back_extdom.h"
 #include "util.h"
 
+#if defined HAVE_DECL_SSS_NSS_GETORIGBYUSERNAME_TIMEOUT && !HAVE_DECL_SSS_NSS_GETORIGBYUSERNAME_TIMEOUT
+#define sss_nss_getorigbyusername_timeout sss_nss_getorigbyname_timeout
+#endif
+
+#if defined HAVE_DECL_SSS_NSS_GETORIGBYGROUPNAME_TIMEOUT && !HAVE_DECL_SSS_NSS_GETORIGBYGROUPNAME_TIMEOUT
+#define sss_nss_getorigbygroupname_timeout sss_nss_getorigbyname_timeout
+#endif
+
 #define SSSD_DOMAIN_SEPARATOR '@'
 
 int get_buffer(size_t *_buf_len, char **_buf)
@@ -98,7 +107,7 @@ static int inc_buffer(size_t buf_max, size_t *_buf_len, char **_buf)
     return 0;
 }
 
-int __nss_to_err(enum nss_status errcode)
+static int __nss_to_err(enum nss_status errcode)
 {
     switch(errcode) {
     case NSS_STATUS_SUCCESS:
@@ -518,6 +527,30 @@ int pack_ber_sid(const char *sid, struct berval **berval)
     return LDAP_SUCCESS;
 }
 
+static bool verify_domain(const char *fqdn, const char *domain_name)
+{
+    const char *pos = strrchr(fqdn, SSSD_DOMAIN_SEPARATOR);
+    if (pos == NULL) {
+        return false;
+    }
+
+    return (strcasecmp(pos + 1, domain_name) == 0);
+}
+
+static char *get_short_name(const char *fqdn, const char *domain_name)
+{
+    const char *pos = strrchr(fqdn, SSSD_DOMAIN_SEPARATOR);
+    if (pos == NULL) {
+        return NULL;
+    }
+
+    if (strcasecmp(pos + 1, domain_name) != 0) {
+        return NULL;
+    }
+
+    return strndup(fqdn, pos - fqdn);
+}
+
 int pack_ber_user(struct ipa_extdom_ctx *ctx,
                   enum response_types response_type,
                   const char *domain_name, const char *user_name,
@@ -534,17 +567,13 @@ int pack_ber_user(struct ipa_extdom_ctx *ctx,
     char *buf = NULL;
     struct group grp;
     size_t c;
-    char *locat;
     char *short_user_name = NULL;
 
-    short_user_name = strdup(user_name);
-    if ((locat = strrchr(short_user_name, SSSD_DOMAIN_SEPARATOR)) != NULL) {
-        if (strcasecmp(locat+1, domain_name) == 0  ) {
-            locat[0] = '\0';
-        } else {
-            ret = LDAP_INVALID_SYNTAX;
-            goto done;
-        }
+    short_user_name = get_short_name(user_name, domain_name);
+    if (short_user_name == NULL) {
+        /* domain mismatch */
+        ret = LDAP_NO_SUCH_OBJECT;
+        goto done;
     }
 
     ber = ber_alloc_t( LBER_USE_DER );
@@ -647,17 +676,13 @@ int pack_ber_group(enum response_types response_type,
     BerElement *ber = NULL;
     int ret;
     size_t c;
-    char *locat;
     char *short_group_name = NULL;
 
-    short_group_name = strdup(group_name);
-    if ((locat = strrchr(short_group_name, SSSD_DOMAIN_SEPARATOR)) != NULL) {
-        if (strcasecmp(locat+1, domain_name) == 0  ) {
-            locat[0] = '\0';
-        } else {
-            ret = LDAP_INVALID_SYNTAX;
-            goto done;
-        }
+    short_group_name = get_short_name(group_name, domain_name);
+    if (short_group_name == NULL) {
+        /* domain mismatch */
+        ret = LDAP_NO_SUCH_OBJECT;
+        goto done;
     }
 
     ber = ber_alloc_t( LBER_USE_DER );
@@ -723,8 +748,8 @@ done:
     return ret;
 }
 
-int pack_ber_name_list(struct extdom_req *req, char **fq_name_list,
-                       struct berval **berval)
+static int pack_ber_name_list(struct extdom_req *req, char **fq_name_list,
+                              struct berval **berval)
 {
     BerElement *ber = NULL;
     int ret;
@@ -880,10 +905,14 @@ static int handle_uid_request(struct ipa_extdom_ctx *ctx,
             }
             goto done;
         }
+        if (!verify_domain(pwd.pw_name, domain_name)) {
+            ret = LDAP_NO_SUCH_OBJECT;
+            goto done;
+        }
 
         if (request_type == REQ_FULL_WITH_GROUPS) {
-            ret = sss_nss_getorigbyname_timeout(pwd.pw_name, get_timeout(ctx),
-                                                &kv_list, &id_type);
+            ret = sss_nss_getorigbyusername_timeout(pwd.pw_name, get_timeout(ctx),
+                                                    &kv_list, &id_type);
             if (ret != 0 || !(id_type == SSS_ID_TYPE_UID
                                 || id_type == SSS_ID_TYPE_BOTH)) {
                 set_err_msg(req, "Failed to read original data");
@@ -959,10 +988,14 @@ static int handle_gid_request(struct ipa_extdom_ctx *ctx,
             }
             goto done;
         }
+        if (!verify_domain(grp.gr_name, domain_name)) {
+            ret = LDAP_NO_SUCH_OBJECT;
+            goto done;
+        }
 
         if (request_type == REQ_FULL_WITH_GROUPS) {
-            ret = sss_nss_getorigbyname_timeout(grp.gr_name, get_timeout(ctx),
-                                                &kv_list, &id_type);
+            ret = sss_nss_getorigbygroupname_timeout(grp.gr_name, get_timeout(ctx),
+                                                     &kv_list, &id_type);
             if (ret != 0 || !(id_type == SSS_ID_TYPE_GID
                                 || id_type == SSS_ID_TYPE_BOTH)) {
                 set_err_msg(req, "Failed to read original data");
@@ -1111,8 +1144,8 @@ static int handle_sid_request(struct ipa_extdom_ctx *ctx,
         }
 
         if (request_type == REQ_FULL_WITH_GROUPS) {
-            ret = sss_nss_getorigbyname_timeout(pwd.pw_name, get_timeout(ctx),
-                                                &kv_list, &id_type);
+            ret = sss_nss_getorigbyusername_timeout(pwd.pw_name, get_timeout(ctx),
+                                                    &kv_list, &id_type);
             if (ret != 0 || !(id_type == SSS_ID_TYPE_UID
                                 || id_type == SSS_ID_TYPE_BOTH)) {
                 set_err_msg(req, "Failed to read original data");
@@ -1148,8 +1181,8 @@ static int handle_sid_request(struct ipa_extdom_ctx *ctx,
         }
 
         if (request_type == REQ_FULL_WITH_GROUPS) {
-            ret = sss_nss_getorigbyname_timeout(grp.gr_name, get_timeout(ctx),
-                                                &kv_list, &id_type);
+            ret = sss_nss_getorigbygroupname_timeout(grp.gr_name, get_timeout(ctx),
+                                                     &kv_list, &id_type);
             if (ret != 0 || !(id_type == SSS_ID_TYPE_GID
                                 || id_type == SSS_ID_TYPE_BOTH)) {
                 set_err_msg(req, "Failed to read original data");
@@ -1261,10 +1294,14 @@ static int handle_username_request(struct ipa_extdom_ctx *ctx,
     ret = getpwnam_r_wrapper(ctx, fq_name, &pwd, &buf, &buf_len);
     switch(ret) {
     case 0:
+        if (!verify_domain(pwd.pw_name, domain_name)) {
+            ret = LDAP_NO_SUCH_OBJECT;
+            goto done;
+        }
         if (request_type == REQ_FULL_WITH_GROUPS) {
-            ret = sss_nss_getorigbyname_timeout(pwd.pw_name,
-                                                get_timeout(ctx),
-                                                &kv_list, &id_type);
+            ret = sss_nss_getorigbyusername_timeout(pwd.pw_name,
+                                                    get_timeout(ctx),
+                                                    &kv_list, &id_type);
             if (ret != 0 || !(id_type == SSS_ID_TYPE_UID
                               || id_type == SSS_ID_TYPE_BOTH)) {
                 set_err_msg(req, "Failed to read original data");
@@ -1351,10 +1388,14 @@ static int handle_groupname_request(struct ipa_extdom_ctx *ctx,
         }
         goto done;
     }
+    if (!verify_domain(grp.gr_name, domain_name)) {
+        ret = LDAP_NO_SUCH_OBJECT;
+        goto done;
+    }
 
     if (request_type == REQ_FULL_WITH_GROUPS) {
-        ret = sss_nss_getorigbyname_timeout(grp.gr_name, get_timeout(ctx),
-                                            &kv_list, &id_type);
+        ret = sss_nss_getorigbygroupname_timeout(grp.gr_name, get_timeout(ctx),
+                                                 &kv_list, &id_type);
         if (ret != 0 || !(id_type == SSS_ID_TYPE_GID
                           || id_type == SSS_ID_TYPE_BOTH)) {
             if (ret == ENOENT) {
