@@ -37,7 +37,10 @@
  * All rights reserved.
  * END COPYRIGHT BLOCK **/
 
+#define _GNU_SOURCE         /* See feature_test_macros(7) */
+
 #include <stdlib.h>
+#include <stdio.h>
 #include <errno.h>
 #include <stdbool.h>
 #include <dirsrv/slapi-plugin.h>
@@ -47,10 +50,17 @@
 #define IPA_CN "cn"
 #define IPA_BASE_ID "ipaBaseID"
 #define IPA_ID_RANGE_SIZE "ipaIDRangeSize"
+#define IPA_RANGE_TYPE "ipaRangeType"
 #define IPA_BASE_RID "ipaBaseRID"
 #define IPA_SECONDARY_BASE_RID "ipaSecondaryBaseRID"
 #define IPA_DOMAIN_ID "ipaNTTrustedDomainSID"
 #define RANGES_FILTER "objectclass=ipaIDRange"
+#define DOMAIN_ID_FILTER "ipaNTTrustedDomainSID=*"
+
+#define AD_TRUST_RANGE_TYPE "ipa-ad-trust"
+#define AD_TRUST_POSIX_RANGE_TYPE "ipa-ad-trust-posix"
+#define LOCAL_RANGE_TYPE "ipa-local"
+
 
 #define IPA_PLUGIN_NAME "ipa-range-check"
 #define IPA_RANGE_CHECK_FEATURE_DESC "IPA ID range check plugin"
@@ -66,24 +76,233 @@ Slapi_PluginDesc ipa_range_check_plugin_desc = {
 
 struct ipa_range_check_ctx {
     Slapi_ComponentId *plugin_id;
-    const char *base_dn;
+    char *base_dn;
 };
 
+typedef enum {
+    RANGE_CHECK_OK,
+    RANGE_CHECK_BASE_OVERLAP,
+    RANGE_CHECK_PRIMARY_PRIMARY_RID_OVERLAP,
+    RANGE_CHECK_SECONDARY_SECONDARY_RID_OVERLAP,
+    RANGE_CHECK_PRIMARY_SECONDARY_RID_OVERLAP,
+    RANGE_CHECK_SECONDARY_PRIMARY_RID_OVERLAP,
+    RANGE_CHECK_DIFFERENT_TYPE_IN_DOMAIN,
+} range_check_result_t;
+
 struct range_info {
     char *name;
     char *domain_id;
+    char *forest_root_id;
+    char *id_range_type;
     uint32_t base_id;
     uint32_t id_range_size;
     uint32_t base_rid;
     uint32_t secondary_base_rid;
+    bool base_rid_set;
+    bool secondary_base_rid_set;
 };
 
-static int slapi_entry_to_range_info(struct slapi_entry *entry,
+static void free_range_info(struct range_info *range) {
+    if (range != NULL) {
+        slapi_ch_free_string(&(range->name));
+        slapi_ch_free_string(&(range->domain_id));
+        slapi_ch_free_string(&(range->forest_root_id));
+        slapi_ch_free_string(&(range->id_range_type));
+        free(range);
+    }
+}
+
+struct domain_info {
+    char *domain_id;
+    char *forest_root_id;
+    struct domain_info *next;
+};
+
+static void free_domain_info(struct domain_info *info) {
+    if (info != NULL) {
+        slapi_ch_free_string(&(info->domain_id));
+        slapi_ch_free_string(&(info->forest_root_id));
+        free(info);
+    }
+}
+
+static int map_domain_to_root(struct domain_info **head,
+                              struct slapi_entry *domain,
+                              struct slapi_entry *root_domain){
+
+    struct domain_info* new_head = NULL;
+    new_head = (struct domain_info*) malloc(sizeof(struct domain_info));
+    if (new_head == NULL) {
+        return ENOMEM;
+    }
+
+    new_head->domain_id = slapi_entry_attr_get_charptr(domain,
+                                                       IPA_DOMAIN_ID);
+    new_head->forest_root_id = slapi_entry_attr_get_charptr(root_domain,
+                                                            IPA_DOMAIN_ID);
+    new_head->next = *head;
+    *head = new_head;
+
+    return 0;
+}
+
+/* Searches for the domain_info struct with the specified domain_id
+ * in the linked list. Returns the forest root domain's ID, or NULL for
+ * local ranges. */
+
+static char* get_forest_root_id(struct domain_info *head, char* domain_id) {
+
+    /* For local ranges there is no forest root domain,
+     * so consider only ranges with domain_id set */
+    if (domain_id != NULL) {
+        while(head) {
+            if (strcasecmp(head->domain_id, domain_id) == 0) {
+                return slapi_ch_strdup(head->forest_root_id);
+            }
+            head = head->next;
+        }
+     }
+
+    return NULL;
+}
+
+
+/*
+ * This function builds a mapping from domain ID to forest
+ * root domain ID.
+ */
+
+static int build_domain_to_forest_root_map(struct domain_info **head,
+                                           struct ipa_range_check_ctx *ctx){
+
+    Slapi_PBlock *trusted_domain_search_pb = NULL;
+    Slapi_Entry **trusted_domain_entries = NULL;
+    Slapi_DN *base_dn = NULL;
+    char *base = NULL;
+
+    int search_result;
+    int ret = 0;
+
+    LOG("Building forest root map \n");
+
+    /* Set the base DN for the search to cn=ad, cn=trusts, $SUFFIX */
+    ret = asprintf(&base, "cn=ad,cn=trusts,%s", ctx->base_dn);
+    if (ret == -1) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    /* Create SDN from the base */
+    base_dn = slapi_sdn_new_dn_byref(base);
+    if (base_dn == NULL) {
+        LOG_FATAL("Failed to convert base DN.\n");
+        ret = LDAP_OPERATIONS_ERROR;
+        goto done;
+    }
+
+    /* Allocate a new parameter block */
+    trusted_domain_search_pb = slapi_pblock_new();
+    if (trusted_domain_search_pb == NULL) {
+        LOG_FATAL("Failed to create new pblock.\n");
+        ret = LDAP_OPERATIONS_ERROR;
+        goto done;
+    }
+
+    /* Search for all the root domains, note the LDAP_SCOPE_ONELEVEL */
+    slapi_search_internal_set_pb(trusted_domain_search_pb,
+                                 base,
+                                 LDAP_SCOPE_SUBTREE, DOMAIN_ID_FILTER,
+                                 NULL, 0, NULL, NULL, ctx->plugin_id, 0);
+
+    ret = slapi_search_internal_pb(trusted_domain_search_pb);
+    if (ret != 0) {
+        LOG_FATAL("Starting internal search failed.\n");
+        ret = LDAP_OPERATIONS_ERROR;
+        goto done;
+    }
+
+    ret = slapi_pblock_get(trusted_domain_search_pb, SLAPI_PLUGIN_INTOP_RESULT, &search_result);
+    if (ret != 0 || search_result != LDAP_SUCCESS) {
+
+        /* If the search for the trusted domains fails,
+         * AD Trust support on IPA server is not available */
+
+        LOG("Empty forest root map as trusts are not enabled on this IPA server.\n");
+        ret = 0;
+        *head = NULL;
+
+        goto done;
+    }
+
+    ret = slapi_pblock_get(trusted_domain_search_pb, SLAPI_PLUGIN_INTOP_SEARCH_ENTRIES,
+                           &trusted_domain_entries);
+
+    if (ret != 0) {
+        LOG_FATAL("Failed to read searched root domain entries.\n");
+        ret = LDAP_OPERATIONS_ERROR;
+        goto done;
+    }
+
+    if (trusted_domain_entries == NULL || trusted_domain_entries[0] == NULL) {
+        LOG("No existing root domain entries.\n");
+        ret = 0;
+        goto done;
+    }
+
+    /* now we iterate the domains and determine which of them are root domains */
+    for (int i = 0; trusted_domain_entries[i] != NULL; i++) {
+
+        ret = slapi_sdn_isparent(base_dn,
+                                 slapi_entry_get_sdn(trusted_domain_entries[i]));
+
+        /* trusted domain is root domain */
+        if (ret == 1) {
+            ret = map_domain_to_root(head,
+                                     trusted_domain_entries[i],
+                                     trusted_domain_entries[i]);
+            if (ret != 0) {
+                goto done;
+            }
+        }
+        else {
+            /* we need to search for the root domain */
+            for (int j = 0; trusted_domain_entries[j] != NULL; j++) {
+                ret = slapi_sdn_isparent(
+                          slapi_entry_get_sdn(trusted_domain_entries[j]),
+                          slapi_entry_get_sdn(trusted_domain_entries[i]));
+
+                /* match, set the jth domain as the root domain for the ith */
+                if (ret == 1) {
+                    ret = map_domain_to_root(head,
+                                             trusted_domain_entries[i],
+                                             trusted_domain_entries[j]);
+                    if (ret != 0) {
+                        goto done;
+                    }
+
+                    break;
+                }
+            }
+        }
+    }
+
+done:
+    slapi_free_search_results_internal(trusted_domain_search_pb);
+    slapi_pblock_destroy(trusted_domain_search_pb);
+    free(base);
+
+    return ret;
+
+}
+
+static int slapi_entry_to_range_info(struct domain_info *domain_info_head,
+                                     struct slapi_entry *entry,
                                      struct range_info **_range)
 {
     int ret;
     unsigned long ul_val;
     struct range_info *range = NULL;
+    Slapi_Attr *attr;
 
     range = calloc(1, sizeof(struct range_info));
     if (range == NULL) {
@@ -91,13 +310,16 @@ static int slapi_entry_to_range_info(struct slapi_entry *entry,
     }
 
     range->name = slapi_entry_attr_get_charptr(entry, IPA_CN);
-    if (range->name == NULL) {
+    range->domain_id = slapi_entry_attr_get_charptr(entry, IPA_DOMAIN_ID);
+    range->id_range_type = slapi_entry_attr_get_charptr(entry, IPA_RANGE_TYPE);
+    range->forest_root_id = get_forest_root_id(domain_info_head,
+                                               range->domain_id);
+
+    if (range->name == NULL || range->id_range_type == NULL) {
         ret = EINVAL;
         goto done;
     }
 
-    range->domain_id = slapi_entry_attr_get_charptr(entry, IPA_DOMAIN_ID);
-
     ul_val = slapi_entry_attr_get_ulong(entry, IPA_BASE_ID);
     if (ul_val == 0 || ul_val >= UINT32_MAX) {
         ret = ERANGE;
@@ -126,12 +348,16 @@ static int slapi_entry_to_range_info(struct slapi_entry *entry,
     }
     range->secondary_base_rid = ul_val;
 
+    /* slapi_entry_attr_find return 0 if requested attribute is present in entry */
+    range->base_rid_set = (slapi_entry_attr_find(entry, IPA_BASE_RID, &attr) == 0);
+    range->secondary_base_rid_set = (slapi_entry_attr_find(entry, IPA_SECONDARY_BASE_RID, &attr) == 0);
+
     *_range = range;
     ret = 0;
 
 done:
     if (ret != 0) {
-        free(range);
+        free_range_info(range);
     }
 
     return ret;
@@ -161,65 +387,79 @@ static bool intervals_overlap(uint32_t x, uint32_t base, uint32_t x_size, uint32
  *                   |     |  /  \ |
  * new range:       base  rid  sec_rid
  **/
-static int ranges_overlap(struct range_info *r1, struct range_info *r2)
+static range_check_result_t check_ranges(struct range_info *r1, struct range_info *r2)
 {
+    /* Do not check overlaps of range with the range itself */
     if (r1->name != NULL && r2->name != NULL &&
         strcasecmp(r1->name, r2->name) == 0) {
-        return 0;
+        return RANGE_CHECK_OK;
     }
 
-    /* check if base range overlaps with existing base range */
-    if (intervals_overlap(r1->base_id, r2->base_id,
-        r1->id_range_size, r2->id_range_size)){
-        return 1;
+    /* Check if base range overlaps with existing base range.
+     * Exception: ipa-ad-trust-posix ranges from the same forest */
+    if (!((strcasecmp(r1->id_range_type, AD_TRUST_POSIX_RANGE_TYPE) == 0) &&
+          (strcasecmp(r2->id_range_type, AD_TRUST_POSIX_RANGE_TYPE) == 0) &&
+          (r1->forest_root_id != NULL && r2->forest_root_id != NULL) &&
+          (strcasecmp(r1->forest_root_id, r2->forest_root_id) == 0))) {
+
+        if (intervals_overlap(r1->base_id, r2->base_id,
+            r1->id_range_size, r2->id_range_size)){
+            return RANGE_CHECK_BASE_OVERLAP;
+        }
+
     }
 
-    /* if both base_rid and secondary_base_rid = 0, the rid range is not set */
-    bool rid_ranges_set = (r1->base_rid != 0 || r1->secondary_base_rid != 0) &&
-                          (r2->base_rid != 0 || r2->secondary_base_rid != 0);
-
-    /**
-     * ipaNTTrustedDomainSID is not set for local ranges, use it to
-     * determine the type of the range **/
-    bool local_ranges = r1->domain_id == NULL && r2->domain_id == NULL;
-
+    /* Following checks apply for the ranges from the same domain */
     bool ranges_from_same_domain =
          (r1->domain_id == NULL && r2->domain_id == NULL) ||
          (r1->domain_id != NULL && r2->domain_id != NULL &&
           strcasecmp(r1->domain_id, r2->domain_id) == 0);
 
-    /**
-     * in case rid range is not set or ranges belong to different domains
-     * we can skip rid range tests as they are irrelevant **/
-    if (rid_ranges_set && ranges_from_same_domain){
+    if (ranges_from_same_domain) {
 
-        /* check if rid range overlaps with existing rid range */
-        if (intervals_overlap(r1->base_rid, r2->base_rid,
-            r1->id_range_size, r2->id_range_size))
-            return 2;
+        /* Ranges from the same domain must have the same type */
+        if (strcasecmp(r1->id_range_type, r2->id_range_type) != 0) {
+            return RANGE_CHECK_DIFFERENT_TYPE_IN_DOMAIN;
+        }
 
-        /**
-         * The following 3 checks are relevant only if both ranges are local.
-         * Check if secondary rid range overlaps with existing secondary rid
-         * range. **/
-        if (local_ranges){
-            if (intervals_overlap(r1->secondary_base_rid,
-                r2->secondary_base_rid, r1->id_range_size, r2->id_range_size))
-                return 3;
+        /* For ipa-local or ipa-ad-trust range types primary RID ranges should
+         * not overlap */
 
-            /* check if rid range overlaps with existing secondary rid range */
-            if (intervals_overlap(r1->base_rid, r2->secondary_base_rid,
-                r1->id_range_size, r2->id_range_size))
-                return 4;
+        if (strcasecmp(r1->id_range_type, AD_TRUST_RANGE_TYPE) == 0 ||
+            strcasecmp(r1->id_range_type, LOCAL_RANGE_TYPE) == 0) {
 
-            /* check if secondary rid range overlaps with existing rid range */
-            if (intervals_overlap(r1->secondary_base_rid, r2->base_rid,
-                r1->id_range_size, r2->id_range_size))
-                return 5;
+            /* Check if primary rid range overlaps with existing primary rid range */
+            if ((r1->base_rid_set && r2->base_rid_set) &&
+                intervals_overlap(r1->base_rid, r2->base_rid,
+                                  r1->id_range_size, r2->id_range_size))
+                return RANGE_CHECK_PRIMARY_PRIMARY_RID_OVERLAP;
+        }
+
+        /* The following 3 checks are relevant only if both ranges are local. */
+        if (strcasecmp(r1->id_range_type, LOCAL_RANGE_TYPE) == 0){
+
+            /* Check if secondary RID range overlaps with existing secondary or
+             * primary RID range. */
+            if ((r1->secondary_base_rid_set && r2->secondary_base_rid_set) &&
+                intervals_overlap(r1->secondary_base_rid, r2->secondary_base_rid,
+                                  r1->id_range_size, r2->id_range_size))
+                return RANGE_CHECK_SECONDARY_SECONDARY_RID_OVERLAP;
+
+            /* Check if RID range overlaps with existing secondary RID range */
+            if ((r1->base_rid_set && r2->secondary_base_rid_set) &&
+                intervals_overlap(r1->base_rid, r2->secondary_base_rid,
+                                  r1->id_range_size, r2->id_range_size))
+                return RANGE_CHECK_PRIMARY_SECONDARY_RID_OVERLAP;
+
+            /* Check if secondary RID range overlaps with existing RID range */
+            if ((r1->secondary_base_rid_set && r2->base_rid_set) &&
+                intervals_overlap(r1->secondary_base_rid, r2->base_rid,
+                                  r1->id_range_size, r2->id_range_size))
+                return RANGE_CHECK_SECONDARY_PRIMARY_RID_OVERLAP;
             }
     }
 
-    return 0;
+    return RANGE_CHECK_OK;
 }
 
 static int ipa_range_check_start(Slapi_PBlock *pb)
@@ -229,6 +469,15 @@ static int ipa_range_check_start(Slapi_PBlock *pb)
 
 static int ipa_range_check_close(Slapi_PBlock *pb)
 {
+    int ret;
+    struct ipa_range_check_ctx *ctx;
+
+    ret = slapi_pblock_get(pb, SLAPI_PLUGIN_PRIVATE, &ctx);
+    if (ret == 0 && ctx != NULL) {
+        slapi_ch_free_string(&ctx->base_dn);
+        free(ctx);
+    }
+
     return 0;
 }
 
@@ -248,9 +497,10 @@ static int ipa_range_check_pre_op(Slapi_PBlock *pb, int modtype)
     int search_result;
     Slapi_Entry **search_entries = NULL;
     size_t c;
-    int no_overlap = 0;
+    int ranges_valid = 0;
     const char *check_attr;
     char *errmsg = NULL;
+    struct domain_info *domain_info_head = NULL;
 
     ret = slapi_pblock_get(pb, SLAPI_IS_REPLICATED_OPERATION, &is_repl_op);
     if (ret != 0) {
@@ -304,8 +554,9 @@ static int ipa_range_check_pre_op(Slapi_PBlock *pb, int modtype)
             ret = slapi_search_internal_get_entry(dn, NULL, &entry,
                                                   ctx->plugin_id);
             if (ret != 0 || entry == NULL) {
-                LOG_FATAL("Missing entry to modify.\n");
-                ret = LDAP_NO_SUCH_OBJECT;
+                LOG("Missing entry to modify.\n");
+                /* No range object, nothing to do. */
+                ret = 0;
                 goto done;
             }
             free_entry = true;
@@ -337,7 +588,14 @@ static int ipa_range_check_pre_op(Slapi_PBlock *pb, int modtype)
             goto done;
     }
 
-    ret = slapi_entry_to_range_info(entry, &new_range);
+    /* build a linked list of domain_info structs */
+    ret = build_domain_to_forest_root_map(&domain_info_head, ctx);
+    if (ret != 0) {
+        LOG_FATAL("Building of domain forest root domain map failed.\n");
+        goto done;
+    }
+
+    ret = slapi_entry_to_range_info(domain_info_head, entry, &new_range);
     if (ret != 0) {
         LOG_FATAL("Failed to convert LDAP entry to range struct.\n");
         goto done;
@@ -381,34 +639,38 @@ static int ipa_range_check_pre_op(Slapi_PBlock *pb, int modtype)
     }
 
     for (c = 0; search_entries[c] != NULL; c++) {
-        ret = slapi_entry_to_range_info(search_entries[c], &old_range);
+        ret = slapi_entry_to_range_info(domain_info_head, search_entries[c],
+                                        &old_range);
         if (ret != 0) {
             LOG_FATAL("Failed to convert LDAP entry to range struct.\n");
             goto done;
         }
 
-        no_overlap = ranges_overlap(new_range, old_range);
-        free(old_range);
+        ranges_valid = check_ranges(new_range, old_range);
+        free_range_info(old_range);
         old_range = NULL;
-        if (no_overlap != 0) {
+        if (ranges_valid != RANGE_CHECK_OK) {
             ret = LDAP_CONSTRAINT_VIOLATION;
 
-            switch (no_overlap){
-            case 1:
+            switch (ranges_valid){
+            case RANGE_CHECK_BASE_OVERLAP:
                 errmsg = "New base range overlaps with existing base range.";
                 break;
-            case 2:
+            case RANGE_CHECK_PRIMARY_PRIMARY_RID_OVERLAP:
                 errmsg = "New primary rid range overlaps with existing primary rid range.";
                 break;
-            case 3:
+            case RANGE_CHECK_SECONDARY_SECONDARY_RID_OVERLAP:
                 errmsg = "New secondary rid range overlaps with existing secondary rid range.";
                 break;
-            case 4:
+            case RANGE_CHECK_PRIMARY_SECONDARY_RID_OVERLAP:
                 errmsg = "New primary rid range overlaps with existing secondary rid range.";
                 break;
-            case 5:
+            case RANGE_CHECK_SECONDARY_PRIMARY_RID_OVERLAP:
                 errmsg = "New secondary rid range overlaps with existing primary rid range.";
                 break;
+            case RANGE_CHECK_DIFFERENT_TYPE_IN_DOMAIN:
+                errmsg = "New ID range has invalid type. All ranges in the same domain must be of the same type.";
+                break;
             default:
                 errmsg = "New range overlaps with existing one.";
                 break;
@@ -426,12 +688,20 @@ done:
     slapi_free_search_results_internal(search_pb);
     slapi_pblock_destroy(search_pb);
     slapi_sdn_free(&dn);
-    free(old_range);
-    free(new_range);
+    free_range_info(old_range);
+    free_range_info(new_range);
     if (free_entry) {
         slapi_entry_free(entry);
     }
 
+    /* Remove the domain info linked list from memory */
+    struct domain_info *next;
+    while(domain_info_head) {
+        next = domain_info_head->next;
+        free_domain_info(domain_info_head);
+        domain_info_head = next;
+    }
+
     if (ret != 0) {
         if (errmsg == NULL) {
             errmsg = "Range Check error";
@@ -491,7 +761,10 @@ static int ipa_range_check_init_ctx(Slapi_PBlock *pb,
 
 done:
     if (ret != 0) {
-        free(ctx);
+        if (ctx) {
+            slapi_ch_free_string(&ctx->base_dn);
+            free(ctx);
+        }
     } else {
         *_ctx = ctx;
     }
@@ -526,6 +799,8 @@ int ipa_range_check_init(Slapi_PBlock *pb)
                          (void *) ipa_range_check_add_pre_op) != 0 ||
         slapi_pblock_set(pb, SLAPI_PLUGIN_PRIVATE, rc_ctx) != 0) {
         LOG_FATAL("failed to register plugin\n");
+        slapi_ch_free_string(&rc_ctx->base_dn);
+        free(rc_ctx);
         ret = EFAIL;
     }
 
