@@ -28,8 +28,10 @@ import {
 } from "src/services/rpcSudoRules";
 // Utils
 import { containsAny } from "src/utils/utils";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 import TitleLayout from "../layouts/TitleLayout";
 import { FetchBaseQueryError } from "@reduxjs/toolkit/query";
 import { SerializedError } from "@reduxjs/toolkit";
@@ -52,6 +54,7 @@ interface PropsToRunCommands {
 }
 
 const RunCommands = (props: PropsToRunCommands) => {
+  const dispatch = useAppDispatch();
   const [activeAllowTabKey, setActiveAllowTabKey] = React.useState<
     string | number
   >(0);
@@ -73,9 +76,6 @@ const RunCommands = (props: PropsToRunCommands) => {
     setActiveDenyTabKey(tabIndex);
   };
 
-  // Alerts to show in the UI
-  const alerts = useAlerts();
-
   // API calls
   const [addAllowCommand] = useAddAllowCommandToSudoRuleMutation();
   const [removeAllowCommand] = useRemoveAllowCommandFromSudoRuleMutation();
@@ -137,7 +137,13 @@ const RunCommands = (props: PropsToRunCommands) => {
       results.forEach((result) => {
         // Check if any errors
         if (result.error !== null) {
-          alerts.addAlert(id + "-error", "Error: " + result.error, "danger");
+          dispatch(
+            addAlert({
+              name: id + "-error",
+              title: "Error: " + result.error,
+              variant: "danger",
+            })
+          );
         } else {
           // Infer the type of the result
           // Some values can be undefined after addition
@@ -154,10 +160,12 @@ const RunCommands = (props: PropsToRunCommands) => {
 
           if (containsAny(cmdsFromResponse, commandList)) {
             // Set alert: success
-            alerts.addAlert(
-              id + "-success",
-              "Added new item(s) to '" + props.rule.cn + "'",
-              "success"
+            dispatch(
+              addAlert({
+                name: id + "-success",
+                title: "Added new item(s) to '" + props.rule.cn + "'",
+                variant: "success",
+              })
             );
             // Refresh page
             props.onRefresh();
@@ -166,10 +174,13 @@ const RunCommands = (props: PropsToRunCommands) => {
       });
     } else {
       // Assume error
-      alerts.addAlert(
-        id + "-error",
-        "Error: " + (response.error ? response.error : "Unknown error"),
-        "danger"
+      dispatch(
+        addAlert({
+          name: id + "-error",
+          title:
+            "Error: " + (response.error ? response.error : "Unknown error"),
+          variant: "danger",
+        })
       );
     }
     setModalSpinning(false);
@@ -211,10 +222,12 @@ const RunCommands = (props: PropsToRunCommands) => {
 
         if (!containsAny(cmdsFromResponse, cmdListToRemove)) {
           // Set alert: success
-          alerts.addAlert(
-            id + "-success",
-            "Removed item(s) from " + props.rule.cn,
-            "success"
+          dispatch(
+            addAlert({
+              name: id + "-success",
+              title: "Removed item(s) from " + props.rule.cn,
+              variant: "success",
+            })
           );
           // Refresh page
           props.onRefresh();
@@ -227,7 +240,13 @@ const RunCommands = (props: PropsToRunCommands) => {
           result.failed.memberdenycmd.sudocmd.length > 0 ||
           result.failed.memberdenycmd.sudocmdgroup.length > 0
         ) {
-          alerts.addAlert(id + "-error", "Error: " + result.error, "danger");
+          dispatch(
+            addAlert({
+              name: id + "-error",
+              title: "Error: " + result.error,
+              variant: "danger",
+            })
+          );
         }
       }
     }
@@ -283,14 +302,26 @@ const RunCommands = (props: PropsToRunCommands) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Show toast notification: success
-            alerts.addAlert("save-success", "Sudo rule modified", "success");
+            dispatch(
+              addAlert({
+                name: "save-success",
+                title: "Sudo rule modified",
+                variant: "success",
+              })
+            );
             props.onRefresh();
             // Add new users
             onAddNewAllowCommand(commandsToAdd);
           } else if (response.data?.error) {
             // Show toast notification: error
             const errorMessage = response.data.error as ErrorResult;
-            alerts.addAlert("save-error", errorMessage.message, "danger");
+            dispatch(
+              addAlert({
+                name: "save-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
+            );
           }
         }
       });
@@ -345,14 +376,26 @@ const RunCommands = (props: PropsToRunCommands) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Show toast notification: success
-            alerts.addAlert("save-success", "Sudo rule modified", "success");
+            dispatch(
+              addAlert({
+                name: "save-success",
+                title: "Sudo rule modified",
+                variant: "success",
+              })
+            );
             props.onRefresh();
             // Add new users
             onAddNewAllowCommandGroup(cmdGroupsToAdd);
           } else if (response.data?.error) {
             // Show toast notification: error
             const errorMessage = response.data.error as ErrorResult;
-            alerts.addAlert("save-error", errorMessage.message, "danger");
+            dispatch(
+              addAlert({
+                name: "save-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
+            );
           }
         }
       });
@@ -407,14 +450,26 @@ const RunCommands = (props: PropsToRunCommands) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Show toast notification: success
-            alerts.addAlert("save-success", "Sudo rule modified", "success");
+            dispatch(
+              addAlert({
+                name: "save-success",
+                title: "Sudo rule modified",
+                variant: "success",
+              })
+            );
             props.onRefresh();
             // Add new users
             onAddNewDenyCommand(commandsToAdd);
           } else if (response.data?.error) {
             // Show toast notification: error
             const errorMessage = response.data.error as ErrorResult;
-            alerts.addAlert("save-error", errorMessage.message, "danger");
+            dispatch(
+              addAlert({
+                name: "save-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
+            );
           }
         }
       });
@@ -469,14 +524,26 @@ const RunCommands = (props: PropsToRunCommands) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Show toast notification: success
-            alerts.addAlert("save-success", "Sudo rule modified", "success");
+            dispatch(
+              addAlert({
+                name: "save-success",
+                title: "Sudo rule modified",
+                variant: "success",
+              })
+            );
             props.onRefresh();
             // Add new users
             onAddNewDenyCommandGroup(cmdGroupsToAdd);
           } else if (response.data?.error) {
             // Show toast notification: error
             const errorMessage = response.data.error as ErrorResult;
-            alerts.addAlert("save-error", errorMessage.message, "danger");
+            dispatch(
+              addAlert({
+                name: "save-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
+            );
           }
         }
       });
@@ -524,7 +591,6 @@ const RunCommands = (props: PropsToRunCommands) => {
   // Render component
   return (
     <>
-      <alerts.ManagedAlerts />
       {/* Filter: toggle group */}
       {filter}
       {/* Tabs - Allow Commands */}
