@@ -16,8 +16,10 @@ import {
   MicrosoftOrAzureAddPayload,
   useIdpAddMutation,
 } from "src/services/rpcIdp";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 // Errors
 import { SerializedError } from "@reduxjs/toolkit";
 // Components
@@ -33,8 +35,7 @@ interface PropsToAddModal {
 }
 
 const AddModal = (props: PropsToAddModal) => {
-  // Alerts to show in the UI
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   // API calls
   const [addIdp] = useIdpAddMutation();
@@ -201,14 +202,22 @@ const AddModal = (props: PropsToAddModal) => {
         const error = result.data?.error as SerializedError;
 
         if (error) {
-          alerts.addAlert("add-idp-error", error.message, "danger");
+          dispatch(
+            addAlert({
+              name: "add-idp-error",
+              title: error.message,
+              variant: "danger",
+            })
+          );
         }
 
         if (data) {
-          alerts.addAlert(
-            "add-idp-success",
-            "Identity provider successfully added",
-            "success"
+          dispatch(
+            addAlert({
+              name: "add-idp-success",
+              title: "Identity provider successfully added",
+              variant: "success",
+            })
           );
           // Reset selected item
           clearAllFields();
@@ -670,7 +679,6 @@ const AddModal = (props: PropsToAddModal) => {
 
   return (
     <>
-      <alerts.ManagedAlerts />
       <ModalWithFormLayout
         dataCy="add-idp-reference-modal"
         variantType={"small"}
