@@ -4,20 +4,16 @@ import {
   Button,
   Checkbox,
   Flex,
-  HelperText,
-  HelperTextItem,
+  FlexItem,
   SelectOptionProps,
   TextInput,
-  ValidatedOptions,
 } from "@patternfly/react-core";
-// Icons
-import { HelpIcon } from "@patternfly/react-icons";
 // Layout
 import ModalWithFormLayout from "src/components/layouts/ModalWithFormLayout";
 import SecondaryButton from "src/components/layouts/SecondaryButton";
 import PasswordInput from "src/components/layouts/PasswordInput";
 // Redux
-import { useAppSelector } from "src/store/hooks";
+import { useAppDispatch, useAppSelector } from "src/store/hooks";
 // RPC
 import {
   useSimpleMutCommandMutation,
@@ -29,12 +25,14 @@ import { SerializedError } from "@reduxjs/toolkit";
 // Modals
 import ErrorModal from "src/components/modals/ErrorModal";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 // Utils
 import { NO_SELECTION_OPTION } from "src/utils/constUtils";
 // Components
 import TypeAheadSelectWithCreate from "src/components/TypeAheadSelectWithCreate";
 import InputWithValidation from "src/components/layouts/InputWithValidation";
+import { AddUserPayload, useAddUserMutation } from "src/services/rpcUsers";
+import PopoverWithIconLayout from "src/components/layouts/PopoverWithIconLayout";
 
 interface GroupId {
   cn: string;
@@ -54,8 +52,7 @@ interface PropsToAddUser {
 }
 
 const AddUser = (props: PropsToAddUser) => {
-  // Alerts to show in the UI
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   // Retrieve API version from environment data
   const apiVersion = useAppSelector(
@@ -63,7 +60,7 @@ const AddUser = (props: PropsToAddUser) => {
   ) as string;
 
   // Define 'executeCommand' to add user data to IPA server
-  const [executeUserAddCommand] = useSimpleMutCommandMutation();
+  const [addUser] = useAddUserMutation();
   // Define handler to execute when getting gids
   const [retrieveGIDs] = useSimpleMutCommandMutation();
 
@@ -77,18 +74,6 @@ const AddUser = (props: PropsToAddUser) => {
   const [newPassword, setNewPassword] = React.useState("");
   const [verifyNewPassword, setVerifyNewPassword] = React.useState("");
   const [addSpinning, setAddBtnSpinning] = React.useState<boolean>(false);
-  const [addAgainSpinning, setAddAgainBtnSpinning] =
-    React.useState<boolean>(false);
-
-  // Verify the passwords are the same when we update a password value
-  useEffect(() => {
-    verifyPasswordValidationHandler();
-  }, [newPassword, verifyNewPassword]);
-  const [verifyPasswordValidation, setVerifyPasswordValidation] = useState({
-    isError: false,
-    message: "",
-    pfError: ValidatedOptions.default,
-  });
 
   const newPasswordValueHandler = (value: string) => {
     setNewPassword(value);
@@ -107,34 +92,6 @@ const AddUser = (props: PropsToAddUser) => {
   // Valid characters: '-' symbols only
   const formatWithoutSpaces = /[`!@#$%^&*()_+=[\]{};':"\\|,.<>/?~\s]/;
 
-  // TextInput validation handlers
-  //   Returns true | false if error
-
-  const verifyPasswordValidationHandler = () => {
-    if (newPassword !== verifyNewPassword) {
-      const verifyPassVal = {
-        isError: true,
-        message: "Passwords must match",
-        pfError: ValidatedOptions.error,
-      };
-      setVerifyPasswordValidation(verifyPassVal);
-      return true; // is error
-    }
-    resetVerifyPassword();
-    return false;
-  };
-
-  // Reset validation methods (password only)
-
-  // Verify password
-  const resetVerifyPassword = () => {
-    setVerifyPasswordValidation({
-      isError: false,
-      message: "",
-      pfError: ValidatedOptions.default,
-    });
-  };
-
   // [API call] Get GIDs
   const getGIDs = () => {
     // Prepare the command data
@@ -198,19 +155,12 @@ const AddUser = (props: PropsToAddUser) => {
     (newPassword.length === 0 && verifyNewPassword.length === 0);
 
   // Buttons are disabled until the user fills the required fields
-  const [buttonDisabled, setButtonDisabled] = useState(true);
-  useEffect(() => {
-    if (
-      firstName.length > 0 &&
-      lastName.length > 0 &&
-      verifiedPasswords &&
-      validateFields()
-    ) {
-      setButtonDisabled(false);
-    } else {
-      setButtonDisabled(true);
-    }
-  }, [userLogin, firstName, lastName, newPassword, verifyNewPassword]);
+  const buttonDisabled = !(
+    firstName.length > 0 &&
+    lastName.length > 0 &&
+    verifiedPasswords &&
+    (isNoPrivateGroupChecked === true ? gidSelected !== "" : true)
+  );
 
   // If modal is shown, load GID data to show in the selector (only once)
   useEffect(() => {
@@ -311,24 +261,32 @@ const AddUser = (props: PropsToAddUser) => {
           onChange={(_event, value: string) => setUserClass(value)}
         />
       ),
-      labelIcon:
-        props.from !== "stage-users" ? (
-          <HelpIcon className="pf-v6-u-ml-xs" />
-        ) : (
-          <div />
-        ),
     },
     {
       id: "no-private-group",
       pfComponent: (
-        <Flex>
-          <Checkbox
-            data-cy="modal-checkbox-no-private-group"
-            label="No private group"
-            id="no-private-group"
-            isChecked={isNoPrivateGroupChecked}
-          />
-          <HelpIcon />
+        <Flex
+          direction={{ default: "row" }}
+          alignItems={{ default: "alignItemsCenter" }}
+        >
+          <FlexItem>
+            <Checkbox
+              data-cy="modal-checkbox-no-private-group"
+              label="No private group"
+              id="no-private-group"
+              isChecked={isNoPrivateGroupChecked}
+              onChange={(_event, checked: boolean) =>
+                setIsNoPrivateGroupChecked(checked)
+              }
+            />
+          </FlexItem>
+          <FlexItem>
+            <PopoverWithIconLayout
+              message={
+                "A GID must be specified when 'No private group' is selected"
+              }
+            />
+          </FlexItem>
         </Flex>
       ),
     },
@@ -344,6 +302,7 @@ const AddUser = (props: PropsToAddUser) => {
           onSelectedChange={setGidSelected}
         />
       ),
+      fieldRequired: isNoPrivateGroupChecked,
     },
     {
       id: "modal-form-new-password",
@@ -354,7 +313,6 @@ const AddUser = (props: PropsToAddUser) => {
           id="modal-form-new-password"
           name="modal-form-new-password"
           value={newPassword}
-          onFocus={resetVerifyPassword}
           onChange={newPasswordValueHandler}
           onRevealHandler={setPasswordHidden}
           passwordHidden={passwordHidden}
@@ -371,20 +329,17 @@ const AddUser = (props: PropsToAddUser) => {
             id="modal-form-verify-password"
             name="modal-form-verify-password"
             value={verifyNewPassword}
-            onFocus={resetVerifyPassword}
             onChange={verifyNewPasswordValueHandler}
             onRevealHandler={setVerifyPasswordHidden}
             passwordHidden={verifyPasswordHidden}
-            validated={verifyPasswordValidation.pfError}
+            rules={[
+              {
+                id: "verify-match",
+                message: "Passwords must match",
+                validate: (v: string) => v === newPassword,
+              },
+            ]}
           />
-          {verifyPasswordValidation.isError &&
-            verifyPasswordValidation.message !== "" && (
-              <HelperText>
-                <HelperTextItem variant="error">
-                  {verifyPasswordValidation.message}
-                </HelperTextItem>
-              </HelperText>
-            )}
         </>
       ),
     },
@@ -398,100 +353,74 @@ const AddUser = (props: PropsToAddUser) => {
     fields = new_fields;
   }
 
-  // Helper method to reset validation values
-  const resetValidations = () => {
-    resetVerifyPassword();
-  };
-
-  // List of field validations
-  const validateFields = () => {
-    resetValidations();
-    const verifyPasswordError = verifyPasswordValidationHandler();
-    return !verifyPasswordError;
-  };
-
-  // Define status flags to determine user added successfully or error
-  let isAdditionSuccess = true;
-
-  // Track which button has been clicked ('onAddUser' or 'onAddAndAddAnother')
+  // Track which button has been clicked ('onAddUser')
   //  to better handle the 'retry' function and its behavior
   let onAddUserClicked = true;
 
-  // Add user data
-  const addUserData = async () => {
-    // If 'userLogin' is not provided, use empty array
-    const usLogin = userLogin !== "" ? [userLogin] : [];
-    const newUserData = {
-      givenname: firstName,
-      sn: lastName,
-      userclass: userClass !== "" ? userClass : undefined,
-      userpassword: newPassword,
-      version: apiVersion,
-    };
-
-    // Define payload data
-    let method = "user_add";
-    if (props.from === "stage-users") {
-      method = "stageuser_add";
-    } else {
-      // Non-stage users use noprivate
-      newUserData["noprivate"] = isNoPrivateGroupChecked;
-      // Add gidNumber for non-stage users
-      newUserData["gidnumber"] = gidSelected;
-    }
-    // Prepare the command data
-    const newUserCommandData = [usLogin, newUserData];
-
-    const newUserPayload: Command = {
-      method: method,
-      params: newUserCommandData,
-    };
-
-    // Add user via API call
-    await executeUserAddCommand(newUserPayload).then((user) => {
-      if ("data" in user) {
-        const data = user.data as FindRPCResponse;
-        const result = data.result;
-        const error = data.error as FetchBaseQueryError | SerializedError;
-
-        if (result) {
-          // Set status flag: success
-          isAdditionSuccess = true;
-          // Refresh data
-          if (props.onRefresh !== undefined) {
-            props.onRefresh();
-          }
-
-          // Set alert: success
-          alerts.addAlert("add-user-success", "New user added", "success");
-        } else if (error) {
-          // Set status flag: error
-          isAdditionSuccess = false;
-          // Handle error
-          handleAPIError(error);
-        }
-      }
-      setAddBtnSpinning(false);
-      setAddAgainBtnSpinning(false);
-    });
-  };
-
   const onAddUser = () => {
     onAddUserClicked = true;
-    const validation = validateFields();
-    if (validation) {
+
+    // Prepare payload
+    const newUserPayload: AddUserPayload = {
+      type: props.from === "stage-users" ? "stageuser" : "user",
+      givenname: firstName,
+      sn: lastName,
+    };
+
+    if (userLogin !== "") {
+      newUserPayload.uid = userLogin;
+    }
+
+    if (userClass !== "") {
+      newUserPayload.userclass = userClass;
+    }
+
+    if (isNoPrivateGroupChecked === true) {
+      newUserPayload.noprivate = true;
+    }
+
+    if (gidSelected !== "") {
+      newUserPayload.gidnumber = gidSelected;
+    }
+
+    if (newPassword !== "") {
+      newUserPayload.userpassword = newPassword;
+    }
+
+    if (verifiedPasswords) {
       setAddBtnSpinning(true);
-      addUserData().then(() => {
-        if (!isAdditionSuccess) {
-          // Close the modal without cleaning fields
-          if (props.onCloseAddModal !== undefined) {
-            props.onCloseAddModal();
+
+      addUser(newUserPayload)
+        .then((user) => {
+          if ("data" in user) {
+            const data = user.data as FindRPCResponse;
+            const result = data.result;
+            const error = data.error as FetchBaseQueryError | SerializedError;
+
+            if (result) {
+              // Refresh data
+              if (props.onRefresh !== undefined) {
+                props.onRefresh();
+              }
+
+              // Set alert: success
+              dispatch(
+                addAlert({
+                  name: "add-user-success",
+                  title: "New user added",
+                  variant: "success",
+                })
+              );
+              cleanAndCloseModal();
+            } else if (error) {
+              // Handle error
+              handleAPIError(error);
+            }
           }
-        } else {
-          // Clean data and close modal
-          cleanAndCloseModal();
-        }
-      });
+        })
+        .finally(() => {
+          setAddBtnSpinning(false);
+        });
     }
   };
 
@@ -510,32 +439,11 @@ const AddUser = (props: PropsToAddUser) => {
   // Clean fields and close modal (To prevent data persistence when reopen modal)
   const cleanAndCloseModal = () => {
     cleanAllFields();
-    resetValidations();
     if (props.onCloseAddModal !== undefined) {
       props.onCloseAddModal();
     }
   };
 
-  const onAddAndAddAnother = () => {
-    onAddUserClicked = false;
-    const validation = validateFields();
-    if (validation) {
-      setAddAgainBtnSpinning(true);
-      addUserData().then(() => {
-        if (isAdditionSuccess) {
-          // Do not close the modal, but clean fields & reset validations
-          cleanAllFields();
-          resetValidations();
-        } else {
-          // Close the modal without cleaning fields
-          if (props.onCloseAddModal !== undefined) {
-            props.onCloseAddModal();
-          }
-        }
-      });
-    }
-  };
-
   // Handle API error data
   const [isModalErrorOpen, setIsModalErrorOpen] = useState(false);
   const [errorTitle, setErrorTitle] = useState("");
@@ -567,8 +475,6 @@ const AddUser = (props: PropsToAddUser) => {
     // Repeats the same previous operation
     if (onAddUserClicked) {
       onAddUser();
-    } else {
-      onAddAndAddAnother();
     }
   };
 
@@ -606,7 +512,7 @@ const AddUser = (props: PropsToAddUser) => {
       data-cy="modal-button-add"
       key="add-new-user"
       variant="secondary"
-      isDisabled={buttonDisabled || addAgainSpinning || addSpinning}
+      isDisabled={buttonDisabled || addSpinning}
       type="submit"
       form="users-add-user-modal"
       spinnerAriaValueText="Adding"
@@ -615,18 +521,6 @@ const AddUser = (props: PropsToAddUser) => {
     >
       {addSpinning ? "Adding" : "Add"}
     </Button>,
-    <Button
-      data-cy="modal-button-add-and-add-another"
-      key="add-and-add-another-user"
-      variant="secondary"
-      isDisabled={buttonDisabled || addAgainSpinning || addSpinning}
-      onClick={onAddAndAddAnother}
-      spinnerAriaValueText="Adding again"
-      spinnerAriaLabel="Adding again"
-      isLoading={addAgainSpinning}
-    >
-      {addAgainSpinning ? "Adding" : "Add and add another"}
-    </Button>,
     <Button
       data-cy="modal-button-cancel"
       key="cancel-new-user"
@@ -640,7 +534,6 @@ const AddUser = (props: PropsToAddUser) => {
   // Render 'AddUser'
   return (
     <>
-      <alerts.ManagedAlerts />
       <ModalWithFormLayout
         dataCy="add-user-modal"
         variantType="small"
