@@ -14,12 +14,12 @@ import {
 // Data types
 import { CertificateMapping } from "src/utils/datatypes/globalDataTypes";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 import useUpdateRoute from "src/hooks/useUpdateRoute";
 import useListPageSearchParams from "src/hooks/useListPageSearchParams";
 import useApiError from "src/hooks/useApiError";
 // Redux
-import { useAppSelector } from "src/store/hooks";
+import { useAppDispatch, useAppSelector } from "src/store/hooks";
 // RPC
 import {
   useGetCertMapRuleEntriesQuery,
@@ -49,6 +49,7 @@ import DeleteMultipleRulesModal from "src/components/modals/CertificateMapping/D
 import EnableDisableMultipleRulesModal from "src/components/modals/CertificateMapping/EnableDisableMultipleRules";
 
 const CertificateMappingPage = () => {
+  const dispatch = useAppDispatch();
   const navigate = useNavigate();
 
   // Update current route data to Redux and highlight the current page in the Nav bar
@@ -66,9 +67,6 @@ const CertificateMappingPage = () => {
     (state) => state.global.environment.api_version
   ) as string;
 
-  // Alerts to show in the UI
-  const alerts = useAlerts();
-
   // URL parameters: page number, page size, search value
   const { page, setPage, perPage, setPerPage, searchValue, setSearchValue } =
     useListPageSearchParams();
@@ -269,10 +267,12 @@ const CertificateMappingPage = () => {
           } else if ("message" in searchError) {
             error = searchError.message;
           }
-          alerts.addAlert(
-            "submit-search-value-error",
-            error || "Error when searching for IdPs",
-            "danger"
+          dispatch(
+            addAlert({
+              name: "submit-search-value-error",
+              title: error || "Error when searching for IdPs",
+              variant: "danger",
+            })
           );
         } else {
           // Success
@@ -467,7 +467,6 @@ const CertificateMappingPage = () => {
   // Render component
   return (
     <div>
-      <alerts.ManagedAlerts />
       <PageSection hasBodyWrapper={false}>
         <TitleLayout
           id="Certificate Identity mapping rules page"
