@@ -16,9 +16,11 @@ import {
   DNSZone,
   Metadata,
 } from "src/utils/datatypes/globalDataTypes";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
 import useUpdateRoute from "src/hooks/useUpdateRoute";
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 // Utils
 import { dnsZoneAsRecord } from "src/utils/dnsZonesUtils";
 // Icons
@@ -59,8 +61,7 @@ interface DnsZonesSettingsProps {
 }
 
 const DnsZonesSettings = (props: DnsZonesSettingsProps) => {
-  // Alerts to show in the UI
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   // Update current route data to Redux and highlight the current page in the Nav bar
   useUpdateRoute({ pathname: props.pathname });
@@ -123,7 +124,13 @@ const DnsZonesSettings = (props: DnsZonesSettingsProps) => {
   const onRevert = () => {
     props.onDnsZoneChange(props.originalDnsZone);
     props.onRefresh();
-    alerts.addAlert("revert-success", "DNS zone data reverted", "success");
+    dispatch(
+      addAlert({
+        name: "revert-success",
+        title: "DNS zone data reverted",
+        variant: "success",
+      })
+    );
   };
 
   // Helper method to build the payload based on values
@@ -179,11 +186,23 @@ const DnsZonesSettings = (props: DnsZonesSettingsProps) => {
       if ("data" in response) {
         const data = response.data;
         if (data?.error) {
-          alerts.addAlert("error", (data.error as Error).message, "danger");
+          dispatch(
+            addAlert({
+              name: "error",
+              title: (data.error as Error).message,
+              variant: "danger",
+            })
+          );
         }
         if (data?.result) {
           props.onDnsZoneChange(data.result.result);
-          alerts.addAlert("success", "DNS zone data updated", "success");
+          dispatch(
+            addAlert({
+              name: "success",
+              title: "DNS zone data updated",
+              variant: "success",
+            })
+          );
           // Disable 'revert' and 'save' buttons
           props.onRefresh();
         }
@@ -311,7 +330,6 @@ const DnsZonesSettings = (props: DnsZonesSettingsProps) => {
         toolbarItems={toolbarFields}
         dataCy="dns-zones-settings"
       >
-        <alerts.ManagedAlerts />
         <Sidebar isPanelRight>
           <SidebarPanel variant="sticky">
             <HelpTextWithIconLayout
