@@ -27,8 +27,10 @@ import HelpTextWithIconLayout from "src/components/layouts/HelpTextWithIconLayou
 import TabLayout from "src/components/layouts/TabLayout";
 // Utils
 import { asRecord } from "../../utils/hostUtils";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 import useUpdateRoute from "src/hooks/useUpdateRoute";
 // Data types
 import { HBACRule, Metadata } from "../../utils/datatypes/globalDataTypes";
@@ -55,7 +57,7 @@ interface PropsToSettings {
 }
 
 const HBACRulesSettings = (props: PropsToSettings) => {
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   // API
   const [saveRule] = useSaveAndCleanHbacRuleMutation();
@@ -145,7 +147,13 @@ const HBACRulesSettings = (props: PropsToSettings) => {
       if ("data" in response) {
         if (response.data?.result) {
           // Show toast notification: success
-          alerts.addAlert("save-success", "HBAC rule modified", "success");
+          dispatch(
+            addAlert({
+              name: "save-success",
+              title: "HBAC rule modified",
+              variant: "success",
+            })
+          );
           setHostTabKey(0);
           setUserTabKey(0);
           setSrvTabKey(0);
@@ -153,7 +161,13 @@ const HBACRulesSettings = (props: PropsToSettings) => {
         } else if (response.data?.error) {
           // Show toast notification: error
           const errorMessage = response.data.error as ErrorResult;
-          alerts.addAlert("save-error", errorMessage.message, "danger");
+          dispatch(
+            addAlert({
+              name: "save-error",
+              title: errorMessage.message,
+              variant: "danger",
+            })
+          );
           // Reset values. Disable 'revert' and 'save' buttons
           props.onResetValues();
         }
@@ -165,7 +179,13 @@ const HBACRulesSettings = (props: PropsToSettings) => {
   // 'Revert' handler method
   const onRevert = () => {
     props.onRuleChange(props.originalRule);
-    alerts.addAlert("revert-success", "HBAC rule data reverted", "success");
+    dispatch(
+      addAlert({
+        name: "revert-success",
+        title: "HBAC rule data reverted",
+        variant: "success",
+      })
+    );
   };
 
   // Toolbar
@@ -224,7 +244,6 @@ const HBACRulesSettings = (props: PropsToSettings) => {
   // Render component
   return (
     <TabLayout id="settings-page" toolbarItems={toolbarFields}>
-      <alerts.ManagedAlerts />
       <Sidebar isPanelRight>
         <SidebarPanel variant="sticky">
           <HelpTextWithIconLayout
