@@ -15,8 +15,10 @@ import SettingsTableLayout from "src/components/layouts/SettingsTableLayout";
 // Modals
 import DualListLayout from "src/components/layouts/DualListLayout";
 import RemoveNetgroupMembersModal from "src/components/modals/RemoveNetgroupMembers";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
-import useAlerts from "../../hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 // React Router DOM
 import { Link } from "react-router";
 import { Netgroup } from "../../utils/datatypes/globalDataTypes";
@@ -40,8 +42,7 @@ interface PropsToTable {
 }
 
 const NetgroupsMemberTable = (props: PropsToTable) => {
-  // Alerts to show in the UI
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   const [saveNetgroup] = useSaveNetgroupMutation();
   const [addMemberToNetgroups] = useAddMemberToNetgroupsMutation();
@@ -169,19 +170,23 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
                 if (modResponse.data?.error) {
                   const errorMessage = modResponse.data
                     .error as unknown as ErrorResult;
-                  alerts.addAlert(
-                    "update-netgroup-error",
-                    errorMessage.message,
-                    "danger"
+                  dispatch(
+                    addAlert({
+                      name: "update-netgroup-error",
+                      title: errorMessage.message,
+                      variant: "danger",
+                    })
                   );
                   setAddSpinning(false);
                   return;
                 } else {
                   // Set alert: success
-                  alerts.addAlert(
-                    "update-success",
-                    "Added " + props.from + " to netgroup",
-                    "success"
+                  dispatch(
+                    addAlert({
+                      name: "update-success",
+                      title: "Added " + props.from + " to netgroup",
+                      variant: "success",
+                    })
                   );
                   props.onRefresh();
                   setAddSpinning(false);
@@ -193,10 +198,12 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
             });
           } else {
             // Set alert: success
-            alerts.addAlert(
-              "add-member-success",
-              "Added " + props.from + " to netgroup",
-              "success"
+            dispatch(
+              addAlert({
+                name: "add-member-success",
+                title: "Added " + props.from + " to netgroup",
+                variant: "success",
+              })
             );
             props.onRefresh();
             setAddSpinning(false);
@@ -207,7 +214,13 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
         } else if (response.data?.error) {
           // Set alert: error
           const errorMessage = response.data.error as unknown as ErrorResult;
-          alerts.addAlert("add-member-error", errorMessage.message, "danger");
+          dispatch(
+            addAlert({
+              name: "add-member-error",
+              title: errorMessage.message,
+              variant: "danger",
+            })
+          );
           setAddSpinning(false);
         }
       }
@@ -225,10 +238,12 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Set alert: success
-            alerts.addAlert(
-              "remove-netgroups-success",
-              "Removed " + props.from + " from netgroup " + props.id,
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-netgroups-success",
+                title: "Removed " + props.from + " from netgroup " + props.id,
+                variant: "success",
+              })
             );
             // Update displayed netgroups
             const newNembers = members.filter(
@@ -245,10 +260,12 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
           } else if (response.data?.error) {
             // Set alert: error
             const errorMessage = response.data.error as unknown as ErrorResult;
-            alerts.addAlert(
-              "remove-netgroups-error",
-              errorMessage.message,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "remove-netgroups-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
             );
           }
         }
@@ -438,7 +455,6 @@ const NetgroupsMemberTable = (props: PropsToTable) => {
 
   return (
     <div className="pf-v6-u-mr-md pf-v6-u-ml-xl">
-      <alerts.ManagedAlerts />
       <SettingsTableLayout
         ariaLabel={props.from + " table in netgroups"}
         variant="compact"
