@@ -16,7 +16,7 @@ import {
 import { SudoRule } from "src/utils/datatypes/globalDataTypes";
 import { ToolbarItem } from "src/components/layouts/ToolbarLayout";
 // Redux
-import { useAppSelector } from "src/store/hooks";
+import { useAppSelector, useAppDispatch } from "src/store/hooks";
 // Layouts
 import TitleLayout from "src/components/layouts/TitleLayout";
 import HelpTextWithIconLayout from "src/components/layouts/HelpTextWithIconLayout";
@@ -33,7 +33,7 @@ import AddSudoRule from "src/components/modals/SudoModals/AddSudoRule";
 import DeleteSudoRule from "src/components/modals/SudoModals/DeleteSudoRule";
 import DisableEnableSudoRules from "src/components/modals/SudoModals/DisableEnableSudoRules";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 import useUpdateRoute from "src/hooks/useUpdateRoute";
 import useListPageSearchParams from "src/hooks/useListPageSearchParams";
 // Utils
@@ -49,6 +49,8 @@ import GlobalErrors from "src/components/errors/GlobalErrors";
 import ModalErrors from "src/components/errors/ModalErrors";
 
 const SudoRules = () => {
+  const dispatch = useAppDispatch();
+
   // Update current route data to Redux and highlight the current page in the Nav bar
   const { browserTitle } = useUpdateRoute({ pathname: "sudo-rules" });
 
@@ -69,9 +71,6 @@ const SudoRules = () => {
 
   const [rulesList, setRulesList] = useState<SudoRule[]>([]);
 
-  // Alerts to show in the UI
-  const alerts = useAlerts();
-
   // Handle API calls errors
   const globalErrors = useApiError([]);
   const modalErrors = useApiError([]);
@@ -259,10 +258,12 @@ const SudoRules = () => {
           } else if ("message" in searchError) {
             error = searchError.message;
           }
-          alerts.addAlert(
-            "submit-search-value-error",
-            error || "Error when searching for sudo rules",
-            "danger"
+          dispatch(
+            addAlert({
+              name: "submit-search-value-error",
+              title: error || "Error when searching for sudo rules",
+              variant: "danger",
+            })
           );
         } else {
           // Success
@@ -576,7 +577,6 @@ const SudoRules = () => {
 
   return (
     <div>
-      <alerts.ManagedAlerts />
       <PageSection hasBodyWrapper={false}>
         <TitleLayout id="sudorules title" headingLevel="h1" text="Sudo rules" />
       </PageSection>
