@@ -3,8 +3,10 @@ import React from "react";
 import { DropdownItem, Flex } from "@patternfly/react-core";
 // Data types
 import { Metadata, SudoRule } from "src/utils/datatypes/globalDataTypes";
+// Redux
+import { useAppDispatch } from "src/store/hooks";
 // Hooks
-import useAlerts from "src/hooks/useAlerts";
+import { addAlert } from "src/store/Global/alerts-slice";
 import useUpdateRoute from "src/hooks/useUpdateRoute";
 // RPC
 import {
@@ -38,6 +40,8 @@ import { TableEntry } from "src/components/tables/KeytabTableWithFilter";
 import AccessThisHost from "./AccessThisHost";
 import RunCommands from "src/components/SudoRuleSections/RunCommands";
 import SudoRuleAsWhom from "src/components/SudoRuleSections/SudoRuleAsWhom";
+import DeleteSudoRule from "src/components/modals/SudoModals/DeleteSudoRule";
+import DisableEnableSudoRules from "src/components/modals/SudoModals/DisableEnableSudoRules";
 
 interface PropsToSudoRulesSettings {
   rule: Partial<SudoRule>;
@@ -52,7 +56,7 @@ interface PropsToSudoRulesSettings {
 }
 
 const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
-  const alerts = useAlerts();
+  const dispatch = useAppDispatch();
 
   // API calls
   const [saveService] = useSaveSudoRuleMutation();
@@ -73,27 +77,35 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
     props.onRuleChange
   );
 
+  // Computed states
+  const isRuleEnabled = React.useMemo<boolean>(
+    () => props.rule.ipaenabledflag === "true",
+    [props.rule.ipaenabledflag]
+  );
+
   // Kebab
   const [isKebabOpen, setIsKebabOpen] = React.useState(false);
 
   const dropdownItems = [
     <DropdownItem
       key="enable-sudo-rule"
-      onClick={() => onChangeEnableModal()}
+      onClick={() => setIsEnableDisableModalOpen(true)}
       data-cy="sudo-rules-tab-settings-kebab-enable"
+      isDisabled={isRuleEnabled}
     >
       Enable
     </DropdownItem>,
     <DropdownItem
       key="disable-sudo-rule"
-      onClick={() => onChangeDisableModal()}
+      onClick={() => setIsEnableDisableModalOpen(true)}
       data-cy="sudo-rules-tab-settings-kebab-disable"
+      isDisabled={!isRuleEnabled}
     >
       Disable
     </DropdownItem>,
     <DropdownItem
       key="delete-sudo-rule"
-      onClick={() => onChangeDeleteModal()}
+      onClick={() => setIsDeleteModalOpen(true)}
       data-cy="sudo-rules-tab-settings-kebab-delete"
     >
       Delete
@@ -113,17 +125,8 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
 
   // Confirmation modals
   const [isDeleteModalOpen, setIsDeleteModalOpen] = React.useState(false);
-  const [isDisableModalOpen, setIsDisableModalOpen] = React.useState(false);
-  const [isEnableModalOpen, setIsEnableModalOpen] = React.useState(false);
-  const onChangeDeleteModal = () => {
-    setIsDeleteModalOpen(!isDeleteModalOpen);
-  };
-  const onChangeDisableModal = () => {
-    setIsDisableModalOpen(!isDisableModalOpen);
-  };
-  const onChangeEnableModal = () => {
-    setIsEnableModalOpen(!isEnableModalOpen);
-  };
+  const [isEnableDisableModalOpen, setIsEnableDisableModalOpen] =
+    React.useState(false);
 
   const onSaveRule = () => {
     // Save the rule
@@ -134,12 +137,24 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
       if ("data" in response) {
         if (response.data?.result) {
           // Show toast notification: success
-          alerts.addAlert("save-success", "Sudo rule modified", "success");
+          dispatch(
+            addAlert({
+              name: "save-success",
+              title: "Sudo rule modified",
+              variant: "success",
+            })
+          );
           props.onRefresh();
         } else if (response.data?.error) {
           // Show toast notification: error
           const errorMessage = response.data.error as ErrorResult;
-          alerts.addAlert("save-error", errorMessage.message, "danger");
+          dispatch(
+            addAlert({
+              name: "save-error",
+              title: errorMessage.message,
+              variant: "danger",
+            })
+          );
           // Reset values. Disable 'revert' and 'save' buttons
           props.onResetValues();
         }
@@ -164,10 +179,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
           const usersFromResponse = results.result.memberuser_group || [];
           if (!containsAny(usersFromResponse, userGroupsToDelete)) {
             // Set alert: success
-            alerts.addAlert(
-              "remove-who-group-success",
-              "Removed item(s) from " + props.rule.cn,
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-who-group-success",
+                title: "Removed item(s) from " + props.rule.cn,
+                variant: "success",
+              })
             );
             // Refresh page
             props.onRefresh();
@@ -179,10 +196,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.error ||
             results.failed.memberuser.group.length > 0
           ) {
-            alerts.addAlert(
-              "remove-who-group-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "remove-who-group-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -208,10 +227,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.result.memberhost_hostgroup || [];
           if (!containsAny(hostGroupsFromResponse, hostGroupsToDelete)) {
             // Set alert: success
-            alerts.addAlert(
-              "remove-acces-host-hostgroup-success",
-              "Removed item(s) from " + props.rule.cn,
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-acces-host-hostgroup-success",
+                title: "Removed item(s) from " + props.rule.cn,
+                variant: "success",
+              })
             );
             // Refresh page
             props.onRefresh();
@@ -223,10 +244,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.error ||
             results.failed.memberhost.hostgroup.length > 0
           ) {
-            alerts.addAlert(
-              "remove-acces-host-hostgroup-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "remove-acces-host-hostgroup-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -257,10 +280,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             !containsAny(externalsFromResponse, usersToDelete)
           ) {
             // Set alert: success
-            alerts.addAlert(
-              "remove-who-user-external-success",
-              "Removed item(s) from " + props.rule.cn,
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-who-user-external-success",
+                title: "Removed item(s) from " + props.rule.cn,
+                variant: "success",
+              })
             );
             // Refresh page
             props.onRefresh();
@@ -269,10 +294,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
           }
           // Check if any errors
           else if (results.error || results.failed.memberuser.user.length > 0) {
-            alerts.addAlert(
-              "remove-who-user-external-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "remove-who-user-external-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -304,10 +331,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             !containsAny(externalsFromResponse, hostsToDelete)
           ) {
             // Set alert: success
-            alerts.addAlert(
-              "remove-who-user-external-success",
-              "Removed item(s) from " + props.rule.cn,
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-who-user-external-success",
+                title: "Removed item(s) from " + props.rule.cn,
+                variant: "success",
+              })
             );
             // Refresh page
             props.onRefresh();
@@ -316,10 +345,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
           }
           // Check if any errors
           else if (results.error || results.failed.memberhost.host.length > 0) {
-            alerts.addAlert(
-              "remove-who-host-external-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "remove-who-host-external-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -361,20 +392,24 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
                   ("memberdenycmd" in result.failed &&
                     result.failed.memberdenycmd.sudocmdgroup.length > 0)))
             ) {
-              alerts.addAlert(
-                "remove-run-commands-error",
-                "Error: " + result.error,
-                "danger"
+              dispatch(
+                addAlert({
+                  name: "remove-run-commands-error",
+                  title: "Error: " + result.error,
+                  variant: "danger",
+                })
               );
             }
           });
           // Set alert: success
           if (!data?.error) {
             props.onRefresh();
-            alerts.addAlert(
-              "remove-run-commands-success",
-              "Removed item(s) from '" + props.rule.cn + "' and saved",
-              "success"
+            dispatch(
+              addAlert({
+                name: "remove-run-commands-success",
+                title: "Removed item(s) from '" + props.rule.cn + "' and saved",
+                variant: "success",
+              })
             );
           }
           setSaving(false);
@@ -416,10 +451,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.error ||
             results.failed.ipasudorunas.group.length > 0
           ) {
-            alerts.addAlert(
-              "as-whom-remove-user-group-external-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "as-whom-remove-user-group-external-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -463,10 +500,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.error ||
             results.failed.ipasudorunas.user.length > 0
           ) {
-            alerts.addAlert(
-              "as-whom-remove-user-external-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "as-whom-remove-user-external-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -508,10 +547,12 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
             results.error ||
             results.failed.ipasudorunas.group.length > 0
           ) {
-            alerts.addAlert(
-              "as-whom-remove-group-external-error",
-              "Error: " + results.error,
-              "danger"
+            dispatch(
+              addAlert({
+                name: "as-whom-remove-group-external-error",
+                title: "Error: " + results.error,
+                variant: "danger",
+              })
             );
           }
         }
@@ -610,12 +651,24 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
         if ("data" in response) {
           if (response.data?.result) {
             // Show toast notification: success
-            alerts.addAlert("save-success", "Sudo rule modified", "success");
+            dispatch(
+              addAlert({
+                name: "save-success",
+                title: "Sudo rule modified",
+                variant: "success",
+              })
+            );
             props.onRefresh();
           } else if (response.data?.error) {
             // Show toast notification: error
             const errorMessage = response.data.error as ErrorResult;
-            alerts.addAlert("save-error", errorMessage.message, "danger");
+            dispatch(
+              addAlert({
+                name: "save-error",
+                title: errorMessage.message,
+                variant: "danger",
+              })
+            );
             // Reset values. Disable 'revert' and 'save' buttons
             props.onResetValues();
           }
@@ -628,7 +681,13 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
   // 'Revert' handler method
   const onRevert = () => {
     props.onRuleChange(props.originalRule);
-    alerts.addAlert("revert-success", "Sudo rule data reverted", "success");
+    dispatch(
+      addAlert({
+        name: "revert-success",
+        title: "Sudo rule data reverted",
+        variant: "success",
+      })
+    );
   };
 
   // Toolbar
@@ -683,7 +742,6 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
           idKebab="toggle-action-buttons"
           isKebabOpen={isKebabOpen}
           dropdownItems={dropdownItems}
-          isDisabled={isSaving}
         />
       ),
     },
@@ -855,111 +913,144 @@ const SudoRulesSettings = (props: PropsToSudoRulesSettings) => {
 
   // Render component
   return (
-    <TabLayout id="settings-page" toolbarItems={toolbarFields}>
-      <alerts.ManagedAlerts />
-      <SidebarLayout itemNames={itemNames}>
-        {/* General */}
-        <Flex direction={{ default: "column" }} flex={{ default: "flex_1" }}>
-          <TitleLayout headingLevel="h2" id="general" text="General" />
-          <SudoRuleGeneral
-            ipaObject={ipaObject}
-            recordOnChange={recordOnChange}
-            metadata={props.metadata}
-          />
-        </Flex>
-        {/* Options */}
-        <Flex direction={{ default: "column" }} flex={{ default: "flex_1" }}>
-          <TitleLayout headingLevel="h2" id="options" text="Options" />
-          <SudoRuleOptions
-            sudoRuleId={props.rule.cn as string}
-            options={sudoOptions}
-          />
-        </Flex>
-        {/* Who */}
-        <Flex
-          direction={{ default: "column" }}
-          flex={{ default: "flex_1" }}
-          className="pf-v6-u-mt-xl"
-        >
-          <TitleLayout headingLevel="h2" id="who" text="Who" />
-          <SudoRulesWho
-            rule={props.rule}
-            ipaObject={ipaObject}
-            onRefresh={props.onRefresh}
-            usersList={usersAndExternalsList}
-            userGroupsList={usergroupsList}
-            recordOnChange={recordOnChange}
-            metadata={props.metadata}
-            onSave={onSave}
-            modifiedValues={props.modifiedValues}
-          />
-        </Flex>
-        {/* Access this host */}
-        <Flex
-          direction={{ default: "column" }}
-          flex={{ default: "flex_1" }}
-          className="pf-v6-u-mt-xl"
-        >
-          <TitleLayout headingLevel="h2" id="who" text="Access this host" />
-          <AccessThisHost
-            rule={props.rule}
-            ipaObject={ipaObject}
-            onRefresh={props.onRefresh}
-            hostsList={hostsAndExternalsList}
-            hostGroupsList={hostgroupsList}
-            recordOnChange={recordOnChange}
-            metadata={props.metadata}
-            onSave={onSave}
-            modifiedValues={props.modifiedValues}
-          />
-        </Flex>
-        {/* Run commands */}
-        <Flex
-          direction={{ default: "column" }}
-          flex={{ default: "flex_1" }}
-          className="pf-v6-u-mt-xl"
-        >
-          <TitleLayout
-            headingLevel="h2"
-            id="run-commands"
-            text="Run commands"
-          />
-          <RunCommands
-            rule={props.rule}
-            ipaObject={ipaObject}
-            onRefresh={props.onRefresh}
-            allowCommandsList={allowCommandsList}
-            allowCommandGroupsList={allowCommandGroupsList}
-            denyCommandsList={denyCommandsList}
-            denyCommandGroupsList={denyCommandGroupsList}
-            recordOnChange={recordOnChange}
-            metadata={props.metadata}
-            onSave={onSave}
-            modifiedValues={props.modifiedValues}
-          />
-        </Flex>
-        {/* As whom */}
-        <Flex
-          direction={{ default: "column" }}
-          flex={{ default: "flex_1" }}
-          className="pf-v6-u-mt-xl"
-        >
-          <TitleLayout headingLevel="h2" id="as-whom" text="As whom" />
-          <SudoRuleAsWhom
-            rule={props.rule}
-            ipaObject={ipaObject}
-            runasuser_users={runAsUsersAndExternalsList}
-            runasuser_groups={runAsUsersGroupsAndExternalsList}
-            runasgroup_group={runAsGroupsAndExternalsList}
-            onRefresh={props.onRefresh}
-            recordOnChange={recordOnChange}
-            metadata={props.metadata}
-            onSave={onSave}
-            modifiedValues={props.modifiedValues}
-          />
-        </Flex>
-      </SidebarLayout>
-    </TabLayout>
+    <>
+      <TabLayout id="settings-page" toolbarItems={toolbarFields}>
+        <SidebarLayout itemNames={itemNames}>
+          {/* General */}
+          <Flex direction={{ default: "column" }} flex={{ default: "flex_1" }}>
+            <TitleLayout headingLevel="h2" id="general" text="General" />
+            <SudoRuleGeneral
+              ipaObject={ipaObject}
+              recordOnChange={recordOnChange}
+              metadata={props.metadata}
+            />
+          </Flex>
+          {/* Options */}
+          <Flex direction={{ default: "column" }} flex={{ default: "flex_1" }}>
+            <TitleLayout headingLevel="h2" id="options" text="Options" />
+            <SudoRuleOptions
+              sudoRuleId={props.rule.cn as string}
+              options={sudoOptions}
+            />
+          </Flex>
+          {/* Who */}
+          <Flex
+            direction={{ default: "column" }}
+            flex={{ default: "flex_1" }}
+            className="pf-v6-u-mt-xl"
+          >
+            <TitleLayout headingLevel="h2" id="who" text="Who" />
+            <SudoRulesWho
+              rule={props.rule}
+              ipaObject={ipaObject}
+              onRefresh={props.onRefresh}
+              usersList={usersAndExternalsList}
+              userGroupsList={usergroupsList}
+              recordOnChange={recordOnChange}
+              metadata={props.metadata}
+              onSave={onSave}
+              modifiedValues={props.modifiedValues}
+            />
+          </Flex>
+          {/* Access this host */}
+          <Flex
+            direction={{ default: "column" }}
+            flex={{ default: "flex_1" }}
+            className="pf-v6-u-mt-xl"
+          >
+            <TitleLayout headingLevel="h2" id="who" text="Access this host" />
+            <AccessThisHost
+              rule={props.rule}
+              ipaObject={ipaObject}
+              onRefresh={props.onRefresh}
+              hostsList={hostsAndExternalsList}
+              hostGroupsList={hostgroupsList}
+              recordOnChange={recordOnChange}
+              metadata={props.metadata}
+              onSave={onSave}
+              modifiedValues={props.modifiedValues}
+            />
+          </Flex>
+          {/* Run commands */}
+          <Flex
+            direction={{ default: "column" }}
+            flex={{ default: "flex_1" }}
+            className="pf-v6-u-mt-xl"
+          >
+            <TitleLayout
+              headingLevel="h2"
+              id="run-commands"
+              text="Run commands"
+            />
+            <RunCommands
+              rule={props.rule}
+              ipaObject={ipaObject}
+              onRefresh={props.onRefresh}
+              allowCommandsList={allowCommandsList}
+              allowCommandGroupsList={allowCommandGroupsList}
+              denyCommandsList={denyCommandsList}
+              denyCommandGroupsList={denyCommandGroupsList}
+              recordOnChange={recordOnChange}
+              metadata={props.metadata}
+              onSave={onSave}
+              modifiedValues={props.modifiedValues}
+            />
+          </Flex>
+          {/* As whom */}
+          <Flex
+            direction={{ default: "column" }}
+            flex={{ default: "flex_1" }}
+            className="pf-v6-u-mt-xl"
+          >
+            <TitleLayout headingLevel="h2" id="as-whom" text="As whom" />
+            <SudoRuleAsWhom
+              rule={props.rule}
+              ipaObject={ipaObject}
+              runasuser_users={runAsUsersAndExternalsList}
+              runasuser_groups={runAsUsersGroupsAndExternalsList}
+              runasgroup_group={runAsGroupsAndExternalsList}
+              onRefresh={props.onRefresh}
+              recordOnChange={recordOnChange}
+              metadata={props.metadata}
+              onSave={onSave}
+              modifiedValues={props.modifiedValues}
+            />
+          </Flex>
+        </SidebarLayout>
+      </TabLayout>
+      <DeleteSudoRule
+        show={isDeleteModalOpen}
+        handleModalToggle={() => setIsDeleteModalOpen(!isDeleteModalOpen)}
+        selectedRulesData={{
+          selectedRules: [props.rule as SudoRule],
+          clearSelectedRules: () => {},
+        }}
+        buttonsData={{
+          updateIsDeleteButtonDisabled: () => {},
+          updateIsDeletion: () => {},
+        }}
+        onRefresh={props.onRefresh}
+        from="settings"
+      />
+      <DisableEnableSudoRules
+        show={isEnableDisableModalOpen}
+        handleModalToggle={() =>
+          setIsEnableDisableModalOpen(!isEnableDisableModalOpen)
+        }
+        optionSelected={isRuleEnabled}
+        selectedRulesData={{
+          selectedRules: [props.rule as SudoRule],
+          clearSelectedRules: () => {},
+        }}
+        buttonsData={{
+          updateIsEnableButtonDisabled: () => {},
+          updateIsDisableButtonDisabled: () => {},
+          updateIsDisableEnableOp: () => {},
+        }}
+        onRefresh={props.onRefresh}
+        singleRule={true}
+      />
+    </>
   );
 };
 
