@@ -100,12 +100,12 @@ export const checkEqualStatusHbacRule = (
 
 /**
  * Helper method: Given a Sudo rule list and status, check if some entry has different status
- * @param {boolean} status - The status to check against
+ * @param {string} status - The status to check against
  * @param {SudoRule[]} rulesList - Array of Sudo rules to check
  * @returns {boolean} - True if all rules have the same status, false otherwise
  */
 export const checkEqualStatusSudoRule = (
-  status: boolean,
+  status: string,
   rulesList: SudoRule[]
 ) => {
   const rulesWithOtherStatus = rulesList.filter(
@@ -504,8 +504,7 @@ export const parseAPIDatetime = (param: any) => {
  * Validate IP address (IPv4 or IPv6)
  */
 export const isValidIpAddress = (ipAddress: string) => {
-  const regexIPv4 =
-    /^(?=(?:[^.]*\.){2,3}[^.]*$)(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(?:\.(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)){1,3}(?:\.\*)?$/;
+  const regexIPv4 = /^(((?!25?[6-9])[12]\d|[1-9])?\d\.?\b){4}$/;
   const regexIPv6 =
     /(?:^|(?<=\s))(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))(?=\s|$)/;
 
