@@ -20,7 +20,6 @@
 
 define([
         'dojo/_base/declare',
-        'dojo/_base/lang',
         'dojo/_base/array',
         'dojo/Deferred',
         'dojo/on',
@@ -32,15 +31,19 @@ define([
         './widgets/App',
         './widgets/FacetContainer',
         './ipa',
+        './rpc',
         './reg',
+        './config',
+        './widget',
         './navigation/Menu',
         './navigation/Router',
         './navigation/routing',
         './navigation/menu_spec',
         './plugins/load_page'
        ],
-       function(declare, lang, array, Deferred, on, topic, query, dom_class, auth,
-            JSON, App_widget, FacetContainer, IPA, reg, Menu, Router, routing, menu_spec) {
+       function(declare, array, Deferred, on, topic, query, dom_class, auth,
+            JSON, App_widget, FacetContainer, IPA, rpc, reg, config, widget_mod,
+            Menu, Router, routing, menu_spec) {
 
     /**
      * Application controller
@@ -66,6 +69,16 @@ define([
 
         facet_changing: false,
 
+        /**
+         * Listeners for user menu items
+         */
+         on_profile_listener: null,
+         on_passwd_reset_listener: null,
+         on_logout_listener: null,
+         on_item_select_listener: null,
+         on_configuration_listerer: null,
+         on_about_listener: null,
+
         /**
          * Currently displayed facet
          *
@@ -107,18 +120,14 @@ define([
                 }
             };
 
-            on(this.app_widget.menu_widget, 'item-select', lang.hitch(this, this.on_menu_click));
-            on(this.app_widget, 'profile-click', lang.hitch(this, this.on_profile));
-            on(this.app_widget, 'logout-click', lang.hitch(this, this.on_logout));
-            on(this.app_widget, 'password-reset-click', lang.hitch(this, this.on_password_reset));
-            on(this.app_widget, 'about-click', lang.hitch(this, this.on_about));
+            this.register_user_menu_listeners();
 
-            on(this.router, 'facet-show', lang.hitch(this, this.on_facet_show));
-            on(this.router, 'facet-change', lang.hitch(this, this.on_facet_change));
-            on(this.router, 'facet-change-canceled', lang.hitch(this, this.on_facet_canceled));
-            on(this.router, 'error', lang.hitch(this, this.on_router_error));
-            topic.subscribe('phase-error', lang.hitch(this, this.on_phase_error));
-            topic.subscribe('authenticate', lang.hitch(this, this.on_authenticate));
+            on(this.router, 'facet-show', this.on_facet_show.bind(this));
+            on(this.router, 'facet-change', this.on_facet_change.bind(this));
+            on(this.router, 'facet-change-canceled', this.on_facet_canceled.bind(this));
+            on(this.router, 'error', this.on_router_error.bind(this));
+            topic.subscribe('phase-error', this.on_phase_error.bind(this));
+            topic.subscribe('authenticate', this.on_authenticate.bind(this));
 
             this.app_widget.render();
             this.app_widget.hide();
@@ -130,6 +139,31 @@ define([
             IPA.opened_dialogs.start_handling(this);
         },
 
+        register_user_menu_listeners: function() {
+            this.on_profile_listener = on(this.app_widget, 'profile-click',
+                    this.on_profile.bind(this));
+            this.on_passwd_reset_listener = on(this.app_widget,
+                    'password-reset-click', this.on_password_reset.bind(this));
+            this.on_logout_listener = on(this.app_widget, 'logout-click',
+                    this.on_logout.bind(this));
+            this.on_item_select_listener = on(this.app_widget.menu_widget,
+                    'item-select', this.on_menu_click.bind(this));
+            this.on_configuration_listerer = on(this.app_widget,
+                    'configuration-click', this.on_configuration.bind(this));
+            this.on_about_listener = on(this.app_widget,
+                    'about-click', this.on_about.bind(this));
+        },
+
+        /**
+         * Turns off one item in user dropdown menu and remove its listener.
+         * @param {string} name of the user menu item which should be disabled
+         * @param {Object} listener disable di
+         */
+        disable_user_menu_item: function(name, listener) {
+            this.app_widget.disable_user_menu_item(name);
+            listener.remove();
+        },
+
         /**
          * Gets:
          *  * metadata
@@ -146,16 +180,22 @@ define([
          */
         choose_profile: function() {
 
-            // TODO: change IPA.whoami.cn[0] to something readable
-            this.update_logged_in(true, IPA.whoami.cn[0]);
+            this.update_logged_in(true);
             var selfservice = this.is_selfservice();
 
 
             this.app_widget.menu_widget.ignore_changes = true;
 
             if (selfservice) {
-                this.menu.name = menu_spec.self_service.name;
-                this.menu.add_items(menu_spec.self_service.items);
+                if (this.is_aduser_selfservice()) {
+                    this.menu.name = menu_spec.ad_self_service.name;
+                    this.menu.add_items(menu_spec.ad_self_service.items);
+                    this.disable_user_menu_item('password_reset',
+                            this.on_passwd_reset_listener);
+                } else {
+                    this.menu.name = menu_spec.self_service.name;
+                    this.menu.add_items(menu_spec.self_service.items);
+                }
             } else {
                 this.menu.name = menu_spec.admin.name;
                 this.menu.add_items(menu_spec.admin.items);
@@ -174,7 +214,6 @@ define([
 
             IPA.update_password_expiration();
 
-
             // now we are ready for displaying a facet,
             // it can match a facet if hash is set
             this.router.startup();
@@ -199,37 +238,68 @@ define([
             IPA.logout();
         },
 
-        is_selfservice: function() {
-            var whoami = IPA.whoami;
-            var self_service = true;
-
-
+        is_admin: function(whoami) {
             if (whoami.hasOwnProperty('memberof_group') &&
                 whoami.memberof_group.indexOf('admins') !== -1) {
-                self_service = false;
+                return true;
             } else if (whoami.hasOwnProperty('memberofindirect_group')&&
                     whoami.memberofindirect_group.indexOf('admins') !== -1) {
-                self_service = false;
+                return true;
             } else if (whoami.hasOwnProperty('memberof_role') &&
                     whoami.memberof_role.length > 0) {
-                self_service = false;
+                return true;
             } else if (whoami.hasOwnProperty('memberofindirect_role') &&
                     whoami.memberofindirect_role.length > 0) {
-                self_service = false;
+                return true;
             }
+            return false;
+        },
+
+        is_selfservice: function() {
+            var whoami = IPA.whoami.data;
+            var self_service = !this.is_admin(whoami);
 
             IPA.is_selfservice = self_service; // quite ugly, needed for users
 
             return self_service;
         },
 
-        update_logged_in: function(logged_in, fullname) {
+        is_aduser_selfservice: function() {
+            var whoami = IPA.whoami.data;
+            var idoverride = IPA.whoami.metadata.object === 'idoverrideuser';
+            var self_service = idoverride && (this.is_admin(whoami) === false);
+
+            // quite ugly, needed for users and iduseroverride to hide breadcrumb
+            IPA.is_aduser_selfservice = self_service;
+
+            return self_service;
+        },
+
+        update_logged_in: function(logged_in) {
             this.app_widget.set('logged', logged_in);
+
+            var whoami = IPA.whoami;
+            var fullname = '';
+            var entity = whoami.metadata.object;
+
+            if (whoami.data.cn) {
+                fullname = whoami.data.cn[0];
+            } else if (whoami.data.displayname) {
+                fullname = whoami.data.displayname[0];
+            } else if (whoami.data.gecos) {
+                fullname = whoami.data.gecos[0];
+            } else if (whoami.data.krbprincipalname) {
+                fullname = whoami.data.krbprincipalname[0];
+            } else if (whoami.data.ipaoriginaluid) {
+                fullname = whoami.data.ipaoriginaluid[0];
+            }
+
             this.app_widget.set('fullname', fullname);
         },
 
         on_profile: function() {
-            routing.navigate(['entity', 'user', 'details', [IPA.whoami.uid[0]]]);
+            routing.navigate(['entity', IPA.whoami.metadata.object, 'details',
+                 IPA.whoami.metadata.arguments]);
         },
 
         on_logout: function(event) {
@@ -240,6 +310,50 @@ define([
             IPA.password_selfservice();
         },
 
+        on_configuration: function() {
+            var dialog = IPA.dialog({
+                title: '@i18n:customization.customization',
+                fields: [
+                    {
+                        $type: 'text',
+                        name: 'pagination_size',
+                        label: '@i18n:customization.table_pagination',
+                        required: true,
+                        validators: ['positive_integer']
+                    }
+                ]
+            });
+
+            dialog.create_button({
+                name: 'save',
+                label: '@i18n:buttons.save',
+                click: function () {
+                    if (!dialog.validate()) {
+                        widget_mod.focus_invalid(dialog);
+                        return;
+                    }
+                    var widget = dialog.get_field('pagination_size').widget;
+                    var new_value = widget.get_value()[0];
+                    config.set('table_page_size', new_value, true);
+                    topic.publish('change-pagination');
+                    dialog.close();
+                }
+            });
+
+            dialog.create_button({
+                name: 'cancel',
+                label: '@i18n:buttons.cancel',
+                click: function () {
+                    dialog.close();
+                }
+            });
+
+            dialog.open();
+
+            var size = config.get('table_page_size').toString();
+            dialog.get_field('pagination_size').set_value([size]);
+        },
+
         on_about: function() {
             var dialog = IPA.about_dialog();
             dialog.open();
@@ -257,15 +371,20 @@ define([
                 'class': 'error-details'
             }).appendTo(error_container);
 
-            details.append($('<p/>', { text: 'Web UI got in unrecoverable state during "' + error.phase + '" phase' }));
+            details.append($('<p/>', { text: 'Web UI got in unrecoverable state during "' + error.phase + '" phase.' }));
             if (error.name) window.console.error(error.name);
             if (error.results) {
-                var msg = error.results.message;
-                var stack = error.results.stack.toString();
-                window.console.error(stack);
                 details.append('<h3>Technical details:</h3>');
-                details.append($('<div/>', { text: error.results.message }));
-                details.append($('<div/>').append($('<code/>', { text: stack })));
+                var msg = error.results.message;
+                if (msg) {
+                    window.console.error(msg);
+                    details.append($('<div/>', { text: msg }));
+                }
+                if (error.results.stack) {
+                    var stack = error.results.stack.toString();
+                    window.console.error(stack);
+                    details.append($('<div/>').append($('<code/>', { text: stack })));
+                }
             }
         },
 
@@ -277,13 +396,13 @@ define([
             if (current_facet === new_facet) return;
 
             if (current_facet && !current_facet.can_leave()) {
-                var permit_clb = lang.hitch(this, function() {
+                var permit_clb = function() {
                     // Some facet's might not call reset before this call but after
                     // so they are still dirty. Calling reset prevent's opening of
                     // dirty dialog again.
                     if (current_facet.is_dirty()) current_facet.reset(); //TODO change
                     this.router.navigate_to_hash(event.hash, event.facet);
-                });
+                }.bind(this);
 
                 var dialog = current_facet.show_leave_dialog(permit_clb);
                 this.router.canceled = true;
@@ -333,7 +452,7 @@ define([
             // show facet
             if (!facet.container_node) {
                 facet.container_node = container.widget.content_node;
-                on(facet, 'facet-state-change', lang.hitch(this, this.on_facet_state_changed));
+                on(facet, 'facet-state-change', this.on_facet_state_changed.bind(this));
             }
 
             if (this.current_facet !== facet) {
@@ -423,37 +542,9 @@ define([
          * Tries to find menu item with assigned facet and navigate to it.
          */
         on_menu_click: function(menu_item) {
-            this._navigate_to_menu_item(menu_item);
-        },
-
-        _navigate_to_menu_item: function(menu_item) {
-
-            if (menu_item.entity) {
-                // entity pages
-                routing.navigate([
-                    'entity',
-                    menu_item.entity,
-                    menu_item.facet,
-                    menu_item.pkeys,
-                    menu_item.args]);
-            } else if (menu_item.facet) {
-                // concrete facets
-                routing.navigate(['generic', menu_item.facet, menu_item.args]);
-            } else {
-                // categories, select first posible child, it may be the last
-                var children = this.menu.query({parent: menu_item.name });
-                if (children.total) {
-                    var success = false;
-                    for (var i=0; i<children.total;i++) {
-                        success = this._navigate_to_menu_item(children[i]);
-                        if (success) break;
-                    }
-                } else {
-                    return false;
-                }
-            }
-
-            return true;
+            routing.navigate(
+                this.app_widget.menu_widget.get_item_path(menu_item)
+            );
         },
 
         /**
@@ -498,4 +589,4 @@ define([
     });
 
     return App;
-});
\ No newline at end of file
+});
