@@ -63,7 +63,11 @@ return {
         }
     ],
     adder_dialog: {
+        title: '@i18n:objects.automountlocation.add',
         fields: [ 'cn' ]
+    },
+    deleter_dialog: {
+        title: '@i18n:objects.automountlocation.remove'
     }
 };};
 
@@ -109,6 +113,7 @@ return {
         }
     ],
     adder_dialog: {
+        title: '@i18n:objects.automountmap.add',
         $factory: IPA.automountmap_adder_dialog,
         sections: [
             {
@@ -151,6 +156,9 @@ return {
                 ]
             }
         ]
+    },
+    deleter_dialog: {
+        title: '@i18n:objects.automountmap.remove'
     }
 };};
 
@@ -187,6 +195,7 @@ return {
         }
     ],
     adder_dialog: {
+        title: '@i18n:objects.automountkey.add',
         show_edit_page : function(entity, result){
             var key = result.automountkey[0];
             var info = result.automountinformation[0];
@@ -202,6 +211,9 @@ return {
             return false;
         },
         fields:['automountkey','automountinformation']
+    },
+    deleter_dialog: {
+        title: '@i18n:objects.automountkey.remove'
     }
 };};
 
@@ -256,19 +268,22 @@ IPA.automount_key_column = function(spec) {
         var info = record.automountinformation;
         if (info instanceof Array) info = info[0];
 
+        var pkeys = that.facet.get_pkeys();
+        pkeys.push(key);
+
+        var args = {
+            info: info,
+            key: key
+        };
+
+        var entity_hash = navigation.get_entity_hash(
+            that.entity.name, 'details', pkeys, args
+        );
+
         $('<a/>', {
-            href: '#'+key,
+            href: '#' + entity_hash,
             text: key,
             click: function() {
-
-                var pkeys = that.facet.get_pkeys();
-                pkeys.push(key);
-
-                var args = {
-                    info: info,
-                    key: key
-                };
-
                 navigation.show_entity(that.entity.name, 'details', pkeys, args);
                 return false;
             }
@@ -283,8 +298,8 @@ IPA.automountmap_adder_dialog = function(spec) {
 
     var that = IPA.entity_adder_dialog(spec);
 
-    that.create = function() {
-        that.entity_adder_dialog_create();
+    that.create_content = function() {
+        that.entity_adder_dialog_create_content();
 
         var method_widget = that.widgets.get_widget('general.method');
         var indirect_section = that.widgets.get_widget('indirect');
@@ -313,7 +328,8 @@ IPA.automountmap_adder_dialog = function(spec) {
             indirect_section.set_visible(true);
         });
 
-        direct_input.click();
+        direct_input.prop('checked', true);
+        direct_input.trigger('change');
     };
 
     that.reset = function() {
@@ -322,7 +338,8 @@ IPA.automountmap_adder_dialog = function(spec) {
         var method_widget = that.widgets.get_widget('general.method');
 
         var direct_input = $('input[value="add"]', method_widget.container);
-        direct_input.click();
+        direct_input.prop('checked', true);
+        direct_input.trigger('change');
     };
 
     return that;
@@ -335,16 +352,20 @@ IPA.automount.key_search_facet = function(spec) {
     that.get_selected_values = function() {
 
         var values = [];
+        var keys = that.table.get_selected_values();
+        var records = that.table.records;
 
-        $('input[name="description"]:checked', that.table.tbody).each(function() {
-            var value = {};
-            $('div', $(this).parent().parent()).each(function() {
-                var div = $(this);
-                var name = div.attr('name');
-                value[name] = div.text();
-            });
-            values.push(value);
-        });
+        if (keys.length === 0 || !records) return values;
+
+        for (var i=0,l=records.length; i<l; i++) {
+            var record = records[i];
+            if (keys.indexOf(record.description[0]) > -1) {
+                values.push({
+                    automountkey: record.automountkey[0],
+                    automountinformation: record.automountinformation[0]
+                });
+            }
+        }
 
         return values;
     };
@@ -367,4 +388,4 @@ exp.register = function() {
 phases.on('registration', exp.register);
 
 return exp;
-});
\ No newline at end of file
+});
