@@ -763,13 +763,13 @@ class hbacrule_find(Method):
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
+            doc=_(u'Time limit of search in seconds'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
+            doc=_(u'Maximum number of entries returned'),
         ),
         parameters.Flag(
             'all',
