@@ -137,7 +137,6 @@ class host(Object):
         parameters.Bytes(
             'usercertificate',
             required=False,
-            multivalue=True,
             label=_(u'Certificate'),
             doc=_(u'Base-64 encoded server certificate'),
         ),
@@ -349,7 +348,6 @@ class host_add(Method):
         parameters.Bytes(
             'usercertificate',
             required=False,
-            multivalue=True,
             cli_name='certificate',
             label=_(u'Certificate'),
             doc=_(u'Base-64 encoded server certificate'),
@@ -469,66 +467,6 @@ class host_add(Method):
     )
 
 
-@register()
-class host_add_cert(Method):
-    __doc__ = _("Add certificates to host entry")
-
-    takes_args = (
-        parameters.Str(
-            'fqdn',
-            cli_name='hostname',
-            label=_(u'Host name'),
-            no_convert=True,
-        ),
-    )
-    takes_options = (
-        parameters.Flag(
-            'all',
-            doc=_(u'Retrieve and print all attributes from the server. Affects command output.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'raw',
-            doc=_(u'Print entries as stored on the server. Only affects output format.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Bytes(
-            'usercertificate',
-            required=False,
-            multivalue=True,
-            cli_name='certificate',
-            label=_(u'Certificate'),
-            doc=_(u'Base-64 encoded server certificate'),
-            alwaysask=True,
-        ),
-    )
-    has_output = (
-        output.Output(
-            'summary',
-            (unicode, type(None)),
-            doc=_(u'User-friendly description of action performed'),
-        ),
-        output.Entry(
-            'result',
-        ),
-        output.PrimaryKey(
-            'value',
-            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
-        ),
-    )
-
-
 @register()
 class host_add_managedby(Method):
     __doc__ = _("Add hosts that can manage this host.")
@@ -1083,7 +1021,6 @@ class host_find(Method):
         parameters.Bytes(
             'usercertificate',
             required=False,
-            multivalue=True,
             cli_name='certificate',
             label=_(u'Certificate'),
             doc=_(u'Base-64 encoded server certificate'),
@@ -1114,13 +1051,13 @@ class host_find(Method):
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
+            doc=_(u'Time limit of search in seconds'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
+            doc=_(u'Maximum number of entries returned'),
         ),
         parameters.Flag(
             'all',
@@ -1367,7 +1304,6 @@ class host_mod(Method):
         parameters.Bytes(
             'usercertificate',
             required=False,
-            multivalue=True,
             cli_name='certificate',
             label=_(u'Certificate'),
             doc=_(u'Base-64 encoded server certificate'),
@@ -1496,66 +1432,6 @@ class host_mod(Method):
     )
 
 
-@register()
-class host_remove_cert(Method):
-    __doc__ = _("Remove certificates from host entry")
-
-    takes_args = (
-        parameters.Str(
-            'fqdn',
-            cli_name='hostname',
-            label=_(u'Host name'),
-            no_convert=True,
-        ),
-    )
-    takes_options = (
-        parameters.Flag(
-            'all',
-            doc=_(u'Retrieve and print all attributes from the server. Affects command output.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'raw',
-            doc=_(u'Print entries as stored on the server. Only affects output format.'),
-            exclude=('webui',),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Flag(
-            'no_members',
-            doc=_(u'Suppress processing of membership attributes.'),
-            exclude=('webui', 'cli'),
-            default=False,
-            autofill=True,
-        ),
-        parameters.Bytes(
-            'usercertificate',
-            required=False,
-            multivalue=True,
-            cli_name='certificate',
-            label=_(u'Certificate'),
-            doc=_(u'Base-64 encoded server certificate'),
-            alwaysask=True,
-        ),
-    )
-    has_output = (
-        output.Output(
-            'summary',
-            (unicode, type(None)),
-            doc=_(u'User-friendly description of action performed'),
-        ),
-        output.Entry(
-            'result',
-        ),
-        output.PrimaryKey(
-            'value',
-            doc=_(u"The primary_key value of the entry, e.g. 'jdoe' for a user"),
-        ),
-    )
-
-
 @register()
 class host_remove_managedby(Method):
     __doc__ = _("Remove hosts that can manage this host.")
