@@ -352,7 +352,7 @@ def request_and_wait_for_cert(
         dns=None, ca='IPA', profile=None,
         pre_command=None, post_command=None, storage='NSSDB', perms=None,
         resubmit_timeout=0, stop_tracking_on_error=False,
-        nss_user=None):
+        nss_user=None, keytype=None, keysize=None):
     """Request certificate, wait and possibly resubmit failing requests
 
     Submit a cert request to certmonger and wait until the request has
@@ -367,7 +367,8 @@ def request_and_wait_for_cert(
     """
     req_id = request_cert(
         certpath, subject, principal, nickname, passwd_fname, dns, ca,
-        profile, pre_command, post_command, storage, perms, nss_user
+        profile, pre_command, post_command, storage, perms, nss_user,
+        keytype, keysize,
     )
     # Don't wait longer than resubmit timeout if it is configured
     certmonger_timeout = api.env.certmonger_wait_timeout
@@ -421,7 +422,7 @@ def request_cert(
         certpath, subject, principal, nickname=None, passwd_fname=None,
         dns=None, ca='IPA', profile=None,
         pre_command=None, post_command=None, storage='NSSDB', perms=None,
-        nss_user=None):
+        nss_user=None, keytype=None, keysize=None):
     """
     Execute certmonger to request a server certificate.
 
@@ -462,6 +463,12 @@ def request_cert(
         request_parameters['ca-profile'] = profile
     if nss_user:
         request_parameters['nss-user'] = nss_user
+    if keysize is None:
+        keysize = 2048
+    if keytype is None:
+        keytype = "rsa"
+    request_parameters['key-type'] = keytype
+    request_parameters['key-size'] = int(keysize)
 
     certmonger_cmd_template = paths.CERTMONGER_COMMAND_TEMPLATE
     if pre_command:
@@ -477,7 +484,8 @@ def request_cert(
         request_parameters['cert-perms'] = perms[0]
         request_parameters['key-perms'] = perms[1]
 
-    result = cm.obj_if.add_request(request_parameters)
+    result = cm.obj_if.add_request(request_parameters,
+                                   timeout=api.env.certmonger_wait_timeout)
     try:
         if result[0]:
             request = _cm_dbus_object(cm.bus, cm, result[1], DBUS_CM_REQUEST_IF,
@@ -493,7 +501,7 @@ def request_cert(
 def start_tracking(
         certpath, ca='IPA', nickname=None, pin=None, pinfile=None,
         pre_command=None, post_command=None, profile=None, storage="NSSDB",
-        token_name=None, dns=None, nss_user=None):
+        token_name=None, dns=None, nss_user=None, perms=None):
     """
     Tell certmonger to track the given certificate in either a file or an NSS
     database. The certificate access can be protected by a password_file.
@@ -532,6 +540,8 @@ def start_tracking(
         List of DNS names
     :param nss_user:
         login of the private key owner
+    :params perms:
+        A tuple of (cert, key) permissions in e.g., (0644,0660)
     :returns: certificate tracking nickname.
     """
     if storage == 'FILE':
@@ -580,8 +590,16 @@ def start_tracking(
         params['DNS'] = dns
     if nss_user:
         params['nss-user'] = nss_user
+    if perms:
+        (cert, key) = perms
+        if cert:
+            params['cert-perms'] = cert
+        if cert:
+            params['key-perms'] = key
 
-    result = cm.obj_if.add_request(params)
+    logger.debug("start tracking %s", params)
+    result = cm.obj_if.add_request(params,
+                                   timeout=api.env.certmonger_wait_timeout)
     try:
         if result[0]:
             request = _cm_dbus_object(cm.bus, cm, result[1], DBUS_CM_REQUEST_IF,
