@@ -28,7 +28,6 @@ class BasePathNamespace:
     BIN_HOSTNAMECTL = "/bin/hostnamectl"
     CRYPTO_POLICY_OPENSSLCNF_FILE = None
     ECHO = "/bin/echo"
-    FIPS_MODE_SETUP = "/bin/fips-mode-setup"
     GZIP = "/bin/gzip"
     LS = "/bin/ls"
     SYSTEMCTL = "/bin/systemctl"
@@ -78,7 +77,8 @@ class BasePathNamespace:
     IPA_NSSDB_PWDFILE_TXT = "/etc/ipa/nssdb/pwdfile.txt"
     COMMON_KRB5_CONF_DIR = "/etc/krb5.conf.d/"
     KRB5_CONF = "/etc/krb5.conf"
-    KRB5_FREEIPA = COMMON_KRB5_CONF_DIR + "freeipa"
+    KRB5_FREEIPA_DEFAULTS = COMMON_KRB5_CONF_DIR + "freeipa"
+    KRB5_FREEIPA = COMMON_KRB5_CONF_DIR + "freeipa-realm"
     KRB5_FREEIPA_SERVER = COMMON_KRB5_CONF_DIR + "freeipa-server"
     KRB5_KEYTAB = "/etc/krb5.keytab"
     LDAP_CONF = "/etc/ldap.conf"
@@ -102,6 +102,9 @@ class BasePathNamespace:
     NAMED_ROOT_KEY = "/etc/named.root.key"
     NAMED_MANAGED_KEYS_DIR = "/var/named/dynamic"
     NAMED_CRYPTO_POLICY_FILE = None
+    UNBOUND_CONF_SRC = '/usr/share/ipa/client/unbound.conf.template'
+    UNBOUND_CONFIG_DIR = "/etc/unbound/conf.d/"
+    UNBOUND_CONF = "/etc/unbound/conf.d/zzz-ipa.conf"
     NSLCD_CONF = "/etc/nslcd.conf"
     NSS_LDAP_CONF = "/etc/nss_ldap.conf"
     NSSWITCH_CONF = "/etc/nsswitch.conf"
@@ -225,6 +228,8 @@ class BasePathNamespace:
     OPENSSL_DIR = "/etc/pki/tls"
     OPENSSL_CERTS_DIR = "/etc/pki/tls/certs"
     OPENSSL_PRIVATE_DIR = "/etc/pki/tls/private"
+    BIND_DNS_OVER_TLS_CRT = "/etc/pki/tls/certs/bind_dot.crt"
+    BIND_DNS_OVER_TLS_KEY = "/etc/pki/tls/private/bind_dot.key"
     PK12UTIL = "/usr/bin/pk12util"
     SOFTHSM2_UTIL = "/usr/bin/softhsm2-util"
     SSLGET = "/usr/bin/sslget"
@@ -292,13 +297,9 @@ class BasePathNamespace:
     CA_TOPOLOGY_ULDIF = "/usr/share/ipa/ca-topology.uldif"
     IPA_HTML_DIR = "/usr/share/ipa/html"
     CA_CRT = "/usr/share/ipa/html/ca.crt"
-    KRB_CON = "/usr/share/ipa/html/krb.con"
-    HTML_KRB5_INI = "/usr/share/ipa/html/krb5.ini"
-    HTML_KRBREALM_CON = "/usr/share/ipa/html/krbrealm.con"
-    NIS_ULDIF = "/usr/share/ipa/nis.uldif"
-    NIS_UPDATE_ULDIF = "/usr/share/ipa/nis-update.uldif"
     SCHEMA_COMPAT_ULDIF = "/usr/share/ipa/updates/91-schema_compat.update"
     SCHEMA_COMPAT_POST_ULDIF = "/usr/share/ipa/schema_compat_post.uldif"
+    SUBID_GENERATORS_ULDIF = "/usr/share/ipa/subid-generators.uldif"
     IPA_JS_PLUGINS_DIR = "/usr/share/ipa/ui/js/plugins"
     UPDATES_DIR = "/usr/share/ipa/updates/"
     DICT_WORDS = "/usr/share/dict/words"
@@ -347,6 +348,7 @@ class BasePathNamespace:
     KRA_CS_CFG_PATH = "/var/lib/pki/pki-tomcat/conf/kra/CS.cfg"
     KRACERT_P12 = "/root/kracert.p12"
     SAMBA_DIR = "/var/lib/samba"
+    SAMBA_LOCKDIR = "/var/lib/samba/lock"
     SSSD_DB = "/var/lib/sss/db"
     SSSD_MC_GROUP = "/var/lib/sss/mc/group"
     SSSD_MC_PASSWD = "/var/lib/sss/mc/passwd"
