@@ -53,7 +53,7 @@ wellknownservices = [
     'named', 'ods_enforcerd', 'ods_signerd', 'gssproxy',
     'nfs-utils', 'sssd', 'NetworkManager', 'ipa-custodia',
     'ipa-dnskeysyncd', 'ipa-otpd', 'ipa-ods-exporter',
-    'systemd-resolved',
+    'systemd-resolved', 'unbound', 'dnsconfd',
 ]
 
 # The common ports for these services. This is used to wait for the
