@@ -119,7 +119,7 @@ class UnsafeIPAddress(netaddr.IPAddress):
                 if addr.version != 6:
                     raise
         except ValueError:
-            self._net = netaddr.IPNetwork(addr, flags=self.netaddr_ip_flags)
+            self._net = netaddr.IPNetwork(addr, flags=0)
             addr = self._net.ip
         super(UnsafeIPAddress, self).__init__(addr,
                                               flags=self.netaddr_ip_flags)
@@ -266,6 +266,19 @@ class CheckedIPAddressLoopback(CheckedIPAddress):
                   file=sys.stderr)
 
 
+class IPAddressDoTForwarder(str):
+    """IPv4 or IPv6 address with added hostname as needed for DNS over TLS
+    configuration. Example: 1.2.3.4#dns.hostname.test
+    """
+    def __init__(self, addr):
+        addr_split = addr.split("#")
+        if len(addr_split) != 2 or not valid_ip(addr_split[0]):
+            raise ValueError(
+                "DoT forwarder must be in the format "
+                "of '1.2.3.4#dns.example.test'."
+            )
+
+
 def valid_ip(addr):
     return netaddr.valid_ipv4(addr) or netaddr.valid_ipv6(addr)
 
@@ -1809,3 +1822,30 @@ def get_config_debug(context):
         return False
 
     return parser.get(CONFIG_SECTION, 'debug').lower() == 'true'
+
+
+@contextmanager
+def log_level_override():
+    """The PKI python libraries log to info() which ends up polluting
+       the ipa server installation output. Switch the log level
+       prior to calling any PKI library functions and then restore
+       the value in order to suppress the output. Lines like:
+
+       INFO Connecting to https://localhost:8443
+       INFO Getting PKI server info from /pki/v2/info
+
+       This won't affect what is logged to files.
+    """
+    stream_handlers = [
+        (handler, handler.level) for handler in logging.root.handlers
+        if type(handler) is logging.StreamHandler
+    ]
+    for (handler, _level) in stream_handlers:
+        handler.setLevel(logging.ERROR)
+    try:
+        yield
+    except Exception as e:
+        raise e
+    finally:
+        for (handler, orig_level) in stream_handlers:
+            handler.setLevel(orig_level)
