@@ -25,8 +25,8 @@ SSH utilities.
 import base64
 import re
 import struct
-from hashlib import md5, sha1
-from hashlib import sha256  #pylint: disable=E0611
+from hashlib import sha1
+from hashlib import sha256
 
 import six
 
@@ -38,7 +38,8 @@ __all__ = ['SSHPublicKey']
 OPENSSH_BASE_REGEX = re.compile(r'^[\t ]*(?P<keytype>[^\x00\n\r]+?) [\t ]*(?P<key>[^\x00\n\r]+?)(?:[\t ]+(?P<comment>[^\x00\n\r]*?)[\t ]*)?$')
 OPENSSH_OPTIONS_REGEX = re.compile(r'(?P<name>[-0-9A-Za-z]+)(?:="(?P<value>(?:\\"|[^\x00\n\r"])*)")?')
 
-class SSHPublicKey(object):
+
+class SSHPublicKey:
     """
     SSH public key object.
     """
@@ -124,6 +125,9 @@ class SSHPublicKey(object):
     def _parse_openssh_with_options(self, key):
         key = key.lstrip('\t ')
 
+        # Options that allow multiple entries
+        multiple_allowed = ('permitopen', 'permitlisten')
+
         options = {}
         while True:
             match = OPENSSH_OPTIONS_REGEX.match(key)
@@ -135,7 +139,13 @@ class SSHPublicKey(object):
             if value:
                 value = value.replace('\\"', '"')
 
-            options[name] = value
+            if name in multiple_allowed:
+                if name in options:
+                    options[name].append(value)
+                else:
+                    options[name] = [value]
+            else:
+                options[name] = value
 
             key = key[len(match.group(0)):]
             key0, key = key[:1], key[1:]
@@ -178,6 +188,10 @@ class SSHPublicKey(object):
                 value = self._options[name]
                 if value is None:
                     options.append(name)
+                elif type(value) is list:
+                    for v in value:
+                        v = v.replace('"', '\\"')
+                        options.append(u'%s="%s"' % (name, v))
                 else:
                     value = value.replace('"', '\\"')
                     options.append(u'%s="%s"' % (name, value))
@@ -190,10 +204,10 @@ class SSHPublicKey(object):
 
         return out
 
-    def fingerprint_hex_md5(self):
-        fp = md5(self._key).hexdigest().upper()
-        fp = u':'.join([fp[j:j+2] for j in range(0, len(fp), 2)])
-        return fp
+    def fingerprint_hex_sha256(self):
+        # OpenSSH trims the trailing '=' of base64 sha256 FP representation
+        fp = base64.b64encode(sha256(self._key).digest()).rstrip(b'=')
+        return u'SHA256:{fp}'.format(fp=fp.decode('utf-8'))
 
     def _fingerprint_dns(self, fpfunc, fptype):
         if self._keytype == 'ssh-rsa':
@@ -205,7 +219,7 @@ class SSHPublicKey(object):
         elif self._keytype == 'ssh-ed25519':
             keytype = 4
         else:
-            return
+            return None
         fp = fpfunc(self._key).hexdigest().upper()
         return u'%d %d %s' % (keytype, fptype, fp)
 
