@@ -55,9 +55,13 @@ from samba import ntstatus
 import samba
 
 try:
-    from samba.trust_utils import CreateTrustedDomainRelax
+    from samba.lsa_utils import CreateTrustedDomainRelax
 except ImportError:
-    CreateTrustedDomainRelax = None
+    try:
+        from samba.trust_utils import CreateTrustedDomainRelax
+    except ImportError:
+        CreateTrustedDomainRelax = None
+
 try:
     from samba import arcfour_encrypt
 except ImportError:
@@ -1358,6 +1362,8 @@ class TrustDomainInstance:
         info.trust_attributes = 0
         if trust_external:
             info.trust_attributes |= lsa.LSA_TRUST_ATTRIBUTE_NON_TRANSITIVE
+        else:
+            info.trust_attributes |= lsa.LSA_TRUST_ATTRIBUTE_FOREST_TRANSITIVE
 
         try:
             dname = lsa.String()
@@ -1654,6 +1660,7 @@ def fetch_domains(api, mydomain, trustdomain, creds=None, server=None):
 
     ftinfo.count = len(ftinfo_records)
     ftinfo.records = ftinfo_records
+    ftinfo.version = 1
     result['ftinfo_data'] = ndr_pack(ftinfo)
     return result
 
