@@ -11,9 +11,9 @@ from __future__ import print_function, absolute_import
 import enum
 import logging
 import os.path
-import pki.util
+import tempfile
 
-import six
+import pki.util
 
 from ipalib.constants import IPA_CA_CN
 from ipalib.install import certstore
@@ -22,7 +22,7 @@ from ipaplatform.constants import constants
 from ipaserver.install import sysupgrade
 from ipapython.install import typing
 from ipapython.install.core import group, knob, extend_knob
-from ipaserver.install import cainstance, bindinstance, dsinstance
+from ipaserver.install import acmeinstance, cainstance, bindinstance, dsinstance
 from ipapython import ipautil, certdb
 from ipapython import ipaldap
 from ipapython.admintool import ScriptError
@@ -35,8 +35,6 @@ from ipapython.dn import DN
 
 from . import conncheck, dogtag, cainstance
 
-if six.PY3:
-    unicode = str
 
 VALID_SUBJECT_BASE_ATTRS = {
     'st', 'o', 'ou', 'dnqualifier', 'c', 'serialnumber', 'l', 'title', 'sn',
@@ -54,8 +52,8 @@ external_ca_file = None
 
 
 def subject_validator(valid_attrs, value):
-    if not isinstance(value, unicode):
-        v = unicode(value, 'utf-8')
+    if not isinstance(value, str):
+        v = str(value, 'utf-8')
     else:
         v = value
     if any(ord(c) < 0x20 for c in v):
@@ -92,22 +90,8 @@ def random_serial_numbers_validator(enabled):
 
 
 def lookup_ca_subject(api, subject_base):
-    dn = DN(('cn', IPA_CA_CN), api.env.container_ca, api.env.basedn)
-    try:
-        # we do not use api.Command.ca_show because it attempts to
-        # talk to the CA (to read certificate / chain), but the RA
-        # backend may be unavailable (ipa-replica-install) or unusable
-        # due to RA Agent cert not yet created (ipa-ca-install).
-        ca_subject = api.Backend.ldap2.get_entry(dn)['ipacasubjectdn'][0]
-    except errors.NotFound:
-        # if the entry doesn't exist, we are dealing with a pre-v4.4
-        # installation, where the default CA subject was always based
-        # on the subject_base.
-        #
-        # installutils.default_ca_subject_dn is NOT used here in
-        # case the default changes in the future.
-        ca_subject = DN(('CN', 'Certificate Authority'), subject_base)
-    return str(ca_subject)
+    """Function moved to installutils with stub retained for API compat"""
+    return installutils.lookup_ca_subject(api, subject_base)
 
 
 def lookup_random_serial_number_version(api):
@@ -211,12 +195,12 @@ def hsm_validator(token_name, token_library, token_password):
         )
     pkiuser = constants.PKI_USER
     pkigroup = constants.PKI_GROUP
-    if 'libsofthsm' in token_library:
-        import grp
-        group = grp.getgrnam(constants.ODS_GROUP)
-        if str(constants.PKI_USER) in group.gr_mem:
-            pkigroup = constants.ODS_GROUP
-    with certdb.NSSDatabase() as tempnssdb:
+    group_list = os.getgrouplist(pkiuser, pkigroup.gid)
+    with (
+        tempfile.TemporaryDirectory(dir=paths.TMP) as tempnssdir,
+        tempfile.NamedTemporaryFile(mode="w+", dir=paths.TMP) as pwdfile,
+    ):
+        tempnssdb = certdb.NSSDatabase(nssdir=tempnssdir)
         tempnssdb.create_db(user=str(pkiuser), group=str(pkigroup))
         # Try adding the token library to the temporary database in
         # case it isn't already available. Ignore all errors.
@@ -231,7 +215,7 @@ def hsm_validator(token_name, token_library, token_password):
         # It may fail if p11-kit has already registered the library, that's
         # ok.
         ipautil.run(command, stdin='\n', cwd=tempnssdb.secdir,
-                    runas=pkiuser, suplementary_groups=[pkigroup],
+                    runas=pkiuser, suplementary_groups=group_list,
                     raiseonerr=False)
 
         command = [
@@ -242,7 +226,7 @@ def hsm_validator(token_name, token_library, token_password):
         ]
         lines = ipautil.run(
             command, cwd=tempnssdb.secdir, capture_output=True,
-            runas=pkiuser, suplementary_groups=[pkigroup]).output
+            runas=pkiuser, suplementary_groups=group_list).output
         found = False
         token_line = f'token: {token_name}'
         for line in lines.split('\n'):
@@ -254,7 +238,9 @@ def hsm_validator(token_name, token_library, token_password):
                 "Token named '%s' was not found. Check permissions"
                 % token_name
             )
-        pwdfile = ipautil.write_tmp_file(token_password)
+
+        pwdfile.write(token_password)
+        pwdfile.flush()
         os.fchown(pwdfile.fileno(), pkiuser.uid, pkigroup.gid)
         args = [
             paths.CERTUTIL,
@@ -265,7 +251,7 @@ def hsm_validator(token_name, token_library, token_password):
         ]
         result = ipautil.run(args, cwd=tempnssdb.secdir,
                              runas=pkiuser,
-                             suplementary_groups=[pkigroup],
+                             suplementary_groups=group_list,
                              capture_error=True, raiseonerr=False)
         if result.returncode != 0 and len(result.error_output):
             if 'SEC_ERROR_BAD_PASSWORD' in result.error_output:
@@ -715,6 +701,9 @@ def install_step_1(standalone, replica_config, options, custodia):
 
 
 def uninstall():
+    acme = acmeinstance.ACMEInstance(api.env.realm)
+    acme.uninstall()
+
     ca_instance = cainstance.CAInstance(api.env.realm)
     ca_instance.stop_tracking_certificates()
     ipautil.remove_file(paths.RA_AGENT_PEM)
