@@ -34,7 +34,9 @@ import fcntl
 import time
 import datetime
 
-import six
+import pki.ca
+import pki.cert
+import pki.client
 
 from ipalib.install import certmonger, sysrestore
 from ipapython import dogtag
@@ -42,13 +44,15 @@ from ipapython import ipautil
 from ipapython.certdb import EMPTY_TRUST_FLAGS, IPA_CA_TRUST_FLAGS
 from ipapython.certdb import get_ca_nickname, find_cert_from_txt, NSSDatabase
 from ipapython.dn import DN
-from ipalib import x509, api
+from ipapython.ipautil import log_level_override
+from ipalib import x509, api, constants
 from ipalib.errors import CertificateOperationError
 from ipalib.install import certstore
 from ipalib.util import strip_csr_header
 from ipalib.text import _
 from ipaplatform.paths import paths
 from ipaplatform.tasks import tasks
+from ipaserver.masters import find_providing_server
 
 
 logger = logging.getLogger(__name__)
@@ -373,7 +377,7 @@ class CertDB:
             except RuntimeError:
                 break
 
-    def get_cert_from_db(self, nickname):
+    def get_cert_from_db(self, nickname, all=False):
         """
         Retrieve a certificate from the current NSS database for nickname.
         """
@@ -386,7 +390,10 @@ class CertDB:
             if token:
                 args.extend(['-h', token])
             result = self.run_certutil(args, capture_output=True)
-            return x509.load_pem_x509_certificate(result.raw_output)
+            if all:
+                return x509.load_certificate_list(result.raw_output)
+            else:
+                return x509.load_pem_x509_certificate(result.raw_output)
         except ipautil.CalledProcessError:
             return None
 
@@ -726,6 +733,173 @@ class CertDB:
         """
         self.nssdb.convert_db()
 
+    def pki_issue_ra_certificate(self, csrfile, certfile, dm_password):
+        """Using a user-provided CSR submit it to the CA using its
+           python API.
+
+        `csrfile` points to the CSR.  `certfile` is the path where we
+        write the issued certificate.
+        """
+        pk12pwfile = ipautil.write_tmp_file(dm_password)
+        agent_key = ipautil.write_tmp_file("")
+        agent_cert = ipautil.write_tmp_file("")
+        cmd = [
+            paths.OPENSSL, 'pkcs12',
+            '-in', paths.DOGTAG_ADMIN_P12,
+            '-out', agent_cert.name,
+            '-nokeys',
+            '-password', 'file:{pk12pwfile}'.format(pk12pwfile=pk12pwfile.name),
+        ]
+        # the PKCS12 MAC requires PKCS12KDF which is not an approved FIPS
+        # algorithm and cannot be supported by the FIPS provider.
+        # Do not require mac verification in FIPS mode
+        fips_enabled = tasks.is_fips_enabled()
+        if fips_enabled:
+            cmd.append('-nomacver')
+        ipautil.run(cmd)
+
+        cmd = [
+            paths.OPENSSL, 'pkcs12',
+            '-in', paths.DOGTAG_ADMIN_P12,
+            '-out', agent_key.name,
+            '-nocerts',
+            '-noenc',
+            '-password', 'file:{pk12pwfile}'.format(pk12pwfile=pk12pwfile.name),
+        ]
+        if fips_enabled:
+            cmd.append('-nomacver')
+        ipautil.run(cmd)
+
+        pki_client = pki.client.PKIClient(
+            url='https://localhost:8443', verify=False)
+        pki_client.set_client_auth(
+            client_cert=agent_cert.name,
+            client_key=agent_key.name,
+        )
+        ca_client = pki.ca.CAClient(pki_client)
+        cert_client = pki.cert.CertClient(ca_client)
+
+        inputs = dict()
+        inputs['cert_request_type'] = 'pkcs10'
+        with open(csrfile, 'r') as f:
+            inputs['cert_request'] = f.read()
+        with log_level_override():
+            result = cert_client.enroll_cert(
+                constants.RA_AGENT_PROFILE, inputs)[0]
+
+        request_data = result.request
+        if request_data.request_status != pki.cert.CertRequestStatus.COMPLETE:
+            raise RuntimeError(
+                "The certificate submission is not complete")
+        if request_data.operation_result != "success":
+            raise RuntimeError(
+                "The certificate submission was not successful")
+
+        cert_data = result.cert
+        c = cert_client.get_cert(cert_data.serial_number)
+        with open(certfile, "w") as fd:
+            fd.write(c.encoded)
+
+    def pki_issue_certificate(self, service, profile, keyfile, certfile,
+                              key_passwd_file=None, dns_2_san='',
+                              othername_2_san=''):
+        """Use openssl to generate a CSR and submit it using the pki
+           Python API, using the IPA RA certificate.
+        """
+        if service == 'krbtgt':
+            principal = api.env.realm
+        else:
+            principal = api.env.host
+        template = os.path.join(
+            paths.USR_SHARE_IPA_DIR, "openssl_cnf.template")
+        sub_dict = dict(
+            REALM=api.env.realm,
+            DOMAIN=api.env.domain,
+            FQDN=api.env.host,
+            PRINCIPAL=principal,
+            NICKNAME="Server-Cert",
+            PROFILE=profile,
+            SERVICE=service,
+            DNS_2=dns_2_san,
+            OTHERNAME_2=othername_2_san,
+        )
+        conf = ipautil.template_file(template, sub_dict)
+        destfile = os.path.join(self.secdir, "openssl.cnf")
+        with open(destfile, 'w') as f:
+            os.fchmod(f.fileno(), 0o600)
+            f.write(conf)
+
+        (keytype, keysize) = api.env.key_type_size.split(':', 1)
+
+        # Generate a private key
+        if (keytype.lower() == 'rsa'):
+            args = ["openssl", "genrsa",
+                    "-out", keyfile]
+            if key_passwd_file:
+                args.extend(
+                    ["-aes256",
+                     "-passout", "file:{}".format(key_passwd_file)]
+                )
+            args.extend([keysize])  # must be the last argument
+            result = ipautil.run(args, capture_output=True)
+        else:
+            raise RuntimeError(f"Key type not supported: {keytype}")
+
+        # Generate a CSR using the private key
+        args = ["openssl", "req", "-new",
+                "-key", keyfile,
+                "-out", os.path.join(self.secdir, "csr"),
+                "-config", destfile]
+        if key_passwd_file:
+            args.extend(
+                ["-passin", "file:{}".format(key_passwd_file)]
+            )
+        result = ipautil.run(args, capture_output=True)
+
+        preferred = [api.env.ca_host]
+        if api.env.host != api.env.ca_host:
+            preferred.append(api.env.host)
+        ca_host = find_providing_server(
+            'CA', conn=api.Backend.ldap2, preferred_hosts=preferred,
+            api=api
+        )
+        if ca_host is None:
+            ca_host = api.env.ca_host
+
+        # during initial bootstrap we need to talk directly to the
+        # CA. So if the operation takes place on a CA-enabled server
+        # then use port 8443.
+        if ca_host == api.env.host:
+            port = 8443
+        else:
+            port = 443
+
+        # initialise PKIClient
+        pki_client = pki.client.PKIClient(
+            url=f'https://{ca_host}:{port}', verify=False)
+        pki_client.set_client_auth(
+            client_cert=paths.RA_AGENT_PEM,
+            client_key=paths.RA_AGENT_KEY)
+        ca_client = pki.ca.CAClient(pki_client)
+        cert_client = pki.cert.CertClient(ca_client)
+
+        inputs = dict()
+        inputs['cert_request_type'] = 'pkcs10'
+        with open(os.path.join(self.secdir, "csr"), 'r') as f:
+            inputs['cert_request'] = f.read()
+        with log_level_override():
+            result = cert_client.enroll_cert(profile, inputs)[0]
+
+        request_data = result.request
+        if request_data.operation_result != "success":
+            raise RuntimeError(
+                "The certificate submission was not successful")
+
+        cert_data = result.cert
+        c = cert_client.get_cert(cert_data.serial_number)
+        with open(certfile, "w") as fd:
+            fd.write(c.encoded)
+
 
 class _CrossProcessLock:
     _DATETIME_FORMAT = '%Y%m%d%H%M%S%f'
@@ -791,10 +965,7 @@ class _CrossProcessLock:
 
     def _read(self, fileobj):
         p = configparser.RawConfigParser()
-        if six.PY2:
-            p.readfp(fileobj)  # pylint: disable=no-member
-        else:
-            p.read_file(fileobj)
+        p.read_file(fileobj)
 
         try:
             self._locked = p.getboolean('lock', 'locked')
