@@ -20,16 +20,20 @@ from subprocess import CalledProcessError
 from ipalib import api
 from ipalib import errors
 from ipalib import util
-from ipalib.install import hostname, sysrestore
+from ipalib import x509
+from ipalib.install import hostname, sysrestore, certmonger
 from ipalib.install.service import enroll_only, prepare_only
 from ipalib.install import dnsforwarders
+from ipalib.constants import FQDN
 from ipaplatform.paths import paths
 from ipaplatform.constants import constants
 from ipaplatform import services
+from ipapython import admintool
 from ipapython import ipautil
 from ipapython import dnsutil
+from ipapython.certdb import EXTERNAL_CA_TRUST_FLAGS
 from ipapython.dn import DN
-from ipapython.dnsutil import check_zone_overlap
+from ipapython.dnsutil import check_zone_overlap, get_ipa_resolver
 from ipapython.install import typing
 from ipapython.install.core import group, knob
 from ipapython.admintool import ScriptError
@@ -37,7 +41,9 @@ from ipapython.ipautil import user_input
 from ipaserver.install.installutils import get_server_ip_address
 from ipaserver.install.installutils import read_dns_forwarders
 from ipaserver.install.installutils import update_hosts_file
+from ipaserver.install.installutils import default_subject_base
 from ipaserver.install import bindinstance
+from ipaserver.install import certs
 from ipaserver.install import dnskeysyncinstance
 from ipaserver.install import odsexporterinstance
 from ipaserver.install import opendnssecinstance
@@ -108,6 +114,88 @@ def _disable_dnssec():
             conn.update_entry(entry)
 
 
+def _request_cert_for_dns_over_tls(options):
+    if os.path.isfile(paths.IPA_CA_CRT) and not options.dns_over_tls_cert:
+        # request certificate for DNS over TLS, using IPA CA
+        cert = paths.BIND_DNS_OVER_TLS_CRT
+        key = paths.BIND_DNS_OVER_TLS_KEY
+        certmonger.request_and_wait_for_cert(
+            certpath=(cert, key),
+            principal='DNS/%s@%s' % (FQDN, api.env.realm),
+            subject=str(DN(('CN', FQDN), default_subject_base(api.env.realm))),
+            storage="FILE"
+        )
+        constants.NAMED_USER.chown(cert, gid=constants.NAMED_GROUP.gid)
+        constants.NAMED_USER.chown(key, gid=constants.NAMED_GROUP.gid)
+
+
+def _setup_dns_over_tls(options):
+    # setup and enable Unbound as resolver
+    forward_addrs = ["# forward-addr: specify here forwarders"]
+    if options.dot_forwarders:
+        forward_addrs = ["forward-addr: %s" % fw
+                         for fw in options.dot_forwarders]
+    # module_config_iterator is commented out if DNSSEC validation is
+    # not disabled.
+    module_config_iterator = '' if options.no_dnssec_validation else '# '
+
+    # backup and remove all previous Unbound configuration
+    fstore = sysrestore.FileStore(paths.SYSRESTORE)
+    for filename in os.listdir(paths.UNBOUND_CONFIG_DIR):
+        filepath = os.path.join(paths.UNBOUND_CONFIG_DIR, filename)
+        if filepath == paths.UNBOUND_CONF:
+            continue
+        fstore.backup_file(filepath)
+        ipautil.remove_file(filepath)
+
+    ipautil.copy_template_file(
+        paths.UNBOUND_CONF_SRC,
+        paths.UNBOUND_CONF,
+        dict(
+            FORWARD_ADDRS="\n".join(forward_addrs),
+            MODULE_CONFIG_ITERATOR=module_config_iterator
+        )
+    )
+
+    sr = services.knownservices["systemd-resolved"]
+    if sr.is_running():
+        sr.stop()
+        sr.disable()
+
+    api.Command.dnsserver_mod(
+        FQDN,
+        idnsforwarders="127.0.0.55",
+        idnsforwardpolicy="first"
+    )
+
+    nm = services.knownservices["NetworkManager"]
+    if nm.is_enabled():
+        with open(paths.NETWORK_MANAGER_IPA_CONF, "w") as f:
+            dns_none = [
+                "# auto-generated by IPA installer",
+                "[main]",
+                "dns=none\n"
+            ]
+            f.write("\n".join(dns_none))
+        nm.reload_or_restart()
+
+    # Ensure resolv.conf points to IPA
+    cfg = [
+        "# auto-generated by IPA installer",
+        "search .",
+        "nameserver 127.0.0.1\n"
+    ]
+    nameservers = get_ipa_resolver().nameservers
+    if not nameservers or nameservers[0] != "127.0.0.1":
+        fstore.backup_file(paths.RESOLV_CONF)
+        with open(paths.RESOLV_CONF, 'w') as f:
+            f.write('\n'.join(cfg))
+            os.chmod(paths.RESOLV_CONF, 0o644)
+
+    services.knownservices.unbound.enable()
+    services.knownservices.unbound.restart()
+
+
 def package_check(exception):
     if not os.path.isfile(paths.IPA_DNS_INSTALL):
         raise exception(
@@ -330,11 +418,47 @@ def install(standalone, replica, options, api=api):
         # otherwise this is done by server/replica installer
         update_hosts_file(ip_addresses, api.env.host, fstore)
 
+    if os.path.isfile(paths.IPA_CA_CRT) and not options.dns_over_tls_cert:
+        dot_cert = paths.BIND_DNS_OVER_TLS_CRT
+        dot_key = paths.BIND_DNS_OVER_TLS_KEY
+    elif options.dns_over_tls_cert and options.dns_over_tls_key:
+        # Check certificate validity first
+        with certs.NSSDatabase() as tmpdb:
+            tmpdb.create_db()
+            ca_certs = x509.load_certificate_list_from_file(
+                options.dns_over_tls_cert)
+            nicknames = []
+            for ca_cert in ca_certs:
+                nicknames.append(str(DN(ca_cert.subject)))
+                tmpdb.add_cert(
+                    ca_cert, str(DN(ca_cert.subject)), EXTERNAL_CA_TRUST_FLAGS)
+            try:
+                for nick in nicknames:
+                    tmpdb.verify_ca_cert_validity(nick)
+            except ValueError as e:
+                raise admintool.ScriptError(
+                    "Not a valid CA certificate: %s" % e)
+        dot_cert = options.dns_over_tls_cert
+        dot_key = options.dns_over_tls_key
+    else:
+        raise RuntimeError(
+            "Certificate for DNS over TLS not specified "
+            "and IPA CA is not present."
+        )
+
+    if options.dns_over_tls:
+        print("Request certificate for DNS over TLS, using IPA CA")
+        _request_cert_for_dns_over_tls(options)
+
     bind = bindinstance.BindInstance(fstore, api=api)
     bind.setup(api.env.host, ip_addresses, api.env.realm, api.env.domain,
                options.forwarders, options.forward_policy,
                reverse_zones, zonemgr=options.zonemgr,
-               no_dnssec_validation=options.no_dnssec_validation)
+               no_dnssec_validation=options.no_dnssec_validation,
+               dns_over_tls=options.dns_over_tls,
+               dns_over_tls_cert=dot_cert,
+               dns_over_tls_key=dot_key,
+               dns_policy=options.dns_policy)
 
     if standalone and not options.unattended:
         print("")
@@ -343,6 +467,14 @@ def install(standalone, replica, options, api=api):
         print("")
 
     bind.create_instance()
+
+    bind.sstore.backup_state("dns_over_tls",
+                             "external_crt",
+                             bool(options.dns_over_tls_cert))
+    if options.dns_over_tls:
+        print("Setting up DNS over TLS")
+        _setup_dns_over_tls(options)
+
     print("Restarting the web server to pick up resolv.conf changes")
     services.knownservices.httpd.restart(capture_output=True)
 
@@ -370,6 +502,12 @@ def install(standalone, replica, options, api=api):
     bind.update_system_records()
 
     if standalone:
+        if options.dns_over_tls and options.dns_policy == "enforced":
+            dns_port = "853"
+        elif options.dns_over_tls:
+            dns_port = "53, 853"
+        else:
+            dns_port = "53"
         print("==============================================================================")
         print("Setup complete")
         print("")
@@ -378,14 +516,22 @@ def install(standalone, replica, options, api=api):
         print("")
         print("\tYou must make sure these network ports are open:")
         print("\t\tTCP Ports:")
-        print("\t\t  * 53: bind")
+        print(f"\t\t  * {dns_port}: bind")
         print("\t\tUDP Ports:")
-        print("\t\t  * 53: bind")
+        print(f"\t\t  * {dns_port}: bind")
     elif not standalone and replica:
         print("")
         bind.check_global_configuration()
         print("")
 
+    if options.dns_over_tls:
+        policy = "enforced" if options.dns_policy == "enforced" else "relaxed"
+        print("")
+        print(("DNS encryption support was enabled "
+               "with policy '{}'.".format(policy)))
+        print(("Unbound is configured to listen on 127.0.0.55:53 and "
+               "forward to upstream DoT servers."))
+
 
 def uninstall_check(options):
     # test if server is DNSSEC key master
@@ -424,6 +570,10 @@ class DNSForwardPolicy(enum.Enum):
     FIRST = 'first'
 
 
+class EncryptedDNSPolicy(enum.Enum):
+    RELAXED = 'relaxed'
+    ENFORCED = 'enforced'
+
 @group
 class DNSInstallInterface(hostname.HostNameInstallInterface):
     """
@@ -536,6 +686,40 @@ class DNSInstallInterface(hostname.HostNameInstallInterface):
     )
     no_dnssec_validation = enroll_only(no_dnssec_validation)
 
+    dns_over_tls = knob(
+        None,
+        description="Configure DNS over TLS",
+    )
+    dns_over_tls = enroll_only(dns_over_tls)
+
+    dot_forwarders = knob(
+        typing.List[ipautil.IPAddressDoTForwarder], None,
+        description=("Add a DNS over TLS forwarder. "
+                     "This option can be used multiple times"),
+        cli_names='--dot-forwarder',
+    )
+    dot_forwarders = enroll_only(dot_forwarders)
+
+    dns_over_tls_cert = knob(
+        str, None,
+        description=("Certificate to use for DNS over TLS. "
+                     "If empty, a new certificate will be "
+                     "requested from IPA CA"),
+    )
+    dns_over_tls_cert = enroll_only(dns_over_tls_cert)
+
+    dns_over_tls_key = knob(
+        str, None,
+        description="Key for certificate specified in --dns-over-tls-cert",
+    )
+    dns_over_tls_key = enroll_only(dns_over_tls_key)
+
+    dns_policy = knob(
+        EncryptedDNSPolicy, 'relaxed',
+        description=("Encrypted DNS policy"),
+    )
+    dns_policy = enroll_only(dns_policy)
+
     dnssec_master = False
     disable_dnssec_master = False
     kasp_db_file = None
