@@ -37,7 +37,6 @@ from configparser import DEFAULTSECT, ConfigParser, RawConfigParser
 import six
 
 import pki
-from pki.client import PKIConnection
 import pki.system
 import pki.util
 
@@ -79,14 +78,12 @@ def get_security_domain():
     Get the security domain from the REST interface on the local Dogtag CA
     This function will succeed if the local dogtag CA is up.
     """
-    connection = PKIConnection(
-        protocol='https',
-        hostname=api.env.ca_host,
-        port='8443',
-        cert_paths=paths.IPA_CA_CRT
-    )
-    domain_client = pki.system.SecurityDomainClient(connection)
-    info = domain_client.get_domain_info()
+    pki_client = pki.client.PKIClient(
+        url=f'https://{api.env.ca_host}:8443', ca_bundle=paths.IPA_CA_CRT)
+    sub_client = pki.subsystem.SubsystemClient(pki_client, 'ca')
+    domain_client = pki.system.SecurityDomainClient(sub_client)
+    with ipautil.log_level_override():
+        info = domain_client.get_domain_info()
     return info
 
 
@@ -129,6 +126,33 @@ class DogtagInstance(service.Service):
         """Look up token name for nickname."""
         return self.token_names.get(nickname, self.token_name)
 
+    def get_token_pwd_file(self, dir):
+        """
+        Create a temp password file in the provided directory.
+
+        The file contains the password for the internal token and
+        for the HSM.
+        The directory dir must already exist, and the caller must
+        delete the file after use.
+        """
+        if tasks.is_fips_enabled():
+            dbname = 'NSS FIPS 140-2 Certificate DB'
+        else:
+            dbname = 'NSS Certificate DB'
+        pwd_file = os.path.join(dir, "pwd_file")
+        with open(pwd_file, "w") as pwd:
+            with open(paths.PKI_TOMCAT_PASSWORD_CONF, 'r') as fd:
+                for line in fd:
+                    (token, pin) = line.split('=', 1)
+                    if token.startswith('hardware-'):
+                        token = token.replace('hardware-', '')
+                        pwd.write(f'{token}:{pin}')
+                    elif token == INTERNAL_TOKEN:
+                        pwd.write(f'{dbname}:{pin}')
+            pwd.flush()
+            os.fchmod(pwd.fileno(), 0o600)
+        return pwd_file
+
     groups_aci = (
         b'(targetfilter="(objectClass=groupOfUniqueNames)")'
         b'(targetattr="cn || description || objectclass || uniquemember")'
@@ -304,25 +328,42 @@ class DogtagInstance(service.Service):
         if self.is_installed():
             self.print_msg("Unconfiguring %s" % self.subsystem)
 
-        args = [paths.PKIDESTROY,
-                "-i", "pki-tomcat", "--force",
-                "-s", self.subsystem]
-
-        # specify --log-file <path> on PKI 11.0.0 or later
-
+        args = []
         pki_version = pki.util.Version(pki.specification_version())
-        if pki_version >= pki.util.Version("11.0.0"):
-            timestamp = time.strftime(
-                "%Y%m%d%H%M%S",
-                time.localtime(time.time()))
-            log_file = os.path.join(
-                paths.VAR_LOG_PKI_DIR,
-                "pki-%s-destroy.%s.log" % (self.subsystem.lower(), timestamp))
-            args.extend(["--log-file", log_file])
+        if self.subsystem == "ACME":
+            if pki_version < pki.util.Version("11.0.0"):
+                return
+            elif not os.path.exists(os.path.join(paths.PKI_TOMCAT, 'acme')):
+                return
+            elif (
+                pki.util.Version("11.0.0") <= pki_version
+                < pki.util.Version("11.6.0")
+            ):
+                args = ['pki-server', 'acme-remove']
+            else:
+                # fall through for PKI >= 11.6.0
+                pass
+        if not args:
+            args = [paths.PKIDESTROY,
+                    "-i", "pki-tomcat", "--force",
+                    "-s", self.subsystem]
+
+            # specify --log-file <path> on PKI 11.0.0 or later
+
+            if pki_version >= pki.util.Version("11.0.0"):
+                timestamp = time.strftime(
+                    "%Y%m%d%H%M%S",
+                    time.localtime(time.time()))
+                log_file = os.path.join(
+                    paths.VAR_LOG_PKI_DIR,
+                    "pki-%s-destroy.%s.log" %
+                    (self.subsystem.lower(), timestamp))
+                args.extend(["--log-file", log_file])
+            if pki_version >= pki.util.Version("11.6.0"):
+                args.extend(["--remove-conf", "--remove-logs"])
 
         try:
             ipautil.run(args)
-
         except ipautil.CalledProcessError as e:
             logger.critical("failed to uninstall %s instance %s",
                             self.subsystem, e)
@@ -532,6 +573,24 @@ class DogtagInstance(service.Service):
             except RuntimeError as e:
                 logger.error(
                     "certmonger failed to start tracking certificate: %s", e)
+            except dbus.exceptions.DBusException as e:
+                if e._dbus_error_name == "org.freedesktop.DBus.Error.NoReply":
+                    logger.error(
+                        "Timeout encountered starting tracking of '%s'."
+                        "This timeout can be tuned using "
+                        "certmonger_wait_timeout in /etc/ipa/installer.conf.",
+                        nickname
+                    )
+                if self.hsm_enabled:
+                    logger.error(
+                        "On an initial install failure this may leave "
+                        "certificates and keys on the HSM token. These "
+                        "need to be manually cleaned per your HSM-specific "
+                        "documentation before installing IPA again. On a "
+                        "replica install no clean-up should be done (it will "
+                        "destroy your installation."
+                    )
+                raise
 
     def stop_tracking_certificates(self):
         """
@@ -980,6 +1039,12 @@ class PKIIniLoader:
         'pki_clone_replication_clone_port',
         'pki_clone_replicate_schema',
         'pki_clone_uri',
+        # hsm
+        'pki_hsm_enable',
+        'pki_hsm_libfile',
+        'pki_hsm_modulename',
+        'pki_token_name',
+        'pki_token_password',
         # cainstance
         'pki_ds_secure_connection',
         'pki_server_database_password',
