@@ -23,7 +23,6 @@ import logging
 import os
 import shutil
 import tempfile
-import base64
 
 from ipalib import api
 from ipalib import x509
@@ -61,9 +60,8 @@ class KRAInstance(DogtagInstance):
     """
     We assume that the CA has already been installed, and we use the
     same tomcat instance to host both the CA and KRA.
-    The mod_nss database will contain the RA agent cert that will be used
-    to do authenticated requests against dogtag.  The RA agent cert will
-    be the same for both the CA and KRA.
+    The same RA agent certificate used with the CA will be used for the
+    KRA.
     """
 
     # Mapping of nicknames for tracking requests, and the profile to
@@ -230,10 +228,7 @@ class KRAInstance(DogtagInstance):
             parentdir = os.path.dirname(paths.ADMIN_CERT_PATH)
             if not os.path.exists(parentdir):
                 os.makedirs(parentdir)
-            with open(paths.ADMIN_CERT_PATH, "wb") as admin_path:
-                admin_path.write(
-                    base64.b64encode(cert.public_bytes(x509.Encoding.DER))
-                )
+            x509.write_certificate(cert, paths.ADMIN_CERT_PATH)
 
         # Generate configuration file
         config = self._create_spawn_config(cfg)
