@@ -681,6 +681,8 @@ def install_check(installer):
         # make sure host name specified by user is used instead of default
         host=host_name,
     )
+    if options.key_type_size:
+        cfg['key_type_size'] = options.key_type_size
     if setup_ca:
         # we have an IPA-integrated CA
         cfg['ca_host'] = host_name
@@ -1018,6 +1020,10 @@ def install(installer):
 
     if options.setup_dns:
         dns.install(False, False, options)
+    elif options.dns_over_tls:
+        service.print_msg("Warning: --dns-over-tls option "
+                          "specified without --setup-dns, ignoring")
+        options.dns_over_tls = False
 
     # Always call adtrust installer to configure SID generation
     # if --setup-adtrust is not specified, only the SID part is executed
@@ -1072,7 +1078,12 @@ def install(installer):
     # Everything installed properly, activate ipa service.
     sstore.delete_state('installation', 'complete')
     sstore.backup_state('installation', 'complete', True)
+
+    service.print_msg("Enabling and restarting the IPA service")
+    start = time.time()
     services.knownservices.ipa.enable()
+    dur = time.time() - start
+    logger.debug("Service enablement duration: %0.3f", dur)
 
     print("======================================="
           "=======================================")
@@ -1084,12 +1095,16 @@ def install(installer):
     print("\t\t  * 80, 443: HTTP/HTTPS")
     print("\t\t  * 389, 636: LDAP/LDAPS")
     print("\t\t  * 88, 464: kerberos")
-    if options.setup_dns:
-        print("\t\t  * 53: bind")
+    if options.dns_over_tls and options.dns_policy == "enforced":
+        dns_port = "853"
+    elif options.dns_over_tls:
+        dns_port = "53, 853"
+    else:
+        dns_port = "53"
+    print(f"\t\t  * {dns_port}: bind")
     print("\t\tUDP Ports:")
     print("\t\t  * 88, 464: kerberos")
-    if options.setup_dns:
-        print("\t\t  * 53: bind")
+    print(f"\t\t  * {dns_port}: bind")
     if not options.no_ntp:
         print("\t\t  * 123: ntp")
     print("")
@@ -1104,6 +1119,14 @@ def install(installer):
         print("\t   and servers for correct operation. You should consider "
               "enabling chronyd.")
 
+    if options.dns_over_tls:
+        policy = "enforced" if options.dns_policy == "enforced" else "relaxed"
+        print("")
+        print(("DNS encryption support was enabled "
+               "with policy '{}'.".format(policy)))
+        print(("Unbound is configured to listen on 127.0.0.55:53 and "
+               "forward to upstream DoT servers."))
+
     print("")
     if setup_ca and not options.token_name:
         print(("Be sure to back up the CA certificates stored in " +
