@@ -17,7 +17,7 @@ import sys
 import tempfile
 from contextlib import contextmanager
 from augeas import Augeas
-from pkg_resources import parse_version
+from packaging.version import parse as parse_version
 
 from ipalib import api, x509
 from ipalib.constants import RENEWAL_CA_NAME, RA_AGENT_PROFILE, IPA_CA_RECORD
@@ -232,44 +232,27 @@ def check_certs():
         logger.debug('Certificate file exists')
 
 def update_dbmodules(realm, filename=paths.KRB5_CONF):
-    newfile = []
-    found_dbrealm = False
-    found_realm = False
-    prefix = ''
-
     logger.info('[Verifying that KDC configuration is using ipa-kdb backend]')
-    fd = open(filename)
+    aug = Augeas(flags=Augeas.NO_LOAD | Augeas.NO_MODL_AUTOLOAD,
+                 loadpath=paths.USR_SHARE_IPA_DIR)
+    try:
+        aug.transform('IPAKrb5', filename)
+        aug.load()
 
-    lines = fd.readlines()
-    fd.close()
+        path = "/files{}/dbmodules/{}/db_library"
+        path = path.format(filename, realm)
+        if aug.match(path):
+            if aug.get(path) == "ipadb.so":
+                logger.debug('dbmodules already updated in %s', filename)
+                return
+            aug.remove(path)
 
-    if '    db_library = ipadb.so\n' in lines:
-        logger.debug('dbmodules already updated in %s', filename)
-        return
+        aug.set(path, "ipadb.so")
+        aug.save()
 
-    for line in lines:
-        if line.startswith('[dbmodules]'):
-            found_dbrealm = True
-        if found_dbrealm and line.find(realm) > -1:
-            found_realm = True
-            prefix = '#'
-        if found_dbrealm and line.find('}') > -1 and found_realm:
-            found_realm = False
-            newfile.append('#%s' % line)
-            prefix = ''
-            continue
+    finally:
+        aug.close()
 
-        newfile.append('%s%s' % (prefix, line))
-
-    # Append updated dbmodules information
-    newfile.append('  %s = {\n' % realm)
-    newfile.append('    db_library = ipadb.so\n')
-    newfile.append('  }\n')
-
-    # Write out new file
-    fd = open(filename, 'w')
-    fd.write("".join(newfile))
-    fd.close()
     logger.debug('%s updated', filename)
 
 def cleanup_kdc(fstore):
@@ -547,21 +530,25 @@ def ca_initialize_hsm_state(ca):
         ca.set_hsm_state(config)
 
 
-def dnssec_set_openssl_engine(dnskeysyncd):
+def dnssec_set_openssl_provider(dnskeysyncd):
     """
-    Setup OpenSSL engine for BIND
+    Setup OpenSSL engine or provider for BIND
     """
-    if constants.NAMED_OPENSSL_ENGINE is None:
+    if all([constants.NAMED_OPENSSL_ENGINE is None,
+            constants.NAMED_OPENSSL_PROVIDER is None]):
         return False
 
-    if sysupgrade.get_upgrade_state('dns', 'openssl_engine'):
+    # Nothing to do if we are using OpenSSL provider already and not on the OS
+    # that requires OpenSSL provider instead.
+    if all([sysupgrade.get_upgrade_state('dns', 'openssl_provider'),
+            constants.NAMED_OPENSSL_PROVIDER is None]):
         return False
 
-    logger.info('[Set OpenSSL engine for BIND]')
+    logger.info('[Set OpenSSL engine or provider for BIND]')
     dnskeysyncd.setup_named_openssl_conf()
     dnskeysyncd.setup_named_sysconfig()
     dnskeysyncd.setup_ipa_dnskeysyncd_sysconfig()
-    sysupgrade.set_upgrade_state('dns', 'openssl_engine', True)
+    sysupgrade.set_upgrade_state('dns', 'openssl_provider', True)
 
     return True
 
@@ -1088,19 +1075,6 @@ def remove_ds_ra_cert(subject_base):
     sysupgrade.set_upgrade_state('ds', 'remove_ra_cert', True)
 
 
-def migrate_to_mod_ssl(http):
-    logger.info('[Migrating from mod_nss to mod_ssl]')
-
-    if sysupgrade.get_upgrade_state('ssl.conf', 'migrated_to_mod_ssl'):
-        logger.info("Already migrated to mod_ssl")
-        return
-
-    http.migrate_to_mod_ssl()
-
-    sysupgrade.set_upgrade_state('ssl.conf', 'migrated_to_mod_ssl', True)
-
-
-
 def update_ipa_httpd_service_conf(http):
     logger.info('[Updating HTTPD service IPA configuration]')
     http.update_httpd_service_ipa_conf()
@@ -1124,6 +1098,7 @@ def update_http_keytab(http):
                 paths.OLD_IPA_KEYTAB, e
             )
     http.keytab_user.chown(http.keytab)
+    tasks.restore_context(http.keytab)
 
 
 def ds_enable_sidgen_extdom_plugins(ds):
@@ -1873,7 +1848,6 @@ def upgrade_configuration():
     http.stop()
     update_ipa_httpd_service_conf(http)
     update_ipa_http_wsgi_conf(http)
-    migrate_to_mod_ssl(http)
     update_http_keytab(http)
     http.configure_gssproxy()
     http.start()
@@ -1901,7 +1875,7 @@ def upgrade_configuration():
                 dnskeysyncd.create_instance(fqdn, api.env.realm)
                 dnskeysyncd.start_dnskeysyncd()
             else:
-                if dnssec_set_openssl_engine(dnskeysyncd):
+                if dnssec_set_openssl_provider(dnskeysyncd):
                     dnskeysyncd.start_dnskeysyncd()
             dnskeysyncd.set_dyndb_ldap_workdir_permissions()
 
@@ -2060,7 +2034,7 @@ def empty_ccache():
         if old_path:
             os.environ['KRB5CCNAME'] = old_path
         else:
-            del os.environ['KRB5CCNAME']
+            os.environ.pop('KRB5CCNAME', None)
         shutil.rmtree(kpath_dir)
 
 
