@@ -59,6 +59,8 @@ def print_msg(message, output_fd=sys.stdout):
 
 def format_seconds(seconds):
     """Format a number of seconds as an English minutes+seconds message"""
+    if type(seconds) is not int:
+        return seconds
     parts = []
     minutes, seconds = divmod(seconds, 60)
     if minutes:
@@ -539,7 +541,7 @@ class Service:
             pass
         else:
             with open(cafile, 'wb') as fd:
-                for cert, _unused1, _unused2, _unused3 in ca_certs:
+                for cert, _unused1, _unused2, _unused3, _unused4 in ca_certs:
                     fd.write(cert.public_bytes(x509.Encoding.PEM))
 
     def export_ca_certs_nssdb(self, db, ca_is_configured, conn=None):
@@ -559,7 +561,7 @@ class Service:
         except errors.NotFound:
             pass
         else:
-            for cert, nickname, trust_flags in ca_certs:
+            for cert, nickname, trust_flags, _serial in ca_certs:
                 db.add_cert(cert, nickname, trust_flags)
 
     def is_configured(self):
@@ -660,7 +662,7 @@ class Service:
                 else:
                     end_message = "Done configuring %s." % self.service_desc
 
-        if runtime is not None and runtime > 0:
+        if runtime is not None or (type(runtime) is int and runtime > 0):
             self.print_msg('%s. Estimated time: %s' % (start_message,
                                                       format_seconds(runtime)))
         else:
