@@ -36,7 +36,12 @@ from ipalib import api
 from ipalib import errors, messages
 from ipalib import x509
 from ipalib import ngettext
-from ipalib.constants import IPA_CA_CN, IPA_CA_RECORD
+from ipalib.constants import (
+    IPA_CA_CN,
+    IPA_CA_RECORD,
+    CA_TRACKING_REQS,
+    KRA_TRACKING_REQS
+)
 from ipalib.crud import Create, PKQuery, Retrieve, Search
 from ipalib.frontend import Method, Object
 from ipalib.parameters import (
@@ -57,6 +62,7 @@ from ipaserver.plugins.service import normalize_principal, validate_realm
 from ipaserver.masters import (
     ENABLED_SERVICE, CONFIGURED_SERVICE, HIDDEN_SERVICE, is_service_enabled
 )
+from ipaserver.install import installutils
 
 try:
     import pyhbac
@@ -163,6 +169,8 @@ register = Registry()
 
 PKIDATE_FORMAT = '%Y-%m-%d'
 
+CA_SERVER_REQ = {'Server-Cert cert-pki-ca': 'caServerCert',}
+
 
 def _acl_make_request(principal_type, principal, ca_id, profile_id):
     """Construct HBAC request for the given principal, CA and profile"""
@@ -666,7 +674,100 @@ class cert_request(Create, BaseCertMethod, VirtualCommand):
         Binding with a user principal one needs to be in the request_certs
         taskgroup (directly or indirectly via role membership).
         """
+        casubsystem_profile = False
         principal_arg = kw.get('principal')
+        op_account = getattr(context, 'principal', None)
+        logger.debug(
+            "Requesting cert for principal %s from principal %s with "
+            "profile %s", principal_arg, op_account, profile_id
+        )
+        if (
+            op_account
+            and profile_id in (
+                self.Backend.ra.OCSP_PROFILE,
+                self.Backend.ra.SUBSYSTEM_PROFILE,
+                self.Backend.ra.AUDIT_PROFILE,
+                self.Backend.ra.CACERT_PROFILE,
+                self.Backend.ra.CASERVER_PROFILE,
+                self.Backend.ra.KRA_AUDIT_PROFILE,
+                self.Backend.ra.KRA_STORAGE_PROFILE,
+                self.Backend.ra.KRA_TRANSPORT_PROFILE
+            )
+        ):
+            # Here we validate for these CA/KRA profiles:
+            #  1. the requesting principal is a host
+            #  2. the requesting principal is an IPA server
+            #  3. the subject of the CSR matches the expected
+            #     subject for this profile type
+            host_principal = kerberos.Principal(op_account)
+            if principal_to_principal_type(host_principal) != HOST:
+                raise errors.NotFound(
+                    reason=_(
+                        "Certificate request for profile '%s' was not "
+                        "requested from a host", profile_id)
+                )
+            try:
+                self.api.Command.server_show(host_principal.hostname)
+            except errors.NotFound:
+                raise errors.NotFound(
+                    reason=_(
+                        "Certificate request for profile '%s' was not "
+                        "requested from an IPA server", profile_id)
+                )
+            reqs = CA_TRACKING_REQS.items()
+            reqs = itertools.chain(reqs, CA_SERVER_REQ.items())
+            if api.Command.kra_is_enabled()['result']:
+                reqs = itertools.chain(reqs,
+                                       KRA_TRACKING_REQS.items())
+            nickname = []
+            for nick, prof in reqs:
+                if prof == profile_id:
+                    if prof == "caSubsystemCert":
+                        # this profile is used for both the CA subsystem cert
+                        # and the RA agent certificate so we have to accept
+                        # the CSR subject.
+                        if not nickname:
+                            nickname.append('ipaCert')
+                    nickname.append(nick)
+            subject_dn = None
+            if nickname:
+                logger.debug("Requested CA/KRA nickname %s", nickname)
+                subject_base = installutils.find_subject_base()
+                ca_subject_dn = installutils.lookup_ca_subject(
+                    api, subject_base)
+                nickname_by_subject_dn = (
+                    installutils.get_nickname_by_subject_dn(
+                        subject_base, ca_subject_dn)
+                )
+                for sub_dn, nick in nickname_by_subject_dn.items():
+                    if nick in nickname:
+                        if len(nickname) == 1:
+                            subject_dn = sub_dn
+                            break
+                        if sub_dn == DN(csr.subject):
+                            # fallback for caSubsystemCert
+                            subject_dn = sub_dn
+                            break
+                if subject_dn:
+                    if subject_dn != DN(csr.subject):
+                        raise errors.NotFound(
+                            reason=_(
+                                "CSR subject mismatch, {expected} vs "
+                                "{csr}".format(
+                                    expected=subject_dn, csr=csr.subject
+                                )
+                            )
+                        )
+                    else:
+                        logger.debug("Found subject %s", subject_dn)
+            else:
+                raise errors.NotFound(
+                    reason=_(
+                        "Invalid subject '{subject}' for profile "
+                        "'{profile}'".format(
+                            subject=csr.subject, profile=profile_id))
+                )
+            casubsystem_profile = True
 
         if principal_to_principal_type(principal_arg) == KRBTGT:
             principal_obj = None
@@ -710,17 +811,18 @@ class cert_request(Create, BaseCertMethod, VirtualCommand):
             # Can the bound principal request certs for another principal?
             self.check_access()
 
-        try:
-            self.check_access("request certificate ignore caacl")
-            bypass_caacl = True
-        except errors.ACIError:
-            bypass_caacl = False
+        if not casubsystem_profile:
+            try:
+                self.check_access("request certificate ignore caacl")
+                bypass_caacl = True
+            except errors.ACIError:
+                bypass_caacl = False
 
-        if not bypass_caacl:
-            if principal_type == KRBTGT:
-                ca_kdc_check(self.api, bind_principal.hostname)
-            else:
-                caacl_check(principal, ca, profile_id)
+            if not bypass_caacl:
+                if principal_type == KRBTGT:
+                    ca_kdc_check(self.api, bind_principal.hostname)
+                else:
+                    caacl_check(principal, ca, profile_id)
 
         try:
             ext_san = csr.extensions.get_extension_for_oid(
@@ -738,7 +840,7 @@ class cert_request(Create, BaseCertMethod, VirtualCommand):
                 error=_("No Common Name was found in subject of request."))
         cn = cns[-1].value  # "most specific" is end of list
 
-        if principal_type in (SERVICE, HOST):
+        if principal_type in (SERVICE, HOST) and not casubsystem_profile:
             if not _dns_name_matches_principal(cn, principal, principal_obj):
                 raise errors.ValidationError(
                     name='csr',
@@ -966,23 +1068,24 @@ class cert_request(Create, BaseCertMethod, VirtualCommand):
 
         # Success? Then add it to the principal's entry
         # (unless the profile tells us not to)
-        profile = api.Command['certprofile_show'](profile_id)
-        store = profile['result']['ipacertprofilestoreissued'][0]
-        if store and 'certificate' in result:
-            cert = result.get('certificate')
-            kwargs = dict(addattr=u'usercertificate={}'.format(cert))
-            # note: we call different commands for the different
-            # principal types because handling of 'userCertificate'
-            # vs. 'userCertificate;binary' varies by plugin.
-            if principal_type == SERVICE:
-                api.Command['service_mod'](principal_string, **kwargs)
-            elif principal_type == HOST:
-                api.Command['host_mod'](principal.hostname, **kwargs)
-            elif principal_type == USER:
-                api.Command['user_mod'](principal.username, **kwargs)
-            elif principal_type == KRBTGT:
-                logger.error("Profiles used to store cert should't be "
-                             "used for krbtgt certificates")
+        if not casubsystem_profile:
+            profile = api.Command['certprofile_show'](profile_id)
+            store = profile['result']['ipacertprofilestoreissued'][0]
+            if store and 'certificate' in result:
+                cert = result.get('certificate')
+                kwargs = dict(addattr=u'usercertificate={}'.format(cert))
+                # note: we call different commands for the different
+                # principal types because handling of 'userCertificate'
+                # vs. 'userCertificate;binary' varies by plugin.
+                if principal_type == SERVICE:
+                    api.Command['service_mod'](principal_string, **kwargs)
+                elif principal_type == HOST:
+                    api.Command['host_mod'](principal.hostname, **kwargs)
+                elif principal_type == USER:
+                    api.Command['user_mod'](principal.username, **kwargs)
+                elif principal_type == KRBTGT:
+                    logger.error("Profiles used to store cert should't be "
+                                 "used for krbtgt certificates")
 
         if 'certificate_chain' in ca_obj:
             cert = x509.load_der_x509_certificate(
@@ -1721,7 +1824,8 @@ class cert_find(Search, CertMethod):
             try:
                 ca_obj = ca_objs[issuer]
             except KeyError:
-                continue
+                # A deleted LWCA? Return the issuer DN as a string
+                ca_obj = {'cn': [str(issuer)]}
 
             if pkey_only:
                 obj = {'serial_number': serial_number}
@@ -1905,8 +2009,16 @@ class cert_find(Search, CertMethod):
                     try:
                         ca_obj = ca_objs[cacn]
                     except KeyError:
-                        ca_obj = ca_objs[cacn] = (
-                            self.api.Command.ca_show(cacn, all=True)['result'])
+                        try:
+                            ca_obj = ca_objs[cacn] = (
+                                self.api.Command.ca_show(
+                                    cacn, all=True)['result'])
+                        except errors.NotFound:
+                            # If we have inserted a CA DN because the
+                            # LWCA was deleted then ca-show of it will
+                            # fail as NotFound. There is no chain to
+                            # retrieve.
+                            ca_obj = []
 
                     obj.update(
                         ra.get_certificate(serial_number)
