@@ -17,6 +17,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
+
+import logging
 import re
 from ldap import MOD_ADD
 from ldap import SCOPE_BASE, SCOPE_ONELEVEL, SCOPE_SUBTREE
@@ -27,18 +30,15 @@ from ipalib import api, errors, output
 from ipalib import Command, Password, Str, Flag, StrEnum, DNParam, Bool
 from ipalib.cli import to_cli
 from ipalib.plugable import Registry
-from .user import NO_UPG_MAGIC
-if api.env.in_server and api.env.context in ['lite', 'server']:
-    try:
-        from ipaserver.plugins.ldap2 import ldap2
-    except Exception as e:
-        raise e
+from ipaserver.plugins.user import NO_UPG_MAGIC
 from ipalib import _
 from ipapython.dn import DN
+from ipapython.ipaldap import LDAPClient
 from ipapython.ipautil import write_tmp_file
 from ipapython.kerberos import Principal
 import datetime
 from ipaplatform.paths import paths
+from ipaplatform.constants import constants as platformconstants
 
 if six.PY3:
     unicode = str
@@ -136,6 +136,8 @@ for each user added plus a summary when the default user group is
 updated.
 """)
 
+logger = logging.getLogger(__name__)
+
 register = Registry()
 
 # USER MIGRATION CALLBACKS AND VARS
@@ -181,10 +183,9 @@ def _create_kerberos_principals(ldap, pkey, entry_attrs, failed):
 
 def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs):
     assert isinstance(dn, DN)
-    attr_blacklist = ['krbprincipalkey','memberofindirect','memberindirect']
-    attr_blacklist.extend(kwargs.get('attr_blacklist', []))
+    attr_blocklist = ['krbprincipalkey','memberofindirect','memberindirect']
+    attr_blocklist.extend(kwargs.get('attr_blocklist', []))
     ds_ldap = ctx['ds_ldap']
-    has_upg = ctx['has_upg']
     search_bases = kwargs.get('search_bases', None)
     valid_gids = kwargs['valid_gids']
     invalid_gids = kwargs['invalid_gids']
@@ -195,8 +196,9 @@ def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs
         # See if the gidNumber at least points to a valid group on the remote
         # server.
         if entry_attrs['gidnumber'][0] in invalid_gids:
-            api.log.warning('GID number %s of migrated user %s does not point to a known group.' \
-                         % (entry_attrs['gidnumber'][0], pkey))
+            logger.warning('GID number %s of migrated user %s does not point '
+                           'to a known group.',
+                           entry_attrs['gidnumber'][0], pkey)
         elif entry_attrs['gidnumber'][0] not in valid_gids:
             try:
                 remote_entry = ds_ldap.find_entry_by_attr(
@@ -205,15 +207,18 @@ def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs
                 )
                 valid_gids.add(entry_attrs['gidnumber'][0])
             except errors.NotFound:
-                api.log.warning('GID number %s of migrated user %s does not point to a known group.' \
-                             % (entry_attrs['gidnumber'][0], pkey))
+                logger.warning('GID number %s of migrated user %s does not '
+                               'point to a known group.',
+                               entry_attrs['gidnumber'][0], pkey)
                 invalid_gids.add(entry_attrs['gidnumber'][0])
             except errors.SingleMatchExpected as e:
                 # GID number matched more groups, this should not happen
-                api.log.warning('GID number %s of migrated user %s should match 1 group, but it matched %d groups' \
-                             % (entry_attrs['gidnumber'][0], pkey, e.found))
-            except errors.LimitsExceeded as e:
-                api.log.warning('Search limit exceeded searching for GID %s' % entry_attrs['gidnumber'][0])
+                logger.warning('GID number %s of migrated user %s should '
+                               'match 1 group, but it matched %d groups',
+                               entry_attrs['gidnumber'][0], pkey, e.found)
+            except errors.LimitsExceeded:
+                logger.warning('Search limit exceeded searching for GID %s',
+                               entry_attrs['gidnumber'][0])
 
     # We don't want to create a UPG so set the magic value in description
     # to let the DS plugin know.
@@ -229,16 +234,17 @@ def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs
         entry_attrs['homedirectory'] = home_dir
 
     if 'loginshell' not in entry_attrs:
-        default_shell = config.get('ipadefaultloginshell', [paths.SH])[0]
+        default_shell = config.get('ipadefaultloginshell',
+                                   [platformconstants.DEFAULT_SHELL])[0]
         entry_attrs.setdefault('loginshell', default_shell)
 
     # do not migrate all attributes
-    for attr in attr_blacklist:
+    for attr in attr_blocklist:
         entry_attrs.pop(attr, None)
 
     # do not migrate all object classes
     if 'objectclass' in entry_attrs:
-        for object_class in kwargs.get('oc_blacklist', []):
+        for object_class in kwargs.get('oc_blocklist', []):
             try:
                 entry_attrs['objectclass'].remove(object_class)
             except ValueError:  # object class not present
@@ -256,19 +262,22 @@ def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs
                     # value is not DN instance, the automatic encoding may have
                     # failed due to missing schema or the remote attribute type OID was
                     # not detected as DN type. Try to work this around
-                    api.log.debug('%s: value %s of type %s in attribute %s is not a DN'
-                        ', convert it', pkey, value, type(value), attr)
+                    logger.debug('%s: value %s of type %s in attribute %s is '
+                                 'not a DN, convert it',
+                                 pkey, value, type(value), attr)
                     try:
                         value = DN(value)
                     except ValueError as e:
-                        api.log.warning('%s: skipping normalization of value %s of type %s '
-                            'in attribute %s which could not be converted to DN: %s',
-                                pkey, value, type(value), attr, e)
+                        logger.warning('%s: skipping normalization of value '
+                                       '%s of type %s in attribute %s which '
+                                       'could not be converted to DN: %s',
+                                       pkey, value, type(value), attr, e)
                         continue
                 try:
                     remote_entry = ds_ldap.get_entry(value, [api.Object.user.primary_key.name, api.Object.group.primary_key.name])
                 except errors.NotFound:
-                    api.log.warning('%s: attribute %s refers to non-existent entry %s' % (pkey, attr, value))
+                    logger.warning('%s: attribute %s refers to non-existent '
+                                   'entry %s', pkey, attr, value)
                     continue
                 if value.endswith(search_bases['user']):
                     primary_key = api.Object.user.primary_key.name
@@ -277,14 +286,18 @@ def _pre_migrate_user(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwargs
                     primary_key = api.Object.group.primary_key.name
                     container = api.env.container_group
                 else:
-                    api.log.warning('%s: value %s in attribute %s does not belong into any known container' % (pkey, value, attr))
+                    logger.warning('%s: value %s in attribute %s does not '
+                                   'belong into any known container',
+                                   pkey, value, attr)
                     continue
 
                 if not remote_entry.get(primary_key):
-                    api.log.warning('%s: there is no primary key %s to migrate for %s' % (pkey, primary_key, attr))
+                    logger.warning('%s: there is no primary key %s to migrate '
+                                   'for %s', pkey, primary_key, attr)
                     continue
 
-                api.log.debug('converting DN value %s for %s in %s' % (value, attr, dn))
+                logger.debug('converting DN value %s for %s in %s',
+                             value, attr, dn)
                 rdnval = remote_entry[primary_key][0].lower()
                 entry_attrs[attr][ind] = DN((primary_key, rdnval), container, api.env.basedn)
 
@@ -316,11 +329,11 @@ def _update_default_group(ldap, ctx, force):
         s = datetime.datetime.now()
         searchfilter = "(&(objectclass=posixAccount)(!(memberof=%s)))" % group_dn
         try:
-            (result, truncated) = ldap.find_entries(searchfilter,
-                [''], DN(api.env.container_user, api.env.basedn),
+            result, _truncated = ldap.find_entries(
+                searchfilter, [''], DN(api.env.container_user, api.env.basedn),
                 scope=ldap.SCOPE_SUBTREE, time_limit=-1, size_limit=-1)
         except errors.NotFound:
-            api.log.debug('All users have default group set')
+            logger.debug('All users have default group set')
             return
 
         member_dns = [m.dn for m in result]
@@ -329,14 +342,14 @@ def _update_default_group(ldap, ctx, force):
             with ldap.error_handler():
                 ldap.conn.modify_s(str(group_dn), modlist)
         except errors.DatabaseError as e:
-            api.log.error('Adding new members to default group failed: %s \n'
-                          'members: %s', e, ','.join(member_dns))
+            logger.error('Adding new members to default group failed: %s \n'
+                         'members: %s', e, ','.join(member_dns))
 
         e = datetime.datetime.now()
         d = e - s
         mode = " (forced)" if force else ""
-        api.log.info('Adding %d users to group%s duration %s',
-                      len(member_dns), mode, d)
+        logger.info('Adding %d users to group%s duration %s',
+                    len(member_dns), mode, d)
 
 # GROUP MIGRATION CALLBACKS AND VARS
 
@@ -354,24 +367,25 @@ def _pre_migrate_group(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwarg
             except ValueError as e:
                 # This should be impossible unless the remote server
                 # doesn't enforce syntax checking.
-                api.log.error('Malformed DN %s: %s'  % (m, e))
+                logger.error('Malformed DN %s: %s', m, e)
                 continue
             try:
                 rdnval = m[0].value
             except IndexError:
-                api.log.error('Malformed DN %s has no RDN?' % m)
+                logger.error('Malformed DN %s has no RDN?', m)
                 continue
 
             if m.endswith(search_bases['user']):
-                api.log.debug('migrating %s user %s', member_attr, m)
+                logger.debug('migrating %s user %s', member_attr, m)
                 m = DN((api.Object.user.primary_key.name, rdnval),
                        api.env.container_user, api.env.basedn)
             elif m.endswith(search_bases['group']):
-                api.log.debug('migrating %s group %s', member_attr, m)
+                logger.debug('migrating %s group %s', member_attr, m)
                 m = DN((api.Object.group.primary_key.name, rdnval),
                        api.env.container_group, api.env.basedn)
             else:
-                api.log.error('entry %s does not belong into any known container' % m)
+                logger.error('entry %s does not belong into any known '
+                             'container', m)
                 continue
 
             new_members.append(m)
@@ -394,8 +408,8 @@ def _pre_migrate_group(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwarg
         entry_attrs['member'] = new_members
 
     assert isinstance(dn, DN)
-    attr_blacklist = ['memberofindirect','memberindirect']
-    attr_blacklist.extend(kwargs.get('attr_blacklist', []))
+    attr_blocklist = ['memberofindirect','memberindirect']
+    attr_blocklist.extend(kwargs.get('attr_blocklist', []))
 
     schema = kwargs.get('schema', None)
     entry_attrs['ipauniqueid'] = 'autogenerate'
@@ -412,12 +426,12 @@ def _pre_migrate_group(ldap, pkey, dn, entry_attrs, failed, config, ctx, **kwarg
         raise ValueError('Schema %s not supported' % schema)
 
     # do not migrate all attributes
-    for attr in attr_blacklist:
+    for attr in attr_blocklist:
         entry_attrs.pop(attr, None)
 
     # do not migrate all object classes
     if 'objectclass' in entry_attrs:
-        for object_class in kwargs.get('oc_blacklist', []):
+        for object_class in kwargs.get('oc_blocklist', []):
             try:
                 entry_attrs['objectclass'].remove(object_class)
             except ValueError:  # object class not present
@@ -457,7 +471,7 @@ def construct_filter(template, oc_list):
     return template % oc_subfilter
 
 def validate_ldapuri(ugettext, ldapuri):
-    m = re.match('^ldaps?://[-\w\.]+(:\d+)?$', ldapuri)
+    m = re.match(r'^ldaps?://[-\w\.]+(:\d+)?$', ldapuri)
     if not m:
         err_msg = _('Invalid LDAP URI.')
         raise errors.ValidationError(name='ldap_uri', error=err_msg)
@@ -491,8 +505,8 @@ class migrate_ds(Command):
         'user': {
             'filter_template' : '(&(|%s)(uid=*))',
             'oc_option' : 'userobjectclass',
-            'oc_blacklist_option' : 'userignoreobjectclass',
-            'attr_blacklist_option' : 'userignoreattribute',
+            'oc_blocklist_option' : 'userignoreobjectclass',
+            'attr_blocklist_option' : 'userignoreattribute',
             'pre_callback' : _pre_migrate_user,
             'post_callback' : _post_migrate_user,
             'exc_callback' : None
@@ -500,8 +514,8 @@ class migrate_ds(Command):
         'group': {
             'filter_template' : '(&(|%s)(cn=*))',
             'oc_option' : 'groupobjectclass',
-            'oc_blacklist_option' : 'groupignoreobjectclass',
-            'attr_blacklist_option' : 'groupignoreattribute',
+            'oc_blocklist_option' : 'groupignoreobjectclass',
+            'attr_blocklist_option' : 'groupignoreattribute',
             'pre_callback' : _pre_migrate_group,
             'post_callback' : None,
             'exc_callback' : _group_exc_callback,
@@ -622,24 +636,24 @@ class migrate_ds(Command):
             doc=_('Load CA certificate of LDAP server from FILE'),
             default=None,
             noextrawhitespace=False,
-        ),
+            ),
         Bool('use_def_group?',
-            cli_name='use_default_group',
-            label=_('Add to default group'),
-            doc=_('Add migrated users without a group to a default group '
-                  '(default: true)'),
-            default=True,
-            autofill=True,
-        ),
+             cli_name='use_default_group',
+             label=_('Add to default group'),
+             doc=_('Add migrated users without a group to a default group '
+                   '(default: true)'),
+             default=True,
+             autofill=True,
+             ),
         StrEnum('scope',
-            cli_name='scope',
-            label=_('Search scope'),
-            doc=_('LDAP search scope for users and groups: base, onelevel, or '
-                  'subtree. Defaults to onelevel'),
-            values=tuple(_supported_scopes.keys()),
-            default=_default_scope,
-            autofill=True,
-        ),
+                cli_name='scope',
+                label=_('Search scope'),
+                doc=_('LDAP search scope for users and groups: base, '
+                      'onelevel, or subtree. Defaults to onelevel'),
+                values=sorted(_supported_scopes),
+                default=_default_scope,
+                autofill=True,
+                ),
     )
 
     has_output = (
@@ -747,8 +761,7 @@ migration process might be incomplete\n''')
                 entries, truncated = ds_ldap.find_entries(
                     search_filter, ['*'], search_bases[ldap_obj_name],
                     scope,
-                    time_limit=0, size_limit=-1,
-                    search_refs=True    # migrated DS may contain search references
+                    time_limit=0, size_limit=-1
                 )
             except errors.NotFound:
                 if not options.get('continue',False):
@@ -764,19 +777,22 @@ migration process might be incomplete\n''')
                     truncated = False
                     entries = []
             if truncated:
-                self.log.error(
-                    '%s: %s' % (
-                        ldap_obj.name, self.truncated_err_msg
-                    )
+                logger.error(
+                    '%s: %s',
+                    ldap_obj.name, self.truncated_err_msg
                 )
 
-            blacklists = {}
-            for blacklist in ('oc_blacklist', 'attr_blacklist'):
-                blacklist_option = self.migrate_objects[ldap_obj_name][blacklist+'_option']
-                if blacklist_option is not None:
-                    blacklists[blacklist] = options.get(blacklist_option, tuple())
+            blocklists = {}
+            for blocklist in ('oc_blocklist', 'attr_blocklist'):
+                blocklist_option = (
+                    self.migrate_objects[ldap_obj_name][blocklist + '_option']
+                )
+                if blocklist_option is not None:
+                    blocklists[blocklist] = options.get(
+                        blocklist_option, tuple()
+                    )
                 else:
-                    blacklists[blacklist] = tuple()
+                    blocklists[blocklist] = tuple()
 
             # get default primary group for new users
             if 'def_group_dn' not in context and options.get('use_def_group'):
@@ -830,7 +846,7 @@ migration process might be incomplete\n''')
                             search_bases=search_bases,
                             valid_gids=valid_gids,
                             invalid_gids=invalid_gids,
-                            **blacklists
+                            **blocklists
                         )
                         if not entry_attrs.dn:
                             continue
@@ -846,8 +862,8 @@ migration process might be incomplete\n''')
                         try:
                             callback(
                                 ldap, entry_attrs.dn, entry_attrs, e, options)
-                        except errors.ExecutionError as e:
-                            failed[ldap_obj_name][pkey] = unicode(e)
+                        except errors.ExecutionError as e2:
+                            failed[ldap_obj_name][pkey] = unicode(e2)
                             continue
                     else:
                         failed[ldap_obj_name][pkey] = unicode(e)
@@ -865,8 +881,10 @@ migration process might be incomplete\n''')
                 total_dur = e - migration_start
                 migrate_cnt += 1
                 if migrate_cnt > 0 and migrate_cnt % 100 == 0:
-                    api.log.info("%d %ss migrated. %s elapsed." % (migrate_cnt, ldap_obj_name, total_dur))
-                api.log.debug("%d %ss migrated, duration: %s (total %s)" % (migrate_cnt, ldap_obj_name, d, total_dur))
+                    logger.info("%d %ss migrated. %s elapsed.",
+                                migrate_cnt, ldap_obj_name, total_dur)
+                logger.debug("%d %ss migrated, duration: %s (total %s)",
+                             migrate_cnt, ldap_obj_name, d, total_dur)
 
         if 'def_group_dn' in context:
             _update_default_group(ldap, context, True)
@@ -883,37 +901,36 @@ migration process might be incomplete\n''')
             assert isinstance(ds_base_dn, DN)
 
         # check if migration mode is enabled
-        if config.get('ipamigrationenabled', ('FALSE', ))[0] == 'FALSE':
+        if not config.get('ipamigrationenabled', (False,))[0]:
             return dict(result={}, failed={}, enabled=False, compat=True)
 
         # connect to DS
-        ds_ldap = ldap2(self.api, ldap_uri=ldapuri)
-
-        cacert = None
         if options.get('cacertfile') is not None:
-            #store CA cert into file
+            # store CA cert into file
             tmp_ca_cert_f = write_tmp_file(options['cacertfile'])
             cacert = tmp_ca_cert_f.name
 
-            #start TLS connection
-            ds_ldap.connect(bind_dn=options['binddn'], bind_pw=bindpw,
-                tls_cacertfile=cacert)
+            # start TLS connection or STARTTLS
+            ds_ldap = LDAPClient(ldapuri, cacert=cacert, start_tls=True)
+            ds_ldap.simple_bind(options['binddn'], bindpw)
 
             tmp_ca_cert_f.close()
         else:
-            ds_ldap.connect(bind_dn=options['binddn'], bind_pw=bindpw)
+            ds_ldap = LDAPClient(ldapuri)
+            ds_ldap.simple_bind(options['binddn'], bindpw, insecure_bind=True)
 
-        #check whether the compat plugin is enabled
+        # check whether the compat plugin is enabled
         if not options.get('compat'):
             try:
-                ldap.get_entry(DN(('cn', 'compat'), (api.env.basedn)))
+                ldap.get_entry(DN(('cn', 'users'), ('cn', 'compat'),
+                                  (api.env.basedn)))
                 return dict(result={}, failed={}, enabled=True, compat=False)
             except errors.NotFound:
                 pass
 
         if not ds_base_dn:
             # retrieve base DN from remote LDAP server
-            entries, truncated = ds_ldap.find_entries(
+            entries, _truncated = ds_ldap.find_entries(
                 '', ['namingcontexts', 'defaultnamingcontext'], DN(''),
                 ds_ldap.SCOPE_BASE, size_limit=-1, time_limit=0,
             )
