@@ -265,6 +265,12 @@ class subid(LDAPObject):
 
     def handle_subordinate_ids(self, ldap, dn, entry_attrs):
         """Handle ipaSubordinateId object class"""
+
+        if self.api.Object.config.is_config_option_present('SubID:Disable'):
+            raise errors.ValidationError(
+                name="configuration state",
+                error=_("Support for subordinate IDs is disabled"))
+
         new_subuid = entry_attrs.single_value.get("ipasubuidnumber")
         new_subgid = entry_attrs.single_value.get("ipasubgidnumber")
 
@@ -577,6 +583,11 @@ class subid_stats(LDAPQuery):
         return int(entry.single_value["numSubordinates"])
 
     def execute(self, *keys, **options):
+        if self.api.Object.config.is_config_option_present('SubID:Disable'):
+            raise errors.ValidationError(
+                name="configuration state",
+                error=_("Support for subordinate IDs is disabled"))
+
         ldap = self.obj.backend
         dna_remaining = self.get_remaining_dna(ldap, **options)
         baseid, rangesize = self.get_idrange(ldap, **options)
