@@ -26,7 +26,7 @@ from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.x509.oid import NameOID
-from pkg_resources import parse_version
+from packaging.version import parse as parse_version
 from pyasn1.type import univ, char, namedtype, tag
 from pyasn1.codec.der import encoder as der_encoder
 from pyasn1.codec.native import decoder as native_decoder
@@ -199,6 +199,20 @@ def profile_server(builder, ca_nick, ca,
             critical=False,
         )
 
+    if ca:
+        try:
+            ski_ext = ca.cert.extensions.get_extension_for_class(
+                x509.SubjectKeyIdentifier)
+            builder = builder.add_extension(
+                x509.AuthorityKeyIdentifier.from_issuer_subject_key_identifier(
+                    ski_ext.value
+                ),
+                critical=False,
+            )
+        except x509.ExtensionNotFound:
+            # if the CA doesn't have a SKI, just ignore
+            pass
+
     if badusage:
         builder = builder.add_extension(
             x509.KeyUsage(
@@ -214,6 +228,26 @@ def profile_server(builder, ca_nick, ca,
             ),
             critical=False
         )
+    else:
+        builder = builder.add_extension(
+            x509.KeyUsage(
+                digital_signature=True,
+                content_commitment=False,
+                key_encipherment=True,
+                data_encipherment=True,
+                key_agreement=False,
+                key_cert_sign=False,
+                crl_sign=False,
+                encipher_only=False,
+                decipher_only=False
+            ),
+            critical=False
+        )
+
+    builder = builder.add_extension(
+        x509.ExtendedKeyUsage([x509.ObjectIdentifier('1.3.6.1.5.5.7.3.1')]),
+        critical=False,
+    )
 
     if wildcard:
         names = [x509.DNSName(u'*.' + domain)]
