@@ -1,13 +1,12 @@
 import contextlib
 import os
+from io import StringIO
 import shlex
 import subprocess
 import sys
 import tempfile
-import unittest
 
 import six
-from six import StringIO
 
 from ipatests import util
 from ipatests.test_ipalib.test_x509 import goodcert_headers
@@ -25,7 +24,7 @@ BASE_DIR = os.path.abspath(os.path.join(HERE, os.pardir, os.pardir))
 
 @pytest.mark.tier0
 @pytest.mark.needs_ipaapi
-class TestCLIParsing(object):
+class TestCLIParsing:
     """Tests that commandlines are correctly parsed to Command keyword args
     """
     def check_command(self, commandline, expected_command_name, **kw_expected):
@@ -45,8 +44,8 @@ class TestCLIParsing(object):
         try:
             api.Command[command_name](**kw)
         except errors.NetworkError:
-            raise unittest.SkipTest('%r: Server not available: %r' %
-                                (self.__module__, api.env.xmlrpc_uri))
+            pytest.skip('%r: Server not available: %r' %
+                        (self.__module__, api.env.xmlrpc_uri))
 
     @contextlib.contextmanager
     def fake_stdin(self, string_in):
@@ -124,7 +123,7 @@ class TestCLIParsing(object):
         try:
             self.run_command('dnszone_add', idnsname=TEST_ZONE)
         except errors.NotFound:
-            raise unittest.SkipTest('DNS is not configured')
+            pytest.skip('DNS is not configured')
         try:
             self.run_command('dnsrecord_add',
                 dnszoneidnsname=TEST_ZONE,
@@ -152,7 +151,7 @@ class TestCLIParsing(object):
         try:
             self.run_command('dnszone_add', idnsname=TEST_ZONE)
         except errors.NotFound:
-            raise unittest.SkipTest('DNS is not configured')
+            pytest.skip('DNS is not configured')
         try:
             records = (u'1 1 E3B72BA346B90570EED94BE9334E34AA795CED23',
                        u'2 1 FD2693C1EFFC11A8D2BE57229212A04B45663791')
@@ -232,7 +231,7 @@ class TestCLIParsing(object):
             self.run_command(
                 'dnszone_add', idnsname=TEST_ZONE)
         except errors.NotFound:
-            raise unittest.SkipTest('DNS is not configured')
+            pytest.skip('DNS is not configured')
         try:
             self.run_command(
                 'dnsrecord_add',
@@ -277,25 +276,12 @@ class TestCLIParsing(object):
                 ipasecondarybaserid=u'500000',
             )
 
-        def test_without_options():
-            self.check_command(
-                'idrange_add range1 --base-id=1 --range-size=1',
-                'idrange_add',
-                cn=u'range1',
-                ipabaseid=u'1',
-                ipaidrangesize=u'1',
-            )
-
         adtrust_dn = 'cn=ADTRUST,cn=%s,cn=masters,cn=ipa,cn=etc,%s' % \
                      (api.env.host, api.env.basedn)
         adtrust_is_enabled = api.Command['adtrust_is_enabled']()['result']
         mockldap = None
 
         if not adtrust_is_enabled:
-            # ipa-adtrust-install not run - no need to pass rid-base
-            # and secondary-rid-base
-            test_without_options()
-
             # Create a mock service object to test against
             adtrust_add = dict(
                 ipaconfigstring=b'enabledService',
@@ -367,8 +353,8 @@ IPA_CLIENT_NOT_CONFIGURED = b'IPA client is not configured on this system'
     [
         # Commands delivered by the client pkg
         (['ipa'], 1, None, IPA_CLIENT_NOT_CONFIGURED),
-        (['ipa-certupdate'], 1, None, IPA_CLIENT_NOT_CONFIGURED),
-        (['ipa-client-automount'], 1, IPA_CLIENT_NOT_CONFIGURED, None),
+        (['ipa-certupdate'], 2, None, IPA_CLIENT_NOT_CONFIGURED),
+        (['ipa-client-automount'], 2, IPA_CLIENT_NOT_CONFIGURED, None),
         # Commands delivered by the server pkg
         (['ipa-adtrust-install'], 2, None, IPA_NOT_CONFIGURED),
         (['ipa-advise'], 2, None, IPA_NOT_CONFIGURED),
@@ -377,6 +363,7 @@ IPA_CLIENT_NOT_CONFIGURED = b'IPA client is not configured on this system'
         (['ipa-ca-install'], 1, None,
          b'IPA server is not configured on this system'),
         (['ipa-compat-manage'], 2, None, IPA_NOT_CONFIGURED),
+        (['ipa-crlgen-manage'], 2, None, IPA_NOT_CONFIGURED),
         (['ipa-csreplica-manage'], 1, None, IPA_NOT_CONFIGURED),
         (['ipactl', 'status'], 4, None, b'IPA is not configured'),
         (['ipa-dns-install'], 2, None, IPA_NOT_CONFIGURED),
@@ -385,7 +372,6 @@ IPA_CLIENT_NOT_CONFIGURED = b'IPA client is not configured on this system'
           '/usr/share/ipa/updates/05-pre_upgrade_plugins.update'],
          2, None, IPA_NOT_CONFIGURED),
         (['ipa-managed-entries'], 2, None, IPA_NOT_CONFIGURED),
-        (['ipa-nis-manage'], 2, None, IPA_NOT_CONFIGURED),
         (['ipa-pkinit-manage'], 2, None, IPA_NOT_CONFIGURED),
         (['ipa-replica-manage', 'list'], 1, IPA_NOT_CONFIGURED, None),
         (['ipa-server-certinstall'], 2, None, IPA_NOT_CONFIGURED),
