@@ -1,5 +1,6 @@
 # Copyright (C) 2016  Custodia Project Contributors - see LICENSE file
-import pkg_resources
+import importlib.metadata
+
 import pytest
 
 from ipaserver.custodia.plugin import (
@@ -12,8 +13,8 @@ class TestCustodiaPlugins:
 
     def get_entry_points(self, group):
         eps = []
-        for e in pkg_resources.iter_entry_points(group):
-            if e.dist.project_name != self.project_name:
+        for e in importlib.metadata.entry_points(group=group):
+            if e.dist.name != self.project_name:
                 # only interested in our own entry points
                 continue
             eps.append(e)
@@ -21,11 +22,7 @@ class TestCustodiaPlugins:
 
     def assert_ep(self, ep, basecls):
         try:
-            # backwards compatibility with old setuptools
-            if hasattr(ep, "resolve"):
-                cls = ep.resolve()
-            else:
-                cls = ep.load(require=False)
+            cls = ep.load(require=False)
         except Exception as e:  # pylint: disable=broad-except
             pytest.fail("Failed to load %r: %r" % (ep, e))
         if not issubclass(cls, basecls):
