@@ -17,6 +17,94 @@ from ipaplatform.osinfo import osinfo
 from ipaplatform.paths import paths
 
 
+def apply_enforced_dns_preconfig(host, master_ip, master_host,
+                                 ca_cert_path, dest_cert_name):
+    """
+    Apply pre-configurations required for enforced
+    DNS policy on client and replica.
+
+    Args:
+        host: The host object (client or replica) to configure
+        master_ip: IP address of the IPA server/master
+        master_host: The master host object to get certificate from
+        ca_cert_path: Path to the CA certificate on the master
+        dest_cert_name: Destination certificate filename in trust anchors
+    """
+    # Get the network interface for routing
+    iface_cmd = host.run_command([
+        "bash", "-c",
+        "nmcli -t -f DEVICE c show --active | head -1"
+    ])
+    iface = iface_cmd.stdout_text.strip()
+
+    # Copy CA certificate to trust anchors using file operations
+    ca_cert_data = master_host.get_file_contents(ca_cert_path)
+    dest_ca_path = f"/etc/pki/ca-trust/source/anchors/{dest_cert_name}"
+    host.put_file_contents(dest_ca_path, ca_cert_data)
+    host.run_command(["update-ca-trust", "extract"])
+
+    if osinfo.id in ['rhel', 'centos']:
+        # RHEL/CentOS configuration
+        # Install and configure dnsconfd
+        tasks.install_packages(host, ['dnsconfd'])
+        host.run_command(["dnsconfd", "config", "install"])
+        host.run_command(["systemctl", "enable", "--now", "dnsconfd"])
+        host.run_command(["nmcli", "g", "reload"])
+
+        # Configure DNS over TLS via NetworkManager
+        host.run_command([
+            "nmcli", "device", "modify", iface,
+            "ipv4.dns", f"dns+tls://{master_ip}"
+        ])
+
+    elif osinfo.id == 'fedora':
+        # Fedora configuration
+        # Configure systemd-resolved for DNS over TLS
+        host.run_command([
+            "ln", "-sf", "../run/systemd/resolve/stub-resolv.conf",
+            "/etc/resolv.conf"
+        ])
+        host.run_command(["systemctl", "restart", "systemd-resolved"])
+
+        # Configure DNS over TLS via systemd-resolve
+        host.run_command([
+            "systemd-resolve", "--set-dns", master_ip,
+            "--set-dnsovertls=yes", f"--interface={iface}"
+        ])
+    else:
+        raise ValueError(
+            f"Unsupported OS for enforced DNS policy: {osinfo.id}"
+        )
+
+
+def setup_dns_over_tls_environment(cls):
+    """
+    Setup DNS over TLS environment for test classes.
+
+    Args:
+        cls: The test class with master, replicas, and clients attributes
+    """
+    # Configuration: (host, setup_firewall, install_package)
+    hosts_config = [
+        (cls.master, True, True),
+        (cls.replicas[0], True, True),
+        (cls.clients[0], False, True),
+    ]
+
+    for host, setup_firewall, install_package in hosts_config:
+        # Setup firewall if requested
+        if setup_firewall:
+            Firewall(host).enable_service("dns-over-tls")
+        # Install appropriate package based on host type
+        if install_package:
+            # Detect if client or server based on hostname
+            if 'client' in host.hostname.lower():
+                package = '*ipa-client-encrypted-dns'
+            else:
+                package = '*ipa-server-encrypted-dns'
+            tasks.install_packages(host, [package])
+
+
 def verify_queries_encrypted(master, replicas, clients,
                              forwarder="1.1.1.1#853",
                              dns_hostname="freeipa.org"):
@@ -77,11 +165,7 @@ class TestDNSOverTLS(IntegrationTest):
 
     @classmethod
     def install(cls, mh):
-        Firewall(cls.master).enable_service("dns-over-tls")
-        Firewall(cls.replicas[0]).enable_service("dns-over-tls")
-        tasks.install_packages(cls.master, ['*ipa-server-encrypted-dns'])
-        tasks.install_packages(cls.replicas[0], ['*ipa-server-encrypted-dns'])
-        tasks.install_packages(cls.clients[0], ['*ipa-client-encrypted-dns'])
+        setup_dns_over_tls_environment(cls)
 
     def test_install_dnsovertls_invalid_ca(self):
         """
@@ -201,11 +285,7 @@ class TestDNSOverTLS_RelaxedPolicy(IntegrationTest):
 
     @classmethod
     def install(cls, mh):
-        Firewall(cls.master).enable_service("dns-over-tls")
-        Firewall(cls.replicas[0]).enable_service("dns-over-tls")
-        tasks.install_packages(cls.master, ['*ipa-server-encrypted-dns'])
-        tasks.install_packages(cls.replicas[0], ['*ipa-server-encrypted-dns'])
-        tasks.install_packages(cls.clients[0], ['*ipa-client-encrypted-dns'])
+        setup_dns_over_tls_environment(cls)
 
     def test_dot_relaxed_dns_policy_with_IPA_CA(self):
         """
@@ -340,6 +420,206 @@ class TestDNSOverTLS_RelaxedPolicy(IntegrationTest):
         )
 
 
+@pytest.mark.skipif(
+    osinfo.id == 'fedora' and osinfo.version_number < (42,),
+    reason='Encrypted DNS not supported in Fedora < 42')
+class TestDNSOverTLS_EnforcedPolicy_IPA_CA(IntegrationTest):
+    """Tests for DNS over TLS feature with enforced policy and IPA CA."""
+
+    topology = 'line'
+    num_replicas = 1
+    num_clients = 1
+
+    @classmethod
+    def install(cls, mh):
+        setup_dns_over_tls_environment(cls)
+
+    def test_dot_enforced_dns_policy_with_ipa_ca(self):
+        """
+        This test installs IPA server, replica, and client with
+        --no-dnssec-validation option, enforced DNS policy, and
+        with IPA CA, ensuring all queries are encrypted.
+        """
+        # Install master first with enforced policy
+        args = [
+            "--dns-over-tls",
+            "--dot-forwarder", "1.1.1.1#cloudflare-dns.com",
+            "--no-dnssec-validation",
+            "--dns-policy", "enforced",
+            "--ip-address", self.master.ip
+        ]
+        tasks.install_master(self.master, extra_args=args)
+
+        # Apply pre-configuration on client before installation
+        apply_enforced_dns_preconfig(
+            self.clients[0], self.master.ip, self.master,
+            paths.IPA_CA_CRT, "ca.crt"
+        )
+
+        # Configure client nameserver
+        self.clients[0].put_file_contents(
+            paths.RESOLV_CONF,
+            "nameserver %s" % self.master.ip
+        )
+
+        # Install client with enforced policy
+        args = [
+            "--dns-over-tls",
+            "--no-dnssec-validation",
+            "--ip-address", self.clients[0].ip
+        ]
+        tasks.install_client(
+            self.master,
+            self.clients[0],
+            nameservers=None,
+            extra_args=args
+        )
+
+        # Apply pre-configuration on replica before installation
+        apply_enforced_dns_preconfig(
+            self.replicas[0], self.master.ip, self.master,
+            paths.IPA_CA_CRT, "ipa-ca.crt"
+        )
+
+        # Install replica with enforced policy
+        args = [
+            "--dns-over-tls",
+            "--dot-forwarder", "1.1.1.1#cloudflare-dns.com",
+            "--no-dnssec-validation",
+            "--dns-policy", "enforced"
+        ]
+        tasks.install_replica(
+            self.master,
+            self.replicas[0],
+            setup_dns=True,
+            extra_args=args
+        )
+
+        # Verify that queries are encrypted
+        verify_queries_encrypted(
+            self.master,
+            [self.replicas[0]],
+            [self.clients[0]]
+        )
+
+    def test_uninstall_all_enforced_ipa_ca(self):
+        """
+        This test ensures that all hosts can be uninstalled correctly.
+        """
+        tasks.uninstall_client(self.clients[0])
+        tasks.uninstall_replica(self.master, self.replicas[0])
+        tasks.uninstall_master(self.master)
+
+
+@pytest.mark.skipif(
+    osinfo.id == 'fedora' and osinfo.version_number < (42,),
+    reason='Encrypted DNS not supported in Fedora < 42')
+class TestDNSOverTLS_EnforcedPolicy_External_CA(IntegrationTest):
+    """Tests for DNS over TLS feature with enforced policy and external CA."""
+
+    topology = 'line'
+    num_replicas = 1
+    num_clients = 1
+
+    @classmethod
+    def install(cls, mh):
+        setup_dns_over_tls_environment(cls)
+
+    def test_dot_enforced_dns_policy_with_external_ca(self):
+        """
+        This test installs IPA server, replica, and client with
+        --no-dnssec-validation option, enforced DNS policy, and
+        with external CA, ensuring all queries are encrypted.
+        """
+        # Create external CA cert + key
+        external_ca = ExternalCA(days=36500)
+        cert_pem = external_ca.create_ca()
+        key_pem = external_ca.ca_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.TraditionalOpenSSL,
+            encryption_algorithm=serialization.NoEncryption(),
+        )
+        cert_dest = "/etc/pki/tls/certs/certificate.pem"
+        key_dest = "/etc/pki/tls/certs/privkey.pem"
+
+        self.master.put_file_contents(cert_dest, cert_pem)
+        self.master.put_file_contents(key_dest, key_pem)
+
+        # Install master with external CA and enforced policy
+        args = [
+            "--dns-over-tls",
+            "--dot-forwarder", "1.1.1.1#cloudflare-dns.com",
+            "--dns-over-tls-cert", cert_dest,
+            "--dns-over-tls-key", key_dest,
+            "--no-dnssec-validation",
+            "--dns-policy", "enforced",
+            "--ip-address", self.master.ip
+        ]
+        tasks.install_master(self.master, extra_args=args)
+
+        # Apply pre-configuration on client before installation
+        # (includes CA cert setup)
+        apply_enforced_dns_preconfig(
+            self.clients[0], self.master.ip, self.master,
+            cert_dest, "certificate.pem"
+        )
+
+        # Configure client nameserver
+        self.clients[0].put_file_contents(
+            paths.RESOLV_CONF,
+            "nameserver %s" % self.master.ip
+        )
+
+        # Install client with enforced policy
+        args = [
+            "--dns-over-tls",
+            "--no-dnssec-validation",
+            "--ip-address", self.clients[0].ip
+        ]
+        tasks.install_client(
+            self.master,
+            self.clients[0],
+            nameservers=None,
+            extra_args=args
+        )
+
+        # Apply pre-configuration on replica before installation
+        # (includes CA cert setup)
+        apply_enforced_dns_preconfig(
+            self.replicas[0], self.master.ip, self.master,
+            cert_dest, "certificate.pem"
+        )
+
+        # Install replica with external CA and enforced policy
+        args = [
+            "--dns-over-tls",
+            "--dot-forwarder", "1.1.1.1#cloudflare-dns.com",
+            "--no-dnssec-validation",
+            "--dns-policy", "enforced"
+        ]
+        tasks.install_replica(
+            self.master,
+            self.replicas[0],
+            setup_dns=True,
+            extra_args=args
+        )
+
+        # Verify that queries are encrypted
+        verify_queries_encrypted(
+            self.master,
+            [self.replicas[0]],
+            [self.clients[0]]
+        )
+
+    def test_uninstall_all_enforced_external_ca(self):
+        """
+        This test ensures that all hosts can be uninstalled correctly.
+        """
+        tasks.uninstall_client(self.clients[0])
+        tasks.uninstall_replica(self.master, self.replicas[0])
+        tasks.uninstall_master(self.master)
+
+
 @pytest.mark.skipif(
     osinfo.id == 'fedora' and osinfo.version_number == (41,),
     reason='Encrypted DNS not supported in fedora 41')
