@@ -312,24 +312,26 @@ class TestHSMInstall(BaseHSMTest):
         assert returncode == 0
         assert output == "No issues found."
 
+
+class TestHSMInstallPasswordFile(BaseHSMTest):
+
+    num_replicas = 1
+
+    @classmethod
+    def install(cls, mh):
+        check_version(cls.master)
+        # Enable pkiuser to read softhsm tokens
+        cls.master.run_command(['usermod', 'pkiuser', '-a', '-G', 'ods'])
+        cls.token_name, cls.token_password = get_hsm_token(cls.master)
+        cls.master.put_file_contents(
+            cls.token_password_file, cls.token_password
+        )
+        cls.replicas[0].put_file_contents(
+            cls.token_password_file, cls.token_password
+        )
+
     def test_hsm_install_server_password_file(self):
         check_version(self.master)
-        # cleanup before fresh install with password file
-        for client in self.clients:
-            tasks.uninstall_client(client)
-
-        for replica in self.replicas:
-            tasks.uninstall_master(replica)
-
-        tasks.uninstall_master(self.master)
-
-        delete_hsm_token([self.master] + self.replicas, self.token_name)
-        self.token_name, self.token_password = get_hsm_token(self.master)
-        self.master.put_file_contents(self.token_password_file,
-                                      self.token_password)
-        self.replicas[0].put_file_contents(self.token_password_file,
-                                           self.token_password)
-
         tasks.install_master(
             self.master, setup_dns=self.master_with_dns,
             setup_kra=self.master_with_kra,
@@ -1314,3 +1316,143 @@ class TestHSMVault(BaseHSMTest):
             vault_name,
             "--password", vault_password,
         ])
+
+
+class TestHSMLWCA(BaseHSMTest):
+    """Test that managing a LWCA on an HSM-installed system installs
+       the keys onto the HSM and not the local NSS database.
+
+       Also verify that the ca-* operations can handle hiding the
+       complexity of the token name prefix without specifying it
+       (but also allowing it).
+    """
+
+    num_replicas = 0
+
+    def remove_lwca(self, lwca, othername=None):
+        """Save a lot of duplicate code disabling and removing a lwca"""
+        self.master.run_command([
+            'ipa', 'ca-disable', lwca,
+        ])
+
+        name = othername or lwca
+        self.master.run_command([
+            'ipa', 'ca-del', name,
+        ])
+
+    def test_hsm_add_lwca(self):
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        """First test add/show/disable/delete without specifying
+           the token. So hiding the complexity of including the
+           token name except the stored Name (cn) value.
+        """
+        result = self.master.run_command([
+            'ipa', 'ca-add', lwca, '--subject', 'CN=LWCA',
+        ])
+        assert f'Name: {lwca_fullname}' in result.stdout_text
+
+        self.remove_lwca(lwca)
+
+    def test_hsm_token_add_lwca(self):
+        """Now test add/show/disable/delete with specifying
+           the token with the name. So not hiding the complexity of
+           including the token name.
+        """
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        result = self.master.run_command([
+            'ipa', 'ca-add', lwca_fullname, '--subject', 'CN=LWCA',
+        ])
+        assert f'Name: {lwca_fullname}' in result.stdout_text
+
+        self.remove_lwca(lwca_fullname)
+
+    def test_duplicate_token_add_lwca(self):
+        """Test that adding a duplicate name by adding with and
+           without the token included"""
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        self.master.run_command([
+            'ipa', 'ca-add', lwca_fullname, '--subject', 'CN=LWCA',
+        ])
+        result = self.master.run_command([
+            'ipa', 'ca-add', lwca, '--subject', 'CN=LWCA',
+        ], raiseonerr=False)
+        assert 'Subject DN is already used' in result.stderr_text
+
+        # we can also mix and match the name in the cleanup
+        self.remove_lwca(lwca, lwca_fullname)
+
+    def test_colon_in_lwca(self):
+        """
+        Trying to add a CA using an unknown or mis-typed token
+        name will result in the real token + whatever the name.
+        """
+        lwca = "lwca"
+        colonname = "undefined:{}".format(lwca)
+        colonfullname = "{}:undefined:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        result = self.master.run_command([
+            'ipa', 'ca-add', colonname, '--subject', 'CN=LWCA',
+        ])
+        assert 'Name: {}'.format(colonfullname) in result.stdout_text
+
+        self.remove_lwca(colonfullname, colonname)
+
+    def test_show_lwca(self):
+        """Show a lwca using with and without the token name"""
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        for name in (lwca, lwca_fullname,):
+            result = self.master.run_command([
+                'ipa', 'ca-add', name, '--subject', f'CN={name}',
+            ])
+            assert f'Name: {lwca_fullname}' in result.stdout_text
+            self.master.run_command(['ipa', 'ca-show', name])
+            self.remove_lwca(name)
+
+    def test_find_lwca(self):
+        """Find a lwca using with and without the token name"""
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        for name in (lwca, lwca_fullname,):
+            result = self.master.run_command([
+                'ipa', 'ca-add', name, '--subject', f'CN={name}',
+            ])
+            assert f'Name: {lwca_fullname}' in result.stdout_text
+            self.master.run_command(['ipa', 'ca-find', '--name', name])
+            self.remove_lwca(name)
+
+    def test_mod_lwca(self):
+        """Modify a lwca using with and without the token name"""
+        lwca = "lwca"
+        lwca_fullname = "{}:{}".format(self.token_name, lwca)
+
+        check_version(self.master)
+
+        for name in (lwca, lwca_fullname,):
+            result = self.master.run_command([
+                'ipa', 'ca-add', name, '--subject', f'CN={name}',
+            ])
+            assert f'Name: {lwca_fullname}' in result.stdout_text
+            self.master.run_command(
+                ['ipa', 'ca-mod', name, '--desc', name])
+            self.remove_lwca(name)
