@@ -144,6 +144,14 @@ class TestIpaCertFix(IntegrationTest):
 
         yield
 
+        # Prior to uninstall remove all the cert tracking to prevent
+        # errors from certmonger trying to check the status of certs
+        # that don't matter because we are uninstalling.
+        self.master.run_command(['systemctl', 'stop', 'certmonger'])
+        # Important: run_command with a str argument is able to
+        # perform shell expansion but run_command with a list of
+        # arguments is not
+        self.master.run_command('rm -fv ' + paths.CERTMONGER_REQUESTS_DIR + '*')
         tasks.uninstall_master(self.master)
         tasks.move_date(self.master, 'start', '-20Years-1day')
 
@@ -301,13 +309,18 @@ class TestIpaCertFix(IntegrationTest):
         valid. If CA cert expired, ipa-cert-fix won't work.
 
         related: https://pagure.io/freeipa/issue/8721
+
+        If CA cert is close to expiry, there's no reason to issue new certs
+        with short validity period. So, ipa-cert-fix should fail in this case.
+
+        related: https://pagure.io/freeipa/issue/9760
         """
         result = self.master.run_command(['ipa-cert-fix', '-v'],
                                          stdin_text='yes\n',
                                          raiseonerr=False)
         # check that pki-server cert-fix command fails
-        err_msg = ("ERROR: CalledProcessError(Command "
-                   "['pki-server', 'cert-fix'")
+        err_msg = ("CA signing cert is expired, exiting!")
+        assert result.returncode == 1
         assert err_msg in result.stderr_text
 
 
