@@ -24,7 +24,7 @@ Host tests
 import uuid
 from random import randint
 
-from ipatests.test_webui.crypto_utils import generate_csr
+from ipatests.test_webui.crypto_utils import generate_certificate, generate_csr
 from ipatests.test_webui.ui_driver import UI_driver
 from ipatests.test_webui.ui_driver import screenshot
 import ipatests.test_webui.data_hostgroup as hostgroup
@@ -48,8 +48,8 @@ ENTITY = 'host'
 @pytest.mark.tier1
 class host_tasks(UI_driver):
 
-    def setup(self, *args, **kwargs):
-        super(host_tasks, self).setup(*args, **kwargs)
+    @pytest.fixture(autouse=True)
+    def hosttasks_setup(self, ui_driver_fsetup):
         self.prep_data()
         self.prep_data2()
         self.prep_data3()
@@ -182,6 +182,8 @@ class test_host(host_tasks):
         self.wait_for_request(n=2, d=3)
         self.assert_visible(cert_widget_sel)
 
+        widget = self.find(cert_widget_sel, By.CSS_SELECTOR)
+
         # cert view
         self.action_list_action('view', confirm=False,
                                 parents_css_sel=cert_widget_sel)
@@ -216,7 +218,8 @@ class test_host(host_tasks):
         self.wait()
         self.select('select', '6')
         self.dialog_button_click('ok')
-        self.wait_for_request(n=2, d=3)
+        self.wait_while_working(widget)
+
         self.assert_visible(cert_widget_sel + " div.watermark")
 
         # check that revoke action is not enabled
@@ -234,7 +237,7 @@ class test_host(host_tasks):
                                 parents_css_sel=cert_widget_sel)
         self.wait()
         self.dialog_button_click('ok')
-        self.wait_for_request(n=2)
+        self.wait_while_working(widget)
 
         # check that revoke action is enabled
         self.assert_action_list_action('revoke',
@@ -254,15 +257,8 @@ class test_host(host_tasks):
     def test_arbitrary_certificates(self):
         """
         Test managing host arbitrary certificate.
-
-        Requires to have 'arbitrary_cert_path' configuration set.
         """
-        cert_path = self.config.get('arbitrary_cert_path')
-        if not cert_path:
-            self.skip('Arbitrary certificate file is not configured')
-
         self.init_app()
-        cert = self.load_file(cert_path)
         self.add_record(ENTITY, self.data)
 
         self.navigate_to_record(self.pkey)
@@ -272,9 +268,11 @@ class test_host(host_tasks):
 
         # add certificate
         self.button_click('add', parents_css_sel="div[name='certificate']")
-        self.assert_dialog()
+        self.assert_dialog('cert-add-dialog')
+
+        cert = generate_certificate(self.pkey)
         self.fill_textarea('new_cert', cert)
-        self.dialog_button_click('add')
+        self.dialog_button_click('ok')
 
         self.assert_visible("div.certificate-widget")
 
@@ -768,17 +766,17 @@ class test_host(host_tasks):
         self.fill_search_filter(self.pkey2)
         actions = ActionChains(self.driver)
         actions.send_keys(Keys.ENTER).perform()
-        self.wait(0.5)
+        self.wait(1.5)
         self.assert_record(self.pkey2)
         # negative search filter
         self.fill_search_filter(self.pkey3)
         actions = ActionChains(self.driver)
         actions.send_keys(Keys.ENTER).perform()
-        self.wait(0.5)
+        self.wait(1.5)
         self.assert_record(self.pkey4, negative=True)
         # cleanup
         self.fill_search_filter('')
         actions = ActionChains(self.driver)
         actions.send_keys(Keys.ENTER).perform()
-        self.wait(0.5)
+        self.wait(1.5)
         self.delete_record([self.pkey2, self.pkey3])
