@@ -23,6 +23,7 @@ RBAC tests
 
 from ipatests.test_webui.ui_driver import UI_driver
 from ipatests.test_webui.ui_driver import screenshot
+import pytest
 
 ROLE_ENTITY = 'role'
 ROLE_DEF_FACET = 'member_user'
@@ -70,6 +71,7 @@ PERMISSION_DATA = {
 }
 
 
+@pytest.mark.tier1
 class test_rbac(UI_driver):
 
     @screenshot
