@@ -7,7 +7,7 @@ import pytest
 
 from ipalib import api, errors
 from ipapython.dn import DN
-from ipatests.test_xmlrpc.xmlrpc_test import XMLRPC_test
+from ipatests.test_xmlrpc.xmlrpc_test import XMLRPC_test, raises_exact
 from ipatests.test_xmlrpc.tracker.certmap_plugin import (CertmapruleTracker,
                                                          CertmapconfigTracker)
 from ipatests.test_xmlrpc.tracker.user_plugin import UserTracker
@@ -53,7 +53,7 @@ certmaprule_optional_params = (
     'ipacertmappriority',
 )
 
-certmapconfig_update_params = {u'ipacertmappromptusername': u'TRUE'}
+certmapconfig_update_params = {u'ipacertmappromptusername': True}
 
 CREATE_PERM = u'System: Add Certmap Rules'
 READ_PERM = u'System: Read Certmap Rules'
@@ -230,6 +230,24 @@ class TestAddRemoveCertmap(XMLRPC_test):
         certmap_user.add_certmap(ipacertmapdata=u'rawdata')
         certmap_user.remove_certmap(ipacertmapdata=u'rawdata')
 
+    def test_add_certmap_multiple_subject(self, certmap_user):
+        certmap_user.ensure_exists()
+        cmd = certmap_user.make_command('user_add_certmapdata',
+                                        certmap_user.name)
+        with raises_exact(errors.ConversionError(
+                name='subject',
+                error=u"Only one value is allowed")):
+            cmd(subject=(u'CN=subject1', u'CN=subject2'), issuer=u'CN=issuer')
+
+    def test_add_certmap_multiple_issuer(self, certmap_user):
+        certmap_user.ensure_exists()
+        cmd = certmap_user.make_command('user_add_certmapdata',
+                                        certmap_user.name)
+        with raises_exact(errors.ConversionError(
+                name='issuer',
+                error=u"Only one value is allowed")):
+            cmd(issuer=(u'CN=issuer1', u'CN=issuer2'), subject=u'CN=subject')
+
 
 class EWE:
     """
@@ -284,7 +302,7 @@ class EWE:
         self.value = None
 
         self.change_principal_cm = change_principal(self.user, self.password)
-        self.change_principal_cm.__enter__()  # pylint: disable=no-member
+        self.change_principal_cm.__enter__()
 
         if self.exception:
             self.assert_raises_cm = pytest.raises(self.exception)
@@ -293,7 +311,7 @@ class EWE:
         return self
 
     def __exit__(self, exc_type, exc_value, tb):
-        self.change_principal_cm.__exit__(  # pylint: disable=no-member
+        self.change_principal_cm.__exit__(
             exc_type, exc_value, tb)
         if self.exception:
             return self.assert_raises_cm.__exit__(exc_type, exc_value, tb)
@@ -441,7 +459,7 @@ class TestPermission(XMLRPC_test):
             api.env.container_certmaprules,
             api.env.basedn,
         )
-        expected_ok[u'result'][0][u'ipaenabledflag'] = (u'TRUE',)
+        expected_ok[u'result'][0][u'ipaenabledflag'] = (True,)
         with self.execute_with_expected(
             certmap_user_permissions,
             [
