@@ -258,6 +258,8 @@ class test_role(Declarative):
                         host=[],
                         hostgroup=[],
                         service=[],
+                        idoverrideuser=[],
+                        sysaccount=[],
                     ),
                 ),
                 result={
@@ -515,6 +517,8 @@ class test_role(Declarative):
                         host=[],
                         hostgroup=[],
                         service=[],
+                        idoverrideuser=[],
+                        sysaccount=[],
                     ),
                 ),
                 result={
