@@ -80,9 +80,7 @@ options_def = OrderedDict([
     ('car license', {u'carlicense': u'abc1234'}),
     ('SSH key', {u'ipasshpubkey': sshpubkey}),
     ('manager', {u'manager': u'auser1'}),
-    ('user ID number', {u'uidnumber': uid}),
     ('group ID number', {u'gidnumber': gid}),
-    ('UID and GID numbers', {u'uidnumber': uid, u'gidnumber': gid}),
     ('password', {u'userpassword': u'Secret123'}),
     ('random password', {u'random': True}),
     ])
@@ -90,6 +88,13 @@ options_def = OrderedDict([
 options_ok = list(options_def.values())
 options_ids = list(options_def.keys())
 
+warn_options_def = OrderedDict([
+    ('user ID number', {u'uidnumber': uid}),
+    ('UID and GID numbers', {u'uidnumber': uid, u'gidnumber': gid}),
+])
+
+warn_options_ok = list(warn_options_def.values())
+warn_options_ids = list(warn_options_def.keys())
 
 @pytest.fixture(scope='class')
 def stageduser(request, xmlrpc_setup):
@@ -108,6 +113,12 @@ def stageduser2(request, xmlrpc_setup):
     return tracker.make_fixture_activate(request)
 
 
+@pytest.fixture(scope='class', params=warn_options_ok, ids=warn_options_ids)
+def warn_stageduser(request, xmlrpc_setup):
+    tracker = StageUserTracker(u'warnuser', u'staged', u'user', **request.param)
+    return tracker.make_fixture_activate(request)
+
+
 @pytest.fixture(scope='class')
 def user_activated(request, xmlrpc_setup):
     tracker = UserTracker(u'suser2', u'staged', u'user')
@@ -120,12 +131,6 @@ def stageduser3(request, xmlrpc_setup):
     return tracker.make_fixture_activate(request)
 
 
-@pytest.fixture(scope='class')
-def stageduser4(request, xmlrpc_setup):
-    tracker = StageUserTracker(u'tuser', u'test', u'user')
-    return tracker.make_fixture(request)
-
-
 @pytest.fixture(scope='class')
 def stageduser_notposix(request, xmlrpc_setup):
     tracker = StageUserTracker(u'notposix', u'notposix', u'notposix')
@@ -161,18 +166,6 @@ def user3(request, xmlrpc_setup):
     return tracker.make_fixture(request)
 
 
-@pytest.fixture(scope='class')
-def user4(request, xmlrpc_setup):
-    tracker = UserTracker(u'tuser', u'test', u'user')
-    return tracker.make_fixture(request)
-
-
-@pytest.fixture(scope='class')
-def user5(request, xmlrpc_setup):
-    tracker = UserTracker(u'tuser', u'test', u'user')
-    return tracker.make_fixture(request)
-
-
 @pytest.fixture(scope='class')
 def user6(request, xmlrpc_setup):
     tracker = UserTracker(u'suser2', u'staged', u'user')
@@ -291,6 +284,36 @@ class TestStagedUser(XMLRPC_test):
 
         user_activated.delete()
 
+    def test_warn_create_with_attr(self, warn_stageduser, user, user_activated):
+        """ Tests creating a user with various valid attributes that throw
+        a warning listed in 'warn_options_ok' list"""
+        # create staged user with specified parameters
+        user.ensure_exists()  # necessary for manager test
+        warn_stageduser.ensure_missing()
+        command = warn_stageduser.make_create_command()
+        result = command()
+        warn_stageduser.track_create()
+        warn_stageduser.check_create_with_warning(result, (13034,))
+
+        # activate user, verify that specified values were preserved
+        # after activation
+        user_activated.ensure_missing()
+        user_activated = UserTracker(
+            warn_stageduser.uid, warn_stageduser.givenname,
+            warn_stageduser.sn, **warn_stageduser.kwargs)
+        user_activated.create_from_staged(warn_stageduser)
+        command = warn_stageduser.make_activate_command()
+        result = command()
+        user_activated.check_activate(result)
+
+        # verify the staged user does not exist after activation
+        command = warn_stageduser.make_retrieve_command()
+        with raises_exact(errors.NotFound(
+                reason=u'%s: stage user not found' % warn_stageduser.uid)):
+            command()
+
+        user_activated.delete()
+
     def test_delete_stageduser(self, stageduser):
         stageduser.delete()
 
@@ -724,52 +747,50 @@ class TestManagers(XMLRPC_test):
 
 @pytest.mark.tier1
 class TestDuplicates(XMLRPC_test):
-    def test_active_same_as_preserved(self, user4, user5):
-        user4.ensure_missing()
-        user5.make_preserved_user()
-        command = user4.make_create_command()
+    @pytest.fixture
+    def user(self, request, xmlrpc_setup):
+        tracker = UserTracker("tuser", "test", "user")
+        return tracker.make_fixture(request)
+
+    @pytest.fixture
+    def stageduser(self, request, xmlrpc_setup):
+        tracker = StageUserTracker("tuser", "test", "user")
+        return tracker.make_fixture(request)
+
+    def test_active_same_as_preserved(self, user):
+        user.make_preserved_user()
+        command = user.make_create_command()
         with raises_exact(errors.DuplicateEntry(
-                message=u'user with name "%s" already exists' % user4.uid)):
+                message=u'user with name "%s" already exists' % user.uid)):
             command()
-        user5.delete()
 
-    def test_staged_same_as_active(self, user4, stageduser4):
-        user4.ensure_exists()
-        stageduser4.create()  # can be created
+    def test_staged_same_as_active(self, user, stageduser):
+        user.create()
+        stageduser.create()  # can be created
 
-        command = stageduser4.make_activate_command()
+        command = stageduser.make_activate_command()
         with raises_exact(errors.DuplicateEntry(
                 message=u'active user with name "%s" already exists' %
-                user4.uid)):
+                user.uid)):
             command()  # cannot be activated
 
-        user4.delete()
-        stageduser4.delete()
+    def test_staged_same_as_preserved(self, user, stageduser):
+        user.make_preserved_user()
+        stageduser.create()  # can be created
 
-    def test_staged_same_as_preserved(self, user5, stageduser4):
-        user5.make_preserved_user()
-        stageduser4.create()  # can be created
-
-        command = stageduser4.make_activate_command()
+        command = stageduser.make_activate_command()
         with raises_exact(errors.DuplicateEntry(
                 message=u'This entry already exists')):
             command()  # cannot be activated
 
-        user5.delete()
-        stageduser4.delete()
+    def test_active_same_as_staged(self, user, stageduser):
+        stageduser.create()
+        user.create()  # can be created
 
-    def test_active_same_as_staged(self, user4, stageduser4):
-        user4.ensure_missing()
-        stageduser4.ensure_exists()
-        command = user4.make_create_command()
-        result = command()
-        user4.track_create()
-        user4.check_create(result)  # can be created
-
-        command = stageduser4.make_activate_command()
+        command = stageduser.make_activate_command()
         with raises_exact(errors.DuplicateEntry(
                 message=u'active user with name "%s" already exists' %
-                user4.uid)):
+                user.uid)):
             command()  # cannot be activated
 
 
