@@ -475,6 +475,7 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     api.env.in_tree = False  # object
     api.env.interactive = True
     api.env.ipalib = ''  # object
+    api.env.key_type_size = 'rsa:2048'
     api.env.kinit_lifetime = None
     api.env.log = ''  # object
     api.env.logdir = ''  # object
@@ -566,6 +567,7 @@ AstroidBuilder(MANAGER).string_build(
     textwrap.dedent(
         """\
     from ipatests.test_integration.base import IntegrationTest
+    from ipatests.test_integration.base import MultiDomainIntegrationTest
     from ipatests.pytest_ipa.integration.host import Host, WinHost
     from ipatests.pytest_ipa.integration.config import Config, Domain
 
@@ -584,6 +586,9 @@ AstroidBuilder(MANAGER).string_build(
         def __getitem__(self, key):
             return Domain()
 
+    class PylintTrustedDomains:
+        def __getitem__(self, key):
+            return Domain()
 
     Host.config = Config()
     Host.domain = Domain()
@@ -596,6 +601,14 @@ AstroidBuilder(MANAGER).string_build(
     IntegrationTest.ad_treedomains = PylintWinHosts()
     IntegrationTest.ad_subdomains = PylintWinHosts()
     IntegrationTest.ad_domains = PylintADDomains()
+    MultiDomainIntegrationTest.domain = Domain()
+    MultiDomainIntegrationTest.master = Host()
+    MultiDomainIntegrationTest.replicas = PylintIPAHosts()
+    MultiDomainIntegrationTest.clients = PylintIPAHosts()
+    MultiDomainIntegrationTest.trusted_master = Host()
+    MultiDomainIntegrationTest.trusted_replicas = PylintIPAHosts()
+    MultiDomainIntegrationTest.trusted_clients = PylintIPAHosts()
+    MultiDomainIntegrationTest.trusted_domains = PylintTrustedDomains()
     """
     )
 )
